@@ -18,7 +18,9 @@ from great_expectations.data_context.store import (
     TupleS3StoreBackend,
     ValidationsStore,
 )
-from great_expectations.data_context.store.store_backend import StoreBackend
+from great_expectations.data_context.store.store_backend import (
+    StoreBackend,  # noqa: TCH001
+)
 from great_expectations.data_context.types.resource_identifiers import (
     ValidationResultIdentifier,
 )
