@@ -3,12 +3,12 @@ import sys
 import click
 
 from great_expectations import DataContext
-from great_expectations import exceptions as ge_exceptions
+from great_expectations import exceptions as gx_exceptions
 from great_expectations.cli.v012.cli_messages import SECTION_SEPARATOR
 from great_expectations.cli.v012.toolkit import load_data_context_with_error_handling
 from great_expectations.cli.v012.util import cli_message
 from great_expectations.core.usage_statistics.util import send_usage_message
-from great_expectations.data_context.types.base import CURRENT_GE_CONFIG_VERSION
+from great_expectations.data_context.types.base import CURRENT_GX_CONFIG_VERSION
 
 
 @click.group()
@@ -68,10 +68,10 @@ def do_config_check(target_directory):
     try:
         context = DataContext(context_root_dir=target_directory)
         ge_config_version: int = context.get_config().config_version
-        if int(ge_config_version) < CURRENT_GE_CONFIG_VERSION:
+        if int(ge_config_version) < CURRENT_GX_CONFIG_VERSION:
             upgrade_message: str = f"""The config_version of your great_expectations.yml -- {float(ge_config_version)} -- is outdated.
 Please consult the V3 API migration guide https://docs.greatexpectations.io/en/latest/guides/how_to_guides/migrating_versions.html and
-upgrade your Great Expectations configuration to version {float(CURRENT_GE_CONFIG_VERSION)} in order to take advantage of the latest capabilities.
+upgrade your Great Expectations configuration to version {float(CURRENT_GX_CONFIG_VERSION)} in order to take advantage of the latest capabilities.
             """
             return (
                 False,
@@ -80,14 +80,14 @@ upgrade your Great Expectations configuration to version {float(CURRENT_GE_CONFI
             )
         return True, None, context
     except (
-        ge_exceptions.InvalidConfigurationYamlError,
-        ge_exceptions.InvalidTopLevelConfigKeyError,
-        ge_exceptions.MissingTopLevelConfigKeyError,
-        ge_exceptions.InvalidConfigValueTypeError,
-        ge_exceptions.UnsupportedConfigVersionError,
-        ge_exceptions.DataContextError,
-        ge_exceptions.PluginClassNotFoundError,
-        ge_exceptions.PluginModuleNotFoundError,
-        ge_exceptions.GreatExpectationsError,
+        gx_exceptions.InvalidConfigurationYamlError,
+        gx_exceptions.InvalidTopLevelConfigKeyError,
+        gx_exceptions.MissingTopLevelConfigKeyError,
+        gx_exceptions.InvalidConfigValueTypeError,
+        gx_exceptions.UnsupportedConfigVersionError,
+        gx_exceptions.DataContextError,
+        gx_exceptions.PluginClassNotFoundError,
+        gx_exceptions.PluginModuleNotFoundError,
+        gx_exceptions.GreatExpectationsError,
     ) as err:
         return False, err.message, None
