@@ -9,7 +9,7 @@ programmatically create new enum values if run as a module.
         In send_usage_message() as an event name:
 
         handler.send_usage_message(
-            event=UsageStatsEvents.EXECUTION_ENGINE_SQLALCHEMY_CONNECT.value,
+            event=UsageStatsEvents.EXECUTION_ENGINE_SQLALCHEMY_CONNECT,
             event_payload={
                 "anonymized_name": handler.anonymizer.anonymize(self.name),
                 "sqlalchemy_dialect": self.engine.name,
@@ -36,7 +36,7 @@ import enum
 from typing import List, Optional
 
 
-class UsageStatsEvents(enum.Enum):
+class UsageStatsEvents(str, enum.Enum):
     """Event names for all Great Expectations usage stats events.
 
     Note: These should be used in place of strings, or retrieved
