@@ -1,26 +1,24 @@
-"""Provide GE package dependencies.
+"""Provide GX package dependencies.
 
-This module contains static lists of GE dependencies, along with a utility for
+This module contains static lists of GX dependencies, along with a utility for
 checking and updating these static lists.
 
     Typical usage example:
-        ge_dependencies = GEDependencies()
+        ge_dependencies = GXDependencies()
         print(ge_dependencies.get_required_dependency_names())
         print(ge_dependencies.get_dev_dependency_names())
 
     To verify lists are accurate, you can run this file or execute main() from
-    within a cloned GE repository. This will check the existing requirements
+    within a cloned GX repository. This will check the existing requirements
     files against the static lists returned via the methods above in the
     usage example and raise exceptions if there are discrepancies.
 """
-import os
+import pathlib
 import re
-from typing import List, Set
-
-from great_expectations.data_context.util import file_relative_path
+from typing import Dict, List, Set
 
 
-class GEDependencies:
+class GXDependencies:
     """Store and provide dependencies when requested.
 
     Also acts as a utility to check stored dependencies match our
@@ -30,7 +28,7 @@ class GEDependencies:
     """
 
     """This list should be kept in sync with our requirements.txt file."""
-    GE_REQUIRED_DEPENDENCIES: List[str] = sorted(
+    GX_REQUIRED_DEPENDENCIES: List[str] = sorted(
         [
             "altair",
             "Click",
@@ -50,13 +48,13 @@ class GEDependencies:
             "numpy",
             "packaging",
             "pandas",
+            "pydantic",
             "pyparsing",
             "python-dateutil",
             "pytz",
             "requests",
             "ruamel.yaml",
             "scipy",
-            "termcolor",
             "tqdm",
             "typing-extensions",
             "urllib3",
@@ -65,7 +63,7 @@ class GEDependencies:
     )
 
     """This list should be kept in sync with our requirements-dev*.txt files."""
-    ALL_GE_DEV_DEPENDENCIES: List[str] = sorted(
+    ALL_GX_DEV_DEPENDENCIES: List[str] = sorted(
         [
             "PyMySQL",
             "azure-identity",
@@ -73,15 +71,16 @@ class GEDependencies:
             "azure-storage-blob",
             "black",
             "boto3",
+            "docstring-parser",
             "feather-format",
-            "flake8",
+            "ruff",
             "flask",
             "freezegun",
             "gcsfs",
+            "google-cloud-bigquery",
             "google-cloud-secret-manager",
             "google-cloud-storage",
             "invoke",
-            "isort",
             "mistune",
             "mock-alchemy",
             "moto",
@@ -104,7 +103,6 @@ class GEDependencies:
             "pytest-order",
             "pytest-random-order",
             "pytest-timeout",
-            "pyupgrade",
             "requirements-parser",
             "s3fs",
             "snapshottest",
@@ -116,28 +114,29 @@ class GEDependencies:
             "sqlalchemy-redshift",
             "teradatasqlalchemy",
             "xlrd",
+            "sqlalchemy-vertica-python",
         ]
     )
 
-    GE_DEV_DEPENDENCIES_EXCLUDED_FROM_TRACKING: List[str] = [
+    GX_DEV_DEPENDENCIES_EXCLUDED_FROM_TRACKING: List[str] = [
         # requirements-dev-contrib.txt:
         "black",
-        "flake8",
+        "ruff",
         "invoke",
-        "isort",
         "mypy",
         "pre-commit",
         "pytest-cov",
         "pytest-order",
         "pytest-random-order",
-        "pyupgrade",
         # requirements-dev-lite.txt:
         "flask",
         "freezegun",
         "mistune",
         "mock-alchemy",
         "moto",
+        "ipykernel",
         "nbconvert",
+        "py",
         "pyfakefs",
         "pytest",
         "pytest-benchmark",
@@ -203,25 +202,41 @@ class GEDependencies:
         "uszipcode",
         "yahoo_fin",
         "zipcodes",
+        # requirements-dev-api-docs-test.txt
+        "docstring-parser",
     ]
 
-    GE_DEV_DEPENDENCIES: Set[str] = set(ALL_GE_DEV_DEPENDENCIES) - set(
-        GE_DEV_DEPENDENCIES_EXCLUDED_FROM_TRACKING
+    GX_DEV_DEPENDENCIES: Set[str] = set(ALL_GX_DEV_DEPENDENCIES) - set(
+        GX_DEV_DEPENDENCIES_EXCLUDED_FROM_TRACKING
     )
 
-    def __init__(self, requirements_relative_base_dir: str = "../../../") -> None:
-        self._requirements_relative_base_dir = file_relative_path(
-            __file__, requirements_relative_base_dir
-        )
-        self._dev_requirements_prefix: str = "requirements-dev"
+    DEV_REQUIREMENTS_PREFIX = "requirements-dev"
+    PRIMARY_REQUIREMENTS_FILE = "requirements.txt"
+
+    def __init__(self) -> None:
+        self._requirements_paths = self._init_requirements_paths()
+
+    def _init_requirements_paths(self) -> Dict[str, pathlib.Path]:
+        project_root = pathlib.Path(__file__).parents[3]
+        reqs_dir = project_root.joinpath("reqs")
+        assert project_root.exists() and reqs_dir.exists()
+
+        pattern = "requirements*.txt"
+
+        req_dict = {}
+        req_files = list(project_root.glob(pattern)) + list(reqs_dir.glob(pattern))
+        for req_file in req_files:
+            req_dict[req_file.name] = req_file
+
+        return req_dict
 
     def get_required_dependency_names(self) -> List[str]:
-        """Sorted list of required GE dependencies"""
-        return self.GE_REQUIRED_DEPENDENCIES
+        """Sorted list of required GX dependencies"""
+        return self.GX_REQUIRED_DEPENDENCIES
 
     def get_dev_dependency_names(self) -> Set[str]:
-        """Set of dev GE dependencies"""
-        return self.GE_DEV_DEPENDENCIES
+        """Set of dev GX dependencies"""
+        return self.GX_DEV_DEPENDENCIES
 
     def get_required_dependency_names_from_requirements_file(self) -> List[str]:
         """Get unique names of required dependencies.
@@ -232,7 +247,7 @@ class GEDependencies:
         return sorted(
             set(
                 self._get_dependency_names_from_requirements_file(
-                    self.required_requirements_path
+                    self._requirements_paths[self.PRIMARY_REQUIREMENTS_FILE]
                 )
             )
         )
@@ -243,49 +258,32 @@ class GEDependencies:
             List of string names of dev dependencies.
         """
         dev_dependency_names: Set[str] = set()
-        dev_dependency_filename: str
-        for dev_dependency_filename in self.dev_requirements_paths:
+        dev_dependency_paths: List[pathlib.Path] = [
+            path
+            for name, path in self._requirements_paths.items()
+            if name.startswith(self.DEV_REQUIREMENTS_PREFIX)
+        ]
+        for dev_dependency_path in dev_dependency_paths:
             dependency_names: List[
                 str
             ] = self._get_dependency_names_from_requirements_file(
-                os.path.join(
-                    self._requirements_relative_base_dir, dev_dependency_filename
-                )
+                dev_dependency_path.absolute()
             )
             dev_dependency_names.update(dependency_names)
         return sorted(dev_dependency_names)
 
-    @property
-    def required_requirements_path(self) -> str:
-        """Get path for requirements.txt
-
-        Returns:
-            String path of requirements.txt
-        """
-        return os.path.join(self._requirements_relative_base_dir, "requirements.txt")
-
-    @property
-    def dev_requirements_paths(self) -> List[str]:
-        """Get all paths for requirements-dev files with dependencies in them.
-        Returns:
-            List of string filenames for dev requirements files
-        """
-        return [
-            filename
-            for filename in os.listdir(self._requirements_relative_base_dir)
-            if filename.startswith(self._dev_requirements_prefix)
-        ]
-
-    def _get_dependency_names_from_requirements_file(self, filepath: str) -> List[str]:
+    def _get_dependency_names_from_requirements_file(
+        self, filepath: pathlib.Path
+    ) -> List[str]:
         """Load requirements file and parse to retrieve dependency names.
 
         Args:
-            filepath: String relative filepath of requirements file to parse.
+            filepath: Absolute filepath of requirements file to parse.
 
         Returns:
             List of string names of dependencies.
         """
-        with open(filepath) as f:
+        with filepath.open() as f:
             dependencies_with_versions = f.read().splitlines()
             return self._get_dependency_names(dependencies_with_versions)
 
@@ -312,7 +310,7 @@ class GEDependencies:
 
 def main() -> None:
     """Run this module to generate a list of packages from requirements files to update our static lists"""
-    ge_dependencies = GEDependencies()
+    ge_dependencies = GXDependencies()
     print("\n\nRequired Dependencies:\n\n")
     print(ge_dependencies.get_required_dependency_names_from_requirements_file())
     print("\n\nDev Dependencies:\n\n")
@@ -320,13 +318,14 @@ def main() -> None:
     assert (
         ge_dependencies.get_required_dependency_names()
         == ge_dependencies.get_required_dependency_names_from_requirements_file()
-    ), "Mismatch between required dependencies in requirements files and in GEDependencies"
-    assert (
-        ge_dependencies.get_dev_dependency_names()
-        == ge_dependencies.get_dev_dependency_names_from_requirements_file()
-    ), "Mismatch between dev dependencies in requirements files and in GEDependencies"
+    ), "Mismatch between required dependencies in requirements files and in GXDependencies"
+    assert ge_dependencies.get_dev_dependency_names() == set(
+        ge_dependencies.get_dev_dependency_names_from_requirements_file()
+    ) - set(
+        GXDependencies.GX_DEV_DEPENDENCIES_EXCLUDED_FROM_TRACKING
+    ), "Mismatch between dev dependencies in requirements files and in GXDependencies"
     print(
-        "\n\nRequired and Dev dependencies in requirements files match those in GEDependencies"
+        "\n\nRequired and Dev dependencies in requirements files match those in GXDependencies"
     )
 
 
