@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import copy
 import datetime
 import decimal
@@ -7,16 +9,31 @@ import re
 import sys
 import uuid
 from collections import OrderedDict
-from collections.abc import Mapping
-from typing import Any, Callable, Dict, Iterable, List, Optional, Union
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Dict,
+    List,
+    Mapping,
+    MutableMapping,
+    Optional,
+    Tuple,
+    TypeVar,
+    Union,
+    overload,
+)
 from urllib.parse import urlparse
 
 import dateutil.parser
 import numpy as np
 import pandas as pd
 from IPython import get_ipython
+from typing_extensions import TypeAlias
 
-from great_expectations import exceptions as ge_exceptions
+from great_expectations import exceptions as gx_exceptions
+from great_expectations.alias_types import JSONValues  # noqa: TCH001
+from great_expectations.core._docs_decorators import public_api
 from great_expectations.core.run_identifier import RunIdentifier
 from great_expectations.exceptions import InvalidExpectationConfigurationError
 from great_expectations.types import SerializableDictDot
@@ -26,19 +43,30 @@ from great_expectations.types.base import SerializableDotDict
 # https://stackoverflow.com/questions/3232943/update-value-of-a-nested-dictionary-of-varying-depth
 from great_expectations.util import convert_decimal_to_float
 
+logger = logging.getLogger(__name__)
+
+try:
+    import pyspark
+    from pyspark.sql import SparkSession  # noqa: F401
+except ImportError:
+    pyspark = None
+    SparkSession = None
+    logger.debug(
+        "Unable to load pyspark; install optional spark dependency if you will be working with Spark dataframes"
+    )
+
 try:
     from pyspark.sql.types import StructType
 except ImportError:
-    StructType = None  # type: ignore
-
-logger = logging.getLogger(__name__)
+    StructType = None
 
 
 try:
-    from shapely.geometry import LineString, Point, Polygon
+    from shapely.geometry import LineString, MultiPolygon, Point, Polygon
 except ImportError:
     Point = None
     Polygon = None
+    MultiPolygon = None
     LineString = None
 
 try:
@@ -70,24 +98,22 @@ SCHEMAS = {
 }
 
 
-try:
-    import pyspark
-except ImportError:
-    pyspark = None
-    logger.debug(
-        "Unable to load pyspark; install optional spark dependency if you will be working with Spark dataframes"
-    )
+if TYPE_CHECKING:
+    import numpy.typing as npt
+    from ruamel.yaml.comments import CommentedMap
 
 
 _SUFFIX_TO_PD_KWARG = {"gz": "gzip", "zip": "zip", "bz2": "bz2", "xz": "xz"}
 
+M = TypeVar("M", bound=MutableMapping)
+
 
 def nested_update(
-    d: Union[Iterable, dict],
-    u: Union[Iterable, dict],
+    d: M,
+    u: Mapping,
     dedup: bool = False,
     concat_lists: bool = True,
-):
+) -> M:
     """
     Update d with items from u, recursively and joining elements. By default, list values are
     concatenated without de-duplication. If concat_lists is set to False, lists in u (new dict)
@@ -161,17 +187,98 @@ def determine_progress_bar_method_by_environment() -> Callable:
     return tqdm
 
 
-def convert_to_json_serializable(data):  # noqa: C901 - complexity 28
-    """
-    Helper function to convert an object to one that is json serializable
-    Args:
-        data: an object to attempt to convert a corresponding json-serializable object
-    Returns:
-        (dict) A converted test_object
-    Warning:
-        test_obj may also be converted in place.
-    """
+ToBool: TypeAlias = bool
+ToFloat: TypeAlias = Union[float, np.floating]
+ToInt: TypeAlias = Union[int, np.integer]
+ToStr: TypeAlias = Union[
+    str, bytes, uuid.UUID, datetime.date, datetime.datetime, np.datetime64
+]
 
+ToList: TypeAlias = Union[list, set, tuple, "npt.NDArray", pd.Index, pd.Series]
+ToDict: TypeAlias = Union[
+    dict, "CommentedMap", pd.DataFrame, SerializableDictDot, SerializableDotDict
+]
+
+JSONConvertable: TypeAlias = Union[
+    ToDict, ToList, ToStr, ToInt, ToFloat, ToBool, ToBool, None
+]
+
+
+@overload
+def convert_to_json_serializable(  # type: ignore[misc] # overlap with `ToList`?
+    data: ToDict,
+) -> dict:
+    ...
+
+
+@overload
+def convert_to_json_serializable(  # type: ignore[misc] # overlap with `ToDict`?
+    data: ToList,
+) -> list:
+    ...
+
+
+@overload
+def convert_to_json_serializable(
+    data: ToBool,
+) -> bool:
+    ...
+
+
+@overload
+def convert_to_json_serializable(
+    data: ToFloat,
+) -> float:
+    ...
+
+
+@overload
+def convert_to_json_serializable(
+    data: ToInt,
+) -> int:
+    ...
+
+
+@overload
+def convert_to_json_serializable(
+    data: ToStr,
+) -> str:
+    ...
+
+
+@overload
+def convert_to_json_serializable(
+    data: None,
+) -> None:
+    ...
+
+
+@public_api  # noqa: C901 - complexity 32
+def convert_to_json_serializable(  # noqa: C901 - complexity 32
+    data: JSONConvertable,
+) -> JSONValues:
+    """Converts an object to one that is JSON-serializable.
+
+    WARNING, data may be converted in place.
+
+    Args:
+        data: an object to convert to a JSON-serializable object
+
+    Returns:
+        A JSON-serializable object. For example:
+
+        >>> convert_to_json_serializable(1)
+        1
+
+        >>> convert_to_json_serializable("hello")
+        "hello"
+
+        >>> convert_to_json_serializable(Polygon([(0, 0), (2, 0), (2, 2), (0, 2)]))
+        "POLYGON ((0 0, 2 0, 2 2, 0 2, 0 0))"
+
+    Raises:
+        TypeError: A non-JSON-serializable field was found.
+    """
     # If it's one of our types, we use our own conversion; this can move to full schema
     # once nesting goes all the way down
     if isinstance(data, (SerializableDictDot, SerializableDotDict)):
@@ -194,7 +301,7 @@ def convert_to_json_serializable(data):  # noqa: C901 - complexity 28
         return new_dict
 
     if isinstance(data, (list, tuple, set)):
-        new_list = []
+        new_list: List[JSONValues] = []
         for val in data:
             new_list.append(convert_to_json_serializable(val))
 
@@ -215,11 +322,17 @@ def convert_to_json_serializable(data):  # noqa: C901 - complexity 28
     if isinstance(data, (datetime.datetime, datetime.date)):
         return data.isoformat()
 
-    if isinstance(data, (uuid.UUID, bytes)):
+    if isinstance(data, (np.datetime64)):
+        return np.datetime_as_string(data)
+
+    if isinstance(data, uuid.UUID):
+        return str(data)
+
+    if isinstance(data, bytes):
         return str(data)
 
     # noinspection PyTypeChecker
-    if Polygon and isinstance(data, (Point, Polygon, LineString)):
+    if Polygon and isinstance(data, (Point, Polygon, MultiPolygon, LineString)):
         return str(data)
 
     # Use built in base type from numpy, https://docs.scipy.org/doc/numpy-1.13.0/user/basics.types.html
@@ -228,11 +341,11 @@ def convert_to_json_serializable(data):  # noqa: C901 - complexity 28
         return bool(data)
 
     if np.issubdtype(type(data), np.integer) or np.issubdtype(type(data), np.uint):
-        return int(data)
+        return int(data)  # type: ignore[arg-type] # could be None
 
     if np.issubdtype(type(data), np.floating):
         # Note: Use np.floating to avoid FutureWarning from numpy
-        return float(round(data, sys.float_info.dig))
+        return float(round(data, sys.float_info.dig))  # type: ignore[arg-type] # could be None
 
     # Note: This clause has to come after checking for np.ndarray or we get:
     #      `ValueError: The truth value of an array with more than one element is ambiguous. Use a.any() or a.all()`
@@ -260,7 +373,7 @@ def convert_to_json_serializable(data):  # noqa: C901 - complexity 28
                 index_name: convert_to_json_serializable(idx),
                 value_name: convert_to_json_serializable(val),
             }
-            for idx, val in data.iteritems()
+            for idx, val in data.items()
         ]
 
     if isinstance(data, pd.DataFrame):
@@ -292,6 +405,7 @@ def convert_to_json_serializable(data):  # noqa: C901 - complexity 28
         raise TypeError(
             f"{str(data)} is of type {type(data).__name__} which cannot be serialized."
         )
+    return None
 
 
 def ensure_json_serializable(data):  # noqa: C901 - complexity 21
@@ -372,7 +486,7 @@ def ensure_json_serializable(data):  # noqa: C901 - complexity 21
                 index_name: ensure_json_serializable(idx),
                 value_name: ensure_json_serializable(val),
             }
-            for idx, val in data.iteritems()
+            for idx, val in data.items()
         ]
         return
 
@@ -406,7 +520,7 @@ def substitute_all_strftime_format_strings(
     elements using either the provided datetime_obj or the current datetime
     """
 
-    datetime_obj: datetime.datetime = datetime_obj or datetime.datetime.now()
+    datetime_obj = datetime_obj or datetime.datetime.now()
     if isinstance(data, dict) or isinstance(data, OrderedDict):
         return {
             k: substitute_all_strftime_format_strings(v, datetime_obj=datetime_obj)
@@ -418,27 +532,16 @@ def substitute_all_strftime_format_strings(
             for el in data
         ]
     elif isinstance(data, str):
-        return get_datetime_string_from_strftime_format(data, datetime_obj=datetime_obj)
+        return datetime_obj.strftime(data)
     else:
         return data
 
 
-def get_datetime_string_from_strftime_format(
-    format_str: str, datetime_obj: Optional[datetime.datetime] = None
-) -> str:
-    """
-    This utility function takes a string with strftime format elements and substitutes those elements using
-    either the provided datetime_obj or current datetime
-    """
-    datetime_obj: datetime.datetime = datetime_obj or datetime.datetime.now()
-    return datetime_obj.strftime(format_str)
-
-
 def parse_string_to_datetime(
     datetime_string: str, datetime_format_string: Optional[str] = None
-) -> datetime.date:
+) -> datetime.datetime:
     if not isinstance(datetime_string, str):
-        raise ge_exceptions.SorterError(
+        raise gx_exceptions.SorterError(
             f"""Source "datetime_string" must have string type (actual type is "{str(type(datetime_string))}").
             """
         )
@@ -447,7 +550,7 @@ def parse_string_to_datetime(
         return dateutil.parser.parse(timestr=datetime_string)
 
     if datetime_format_string and not isinstance(datetime_format_string, str):
-        raise ge_exceptions.SorterError(
+        raise gx_exceptions.SorterError(
             f"""DateTime parsing formatter "datetime_format_string" must have string type (actual type is
 "{str(type(datetime_format_string))}").
             """
@@ -651,30 +754,30 @@ class DBFSPath:
             raise ValueError("Path should start with either /dbfs or dbfs:")
 
 
-def sniff_s3_compression(s3_url: S3Url) -> str:
+def sniff_s3_compression(s3_url: S3Url) -> Union[str, None]:
     """Attempts to get read_csv compression from s3_url"""
-    return _SUFFIX_TO_PD_KWARG.get(s3_url.suffix)
+    return _SUFFIX_TO_PD_KWARG.get(s3_url.suffix) if s3_url.suffix else None
 
 
 # noinspection PyPep8Naming
 def get_or_create_spark_application(
     spark_config: Optional[Dict[str, str]] = None,
     force_reuse_spark_context: bool = False,
-):
-    # Due to the uniqueness of SparkContext per JVM, it is impossible to change SparkSession configuration dynamically.
-    # Attempts to circumvent this constraint cause "ValueError: Cannot run multiple SparkContexts at once" to be thrown.
-    # Hence, SparkSession with SparkConf acceptable for all tests must be established at "pytest" collection time.
-    # This is preferred to calling "return SparkSession.builder.getOrCreate()", which will result in the setting
-    # ("spark.app.name", "pyspark-shell") remaining in SparkConf statically for the entire duration of the "pytest" run.
-    try:
-        from pyspark.sql import SparkSession
-    except ImportError:
-        SparkSession = None
-        # TODO: review logging more detail here
-        logger.debug(
-            "Unable to load pyspark; install optional spark dependency for support."
-        )
+) -> SparkSession:
+    """Obtains configured Spark session if it has already been initialized; otherwise creates Spark session, configures it, and returns it to caller.
 
+    Due to the uniqueness of SparkContext per JVM, it is impossible to change SparkSession configuration dynamically.
+    Attempts to circumvent this constraint cause "ValueError: Cannot run multiple SparkContexts at once" to be thrown.
+    Hence, SparkSession with SparkConf acceptable for all tests must be established at "pytest" collection time.
+    This is preferred to calling "return SparkSession.builder.getOrCreate()", which will result in the setting
+    ("spark.app.name", "pyspark-shell") remaining in SparkConf statically for the entire duration of the "pytest" run.
+
+    Args:
+        spark_config: Dictionary containing Spark configuration (string-valued keys mapped to string-valued properties).
+        force_reuse_spark_context: Boolean flag indicating (if True) that creating new Spark context is forbidden.
+
+    Returns: SparkSession (new or existing as per "isStopped()" status and "force_reuse_spark_context" directive).
+    """
     if spark_config is None:
         spark_config = {}
     else:
@@ -692,7 +795,7 @@ def get_or_create_spark_application(
     if spark_session is None:
         raise ValueError("SparkContext could not be started.")
 
-    # noinspection PyProtectedMember
+    # noinspection PyUnresolvedReferences
     sc_stopped: bool = spark_session.sparkContext._jsc.sc().isStopped()
     if not force_reuse_spark_context and spark_restart_required(
         current_spark_config=spark_session.sparkContext.getConf().getAll(),
@@ -722,21 +825,21 @@ def get_or_create_spark_application(
 # noinspection PyPep8Naming
 def get_or_create_spark_session(
     spark_config: Optional[Dict[str, str]] = None,
-):
-    # Due to the uniqueness of SparkContext per JVM, it is impossible to change SparkSession configuration dynamically.
-    # Attempts to circumvent this constraint cause "ValueError: Cannot run multiple SparkContexts at once" to be thrown.
-    # Hence, SparkSession with SparkConf acceptable for all tests must be established at "pytest" collection time.
-    # This is preferred to calling "return SparkSession.builder.getOrCreate()", which will result in the setting
-    # ("spark.app.name", "pyspark-shell") remaining in SparkConf statically for the entire duration of the "pytest" run.
-    try:
-        from pyspark.sql import SparkSession
-    except ImportError:
-        SparkSession = None
-        # TODO: review logging more detail here
-        logger.debug(
-            "Unable to load pyspark; install optional spark dependency for support."
-        )
+) -> SparkSession:
+    """Obtains Spark session if it already exists; otherwise creates Spark session and returns it to caller.
 
+    Due to the uniqueness of SparkContext per JVM, it is impossible to change SparkSession configuration dynamically.
+    Attempts to circumvent this constraint cause "ValueError: Cannot run multiple SparkContexts at once" to be thrown.
+    Hence, SparkSession with SparkConf acceptable for all tests must be established at "pytest" collection time.
+    This is preferred to calling "return SparkSession.builder.getOrCreate()", which will result in the setting
+    ("spark.app.name", "pyspark-shell") remaining in SparkConf statically for the entire duration of the "pytest" run.
+
+    Args:
+        spark_config: Dictionary containing Spark configuration (string-valued keys mapped to string-valued properties).
+
+    Returns:
+
+    """
     spark_session: Optional[SparkSession]
     try:
         if spark_config is None:
@@ -769,8 +872,18 @@ def get_or_create_spark_session(
 
 
 def spark_restart_required(
-    current_spark_config: List[tuple], desired_spark_config: dict
+    current_spark_config: List[Tuple[str, str]], desired_spark_config: dict
 ) -> bool:
+    """Determines whether or not Spark session should be restarted, based on supplied current and desired configuration.
+
+    Either new "App" name or configuration change necessitates Spark session restart.
+
+    Args:
+        current_spark_config: List of tuples containing Spark configuration string-valued key/property pairs.
+        desired_spark_config: List of tuples containing Spark configuration string-valued key/property pairs.
+
+    Returns: Boolean flag indicating (if True) that Spark session restart is required.
+    """
 
     # we can't change spark context config values within databricks runtimes
     if in_databricks():
