@@ -2,19 +2,18 @@ import random
 import uuid
 from typing import Dict
 
+import great_expectations.exceptions as gx_exceptions
 from great_expectations.core import ExpectationSuite
 from great_expectations.core.expectation_suite import ExpectationSuiteSchema
+from great_expectations.data_context.cloud_constants import GXCloudRESTResource
 from great_expectations.data_context.store.database_store_backend import (
     DatabaseStoreBackend,
 )
-from great_expectations.data_context.store.ge_cloud_store_backend import (
-    GeCloudRESTResource,
-)
 from great_expectations.data_context.store.store import Store
 from great_expectations.data_context.store.tuple_store_backend import TupleStoreBackend
 from great_expectations.data_context.types.resource_identifiers import (
     ExpectationSuiteIdentifier,
-    GeCloudIdentifier,
+    GXCloudIdentifier,
 )
 from great_expectations.data_context.util import load_class
 from great_expectations.util import (
@@ -165,14 +164,35 @@ class ExpectationsStore(Store):
 
     def ge_cloud_response_json_to_object_dict(self, response_json: Dict) -> Dict:
         """
-        This method takes full json response from GE cloud and outputs a dict appropriate for
-        deserialization into a GE object
+        This method takes full json response from GX cloud and outputs a dict appropriate for
+        deserialization into a GX object
         """
-        ge_cloud_expectation_suite_id = response_json["data"]["id"]
-        expectation_suite_dict = response_json["data"]["attributes"]["suite"]
-        expectation_suite_dict["ge_cloud_id"] = ge_cloud_expectation_suite_id
+        suite_data: Dict
+        if isinstance(response_json["data"], list):
+            suite_data = response_json["data"][0]
+        else:
+            suite_data = response_json["data"]
+        ge_cloud_suite_id: str = suite_data["id"]
+        suite_dict: Dict = suite_data["attributes"]["suite"]
+        suite_dict["ge_cloud_id"] = ge_cloud_suite_id
 
-        return expectation_suite_dict
+        return suite_dict
+
+    def add(self, key, value, **kwargs):
+        try:
+            super().add(key=key, value=value, **kwargs)
+        except gx_exceptions.StoreBackendError:
+            raise gx_exceptions.ExpectationSuiteError(
+                f"An ExpectationSuite named {value.expectation_suite_name} already exists."
+            )
+
+    def update(self, key, value, **kwargs):
+        try:
+            super().update(key=key, value=value, **kwargs)
+        except gx_exceptions.StoreBackendError:
+            raise gx_exceptions.ExpectationSuiteError(
+                f"Could not find an existing ExpectationSuite named {value.expectation_suite_name}."
+            )
 
     def get(self, key) -> ExpectationSuite:
         return super().get(key)  # type: ignore[return-value]
@@ -181,8 +201,8 @@ class ExpectationsStore(Store):
         return self.store_backend.remove_key(key)
 
     def serialize(self, value):
-        if self.ge_cloud_mode:
-            # GeCloudStoreBackend expects a json str
+        if self.cloud_mode:
+            # GXCloudStoreBackend expects a json str
             return self._expectationSuiteSchema.dump(value)
         return self._expectationSuiteSchema.dumps(value, indent=2, sort_keys=True)
 
@@ -216,9 +236,9 @@ class ExpectationsStore(Store):
         test_key_name = "test-key-" + "".join(
             [random.choice(list("0123456789ABCDEF")) for i in range(20)]
         )
-        if self.ge_cloud_mode:
-            test_key: GeCloudIdentifier = self.key_class(
-                resource_type=GeCloudRESTResource.CHECKPOINT,
+        if self.cloud_mode:
+            test_key: GXCloudIdentifier = self.key_class(
+                resource_type=GXCloudRESTResource.CHECKPOINT,
                 ge_cloud_id=str(uuid.uuid4()),
             )
         else:
