@@ -2,13 +2,12 @@ import random
 import uuid
 from typing import Union
 
+import great_expectations.exceptions as gx_exceptions
+from great_expectations.data_context.cloud_constants import GXCloudRESTResource
 from great_expectations.data_context.store.configuration_store import ConfigurationStore
-from great_expectations.data_context.store.ge_cloud_store_backend import (
-    GeCloudRESTResource,
-)
 from great_expectations.data_context.types.resource_identifiers import (
-    ConfigurationIdentifier,
-    GeCloudIdentifier,
+    ConfigurationIdentifier,  # noqa: TCH001
+    GXCloudIdentifier,  # noqa: TCH001
 )
 from great_expectations.rule_based_profiler.config import RuleBasedProfilerConfig
 
@@ -18,7 +17,7 @@ class ProfilerStore(ConfigurationStore):
     A ProfilerStore manages Profilers for the DataContext.
     """
 
-    _configuration_class = RuleBasedProfilerConfig  # type: ignore[assignment]
+    _configuration_class = RuleBasedProfilerConfig
 
     def serialization_self_check(self, pretty_print: bool) -> None:
         """
@@ -32,10 +31,10 @@ class ProfilerStore(ConfigurationStore):
             rules={},
         )
 
-        test_key: Union[GeCloudIdentifier, ConfigurationIdentifier]
-        if self.ge_cloud_mode:
+        test_key: Union[GXCloudIdentifier, ConfigurationIdentifier]
+        if self.cloud_mode:
             test_key = self.key_class(  # type: ignore[assignment,call-arg]
-                resource_type=GeCloudRESTResource.PROFILER,
+                resource_type=GXCloudRESTResource.PROFILER,
                 ge_cloud_id=str(uuid.uuid4()),
             )
         else:
@@ -66,11 +65,27 @@ class ProfilerStore(ConfigurationStore):
 
     def ge_cloud_response_json_to_object_dict(self, response_json: dict) -> dict:
         """
-        This method takes full json response from GE cloud and outputs a dict appropriate for
-        deserialization into a GE object
+        This method takes full json response from GX cloud and outputs a dict appropriate for
+        deserialization into a GX object
         """
         ge_cloud_profiler_id = response_json["data"]["id"]
         profiler_config_dict = response_json["data"]["attributes"]["profiler"]
         profiler_config_dict["id"] = ge_cloud_profiler_id
 
         return profiler_config_dict
+
+    def add(self, key, value, **kwargs):
+        try:
+            super().add(key=key, value=value, **kwargs)
+        except gx_exceptions.StoreBackendError:
+            raise gx_exceptions.ProfilerError(
+                f"A Profiler named {value.name} already exists."
+            )
+
+    def update(self, key, value, **kwargs):
+        try:
+            super().update(key=key, value=value, **kwargs)
+        except gx_exceptions.StoreBackendError:
+            raise gx_exceptions.ProfilerNotFoundError(
+                f"Could not find an existing Profiler named {value.name}."
+            )
