@@ -2,8 +2,8 @@ import json
 import logging
 from typing import Any, List, Optional
 
-import great_expectations.exceptions as ge_exceptions
-from great_expectations.core.batch import BatchDefinition
+import great_expectations.exceptions as gx_exceptions
+from great_expectations.core.batch import BatchDefinition  # noqa: TCH001
 from great_expectations.datasource.data_connector.sorter import Sorter
 
 logger = logging.getLogger(__name__)
@@ -38,7 +38,7 @@ class DictionarySorter(Sorter):
         elif order_keys_by == "desc":
             reverse_keys = True
         else:
-            raise ge_exceptions.SorterError(
+            raise gx_exceptions.SorterError(
                 f'Illegal key sort order "{order_keys_by}" for attribute "{name}".'
             )
         self._reverse_keys = reverse_keys
