@@ -2,7 +2,7 @@ import json
 import logging
 from typing import Any
 
-from great_expectations.core.batch import BatchDefinition
+from great_expectations.core.batch import BatchDefinition  # noqa: TCH001
 from great_expectations.datasource.data_connector.sorter import Sorter
 
 logger = logging.getLogger(__name__)
