@@ -2,8 +2,8 @@ import json
 import logging
 from typing import Any
 
-import great_expectations.exceptions as ge_exceptions
-from great_expectations.core.batch import BatchDefinition
+import great_expectations.exceptions as gx_exceptions
+from great_expectations.core.batch import BatchDefinition  # noqa: TCH001
 from great_expectations.datasource.data_connector.sorter import Sorter
 from great_expectations.util import is_int, is_numeric
 
@@ -15,7 +15,7 @@ class NumericSorter(Sorter):
         batch_identifiers: dict = batch_definition.batch_identifiers
         batch_value: Any = batch_identifiers[self.name]
         if not is_numeric(value=batch_value):
-            raise ge_exceptions.SorterError(
+            raise gx_exceptions.SorterError(
                 # what is the identifying characteristic of batch_definition?
                 f"""BatchDefinition with IDDict "{self.name}" with value "{batch_value}" has value
 "{batch_value}" which cannot be part of numeric sort.
