@@ -5,11 +5,13 @@ import pickle
 import warnings
 from functools import partial
 from io import BytesIO
-from typing import Any, Callable, Iterable, Optional, Tuple, Union
+from typing import Any, Callable, Dict, Iterable, Optional, Tuple, Union, cast, overload
 
 import pandas as pd
+from typing_extensions import TypeAlias
 
-import great_expectations.exceptions as ge_exceptions
+import great_expectations.exceptions as gx_exceptions
+from great_expectations.core._docs_decorators import public_api
 from great_expectations.core.batch import BatchMarkers
 from great_expectations.core.batch_spec import (
     AzureBatchSpec,
@@ -19,9 +21,14 @@ from great_expectations.core.batch_spec import (
     RuntimeDataBatchSpec,
     S3BatchSpec,
 )
-from great_expectations.core.metric_domain_types import MetricDomainTypes
+from great_expectations.core.metric_domain_types import (
+    MetricDomainTypes,  # noqa: TCH001
+)
 from great_expectations.core.util import AzureUrl, GCSUrl, S3Url, sniff_s3_compression
 from great_expectations.execution_engine import ExecutionEngine
+from great_expectations.execution_engine.execution_engine import (
+    SplitDomainKwargs,  # noqa: TCH001
+)
 from great_expectations.execution_engine.pandas_batch_data import PandasBatchData
 from great_expectations.execution_engine.split_and_sample.pandas_data_sampler import (
     PandasDataSampler,
@@ -59,6 +66,7 @@ try:
 except ImportError:
     storage = None
     service_account = None
+    GoogleAPIError = None
     DefaultCredentialsError = None
     logger.debug(
         "Unable to load GCS connection object; install optional google dependency for support"
@@ -67,39 +75,43 @@ except ImportError:
 
 HASH_THRESHOLD = 1e9
 
+DataFrameFactoryFn: TypeAlias = Callable[..., pd.DataFrame]
 
+
+@public_api
 class PandasExecutionEngine(ExecutionEngine):
-    """
-PandasExecutionEngine instantiates the great_expectations Expectations API as a subclass of a pandas.DataFrame.
+    """PandasExecutionEngine instantiates the ExecutionEngine API to support computations using Pandas.
 
-For the full API reference, please see :func:`Dataset <great_expectations.data_asset.dataset.Dataset>`
+    Constructor builds a PandasExecutionEngine, using provided configuration options.
 
-Notes:
-    1. Samples and Subsets of PandaDataSet have ALL the expectations of the original \
-       data frame unless the user specifies the ``discard_subset_failing_expectations = True`` \
-       property on the original data frame.
-    2. Concatenations, joins, and merges of PandaDataSets contain NO expectations (since no autoinspection
-       is performed by default).
+    Args:
+        *args: Positional arguments for configuring PandasExecutionEngine
+        **kwargs: Keyword arguments for configuring PandasExecutionEngine
 
---ge-feature-maturity-info--
+    For example:
+    ```python
+        execution_engine: ExecutionEngine = PandasExecutionEngine(batch_data_dict={batch.id: batch.data})
+    ```
 
-    id: validation_engine_pandas
-    title: Validation Engine - Pandas
-    icon:
-    short_description: Use Pandas DataFrame to validate data
-    description: Use Pandas DataFrame to validate data
-    how_to_guide_url:
-    maturity: Production
-    maturity_details:
-        api_stability: Stable
-        implementation_completeness: Complete
-        unit_test_coverage: Complete
-        integration_infrastructure_test_coverage: N/A -> see relevant Datasource evaluation
-        documentation_completeness: Complete
-        bug_risk: Low
-        expectation_completeness: Complete
+    --ge-feature-maturity-info--
 
---ge-feature-maturity-info--
+        id: validation_engine_pandas
+        title: Validation Engine - Pandas
+        icon:
+        short_description: Use Pandas DataFrame to validate data
+        description: Use Pandas DataFrame to validate data
+        how_to_guide_url:
+        maturity: Production
+        maturity_details:
+            api_stability: Stable
+            implementation_completeness: Complete
+            unit_test_coverage: Complete
+            integration_infrastructure_test_coverage: N/A -> see relevant Datasource evaluation
+            documentation_completeness: Complete
+            bug_risk: Low
+            expectation_completeness: Complete
+
+    --ge-feature-maturity-info--
     """
 
     recognized_batch_spec_defaults = {
@@ -111,9 +123,9 @@ Notes:
         self.discard_subset_failing_expectations = kwargs.pop(
             "discard_subset_failing_expectations", False
         )
-        boto3_options: dict = kwargs.pop("boto3_options", {})
-        azure_options: dict = kwargs.pop("azure_options", {})
-        gcs_options: dict = kwargs.pop("gcs_options", {})
+        boto3_options: Dict[str, dict] = kwargs.pop("boto3_options", {})
+        azure_options: Dict[str, dict] = kwargs.pop("azure_options", {})
+        gcs_options: Dict[str, dict] = kwargs.pop("gcs_options", {})
 
         # Instantiate cloud provider clients as None at first.
         # They will be instantiated if/when passed cloud-specific in BatchSpec is passed in
@@ -184,18 +196,19 @@ Notes:
         super().configure_validator(validator)
         validator.expose_dataframe_methods = True
 
-    def load_batch_data(self, batch_id: str, batch_data: Any) -> None:
+    def load_batch_data(
+        self, batch_id: str, batch_data: Union[PandasBatchData, pd.DataFrame]
+    ) -> None:
         if isinstance(batch_data, pd.DataFrame):
             batch_data = PandasBatchData(self, batch_data)
-        elif isinstance(batch_data, PandasBatchData):
-            pass
-        else:
-            raise ge_exceptions.GreatExpectationsError(
+        elif not isinstance(batch_data, PandasBatchData):
+            raise gx_exceptions.GreatExpectationsError(
                 "PandasExecutionEngine requires batch data that is either a DataFrame or a PandasBatchData object"
             )
+
         super().load_batch_data(batch_id=batch_id, batch_data=batch_data)
 
-    def get_batch_data_and_markers(
+    def get_batch_data_and_markers(  # noqa: C901 - 22
         self, batch_spec: BatchSpec
     ) -> Tuple[Any, BatchMarkers]:  # batch_data
         # We need to build a batch_markers to be used in the dataframe
@@ -212,10 +225,11 @@ Notes:
             # batch_data != None is already checked when RuntimeDataBatchSpec is instantiated
             batch_data = batch_spec.batch_data
             if isinstance(batch_data, str):
-                raise ge_exceptions.ExecutionEngineError(
-                    f"""PandasExecutionEngine has been passed a string type batch_data, "{batch_data}", which is illegal.
-Please check your config."""
+                raise gx_exceptions.ExecutionEngineError(
+                    f"""PandasExecutionEngine has been passed a string type batch_data, "{batch_data}", which is illegal.  Please check your config.
+"""
                 )
+
             if isinstance(batch_spec.batch_data, pd.DataFrame):
                 df = batch_spec.batch_data
             elif isinstance(batch_spec.batch_data, PandasBatchData):
@@ -224,6 +238,7 @@ Please check your config."""
                 raise ValueError(
                     "RuntimeDataBatchSpec must provide a Pandas DataFrame or PandasBatchData object."
                 )
+
             batch_spec.batch_data = "PandasDataFrame"
 
         elif isinstance(batch_spec, S3BatchSpec):
@@ -231,7 +246,7 @@ Please check your config."""
                 self._instantiate_s3_client()
             # if we were not able to instantiate S3 client, then raise error
             if self._s3 is None:
-                raise ge_exceptions.ExecutionEngineError(
+                raise gx_exceptions.ExecutionEngineError(
                     """PandasExecutionEngine has been passed a S3BatchSpec,
                         but the ExecutionEngine does not have a boto3 client configured. Please check your config."""
                 )
@@ -247,13 +262,15 @@ Please check your config."""
                         reader_options["compression"] = inferred_compression_param
                 s3_object = s3_engine.get_object(Bucket=s3_url.bucket, Key=s3_url.key)
             except (ParamValidationError, ClientError) as error:
-                raise ge_exceptions.ExecutionEngineError(
+                raise gx_exceptions.ExecutionEngineError(
                     f"""PandasExecutionEngine encountered the following error while trying to read data from S3 Bucket: {error}"""
                 )
             logger.debug(
                 f"Fetching s3 object. Bucket: {s3_url.bucket} Key: {s3_url.key}"
             )
-            reader_fn = self._get_reader_fn(reader_method, s3_url.key)
+            reader_fn: DataFrameFactoryFn = self._get_reader_fn(
+                reader_method, s3_url.key
+            )
             buf = BytesIO(s3_object["Body"].read())
             buf.seek(0)
             df = reader_fn(buf, **reader_options)
@@ -263,14 +280,14 @@ Please check your config."""
                 self._instantiate_azure_client()
             # if we were not able to instantiate Azure client, then raise error
             if self._azure is None:
-                raise ge_exceptions.ExecutionEngineError(
+                raise gx_exceptions.ExecutionEngineError(
                     """PandasExecutionEngine has been passed a AzureBatchSpec,
                         but the ExecutionEngine does not have an Azure client configured. Please check your config."""
                 )
             azure_engine = self._azure
-            reader_method: str = batch_spec.reader_method
-            reader_options: dict = batch_spec.reader_options or {}
-            path: str = batch_spec.path
+            reader_method = batch_spec.reader_method
+            reader_options = batch_spec.reader_options or {}
+            path = batch_spec.path
             azure_url = AzureUrl(path)
             blob_client = azure_engine.get_blob_client(
                 container=azure_url.container, blob=azure_url.blob
@@ -289,14 +306,14 @@ Please check your config."""
                 self._instantiate_gcs_client()
             # if we were not able to instantiate GCS client, then raise error
             if self._gcs is None:
-                raise ge_exceptions.ExecutionEngineError(
+                raise gx_exceptions.ExecutionEngineError(
                     """PandasExecutionEngine has been passed a GCSBatchSpec,
                         but the ExecutionEngine does not have an GCS client configured. Please check your config."""
                 )
             gcs_engine = self._gcs
             gcs_url = GCSUrl(batch_spec.path)
-            reader_method: str = batch_spec.reader_method
-            reader_options: dict = batch_spec.reader_options or {}
+            reader_method = batch_spec.reader_method
+            reader_options = batch_spec.reader_options or {}
             try:
                 gcs_bucket = gcs_engine.get_bucket(gcs_url.bucket)
                 gcs_blob = gcs_bucket.blob(gcs_url.blob)
@@ -304,24 +321,27 @@ Please check your config."""
                     f"Fetching GCS blob. Bucket: {gcs_url.bucket} Blob: {gcs_url.blob}"
                 )
             except GoogleAPIError as error:
-                raise ge_exceptions.ExecutionEngineError(
-                    f"""PandasExecutionEngine encountered the following error while trying to read data from GCS Bucket: {error}"""
+                raise gx_exceptions.ExecutionEngineError(
+                    f"""PandasExecutionEngine encountered the following error while trying to read data from GCS \
+Bucket: {error}"""
                 )
             reader_fn = self._get_reader_fn(reader_method, gcs_url.blob)
             buf = BytesIO(gcs_blob.download_as_bytes())
             buf.seek(0)
             df = reader_fn(buf, **reader_options)
 
+        # Experimental datasources will go down this code path
         elif isinstance(batch_spec, PathBatchSpec):
-            reader_method: str = batch_spec.reader_method
-            reader_options: dict = batch_spec.reader_options
-            path: str = batch_spec.path
-            reader_fn: Callable = self._get_reader_fn(reader_method, path)
+            reader_method = batch_spec.reader_method
+            reader_options = batch_spec.reader_options
+            path = batch_spec.path
+            reader_fn = self._get_reader_fn(reader_method, path)
             df = reader_fn(path, **reader_options)
 
         else:
-            raise ge_exceptions.BatchSpecError(
-                f"batch_spec must be of type RuntimeDataBatchSpec, PathBatchSpec, S3BatchSpec, or AzureBatchSpec, not {batch_spec.__class__.__name__}"
+            raise gx_exceptions.BatchSpecError(
+                f"""batch_spec must be of type RuntimeDataBatchSpec, PathBatchSpec, S3BatchSpec, or AzureBatchSpec, \
+not {batch_spec.__class__.__name__}"""
             )
 
         df = self._apply_splitting_and_sampling_methods(batch_spec, df)
@@ -351,21 +371,21 @@ Please check your config."""
         return batch_data
 
     @property
-    def dataframe(self):
+    def dataframe(self) -> pd.DataFrame:
         """Tests whether or not a Batch has been loaded. If the loaded batch does not exist, raises a
         ValueError Exception
         """
         # Changed to is None because was breaking prior
-        if self.active_batch_data is None:
+        if self.batch_manager.active_batch_data is None:
             raise ValueError(
                 "Batch has not been loaded - please run load_batch_data() to load a batch."
             )
 
-        return self.active_batch_data.dataframe
+        return cast(PandasBatchData, self.batch_manager.active_batch_data).dataframe
 
     # NOTE Abe 20201105: Any reason this shouldn't be a private method?
     @staticmethod
-    def guess_reader_method_from_path(path):
+    def guess_reader_method_from_path(path: str):
         """Helper method for deciding which reader to use to read in a certain path.
 
         Args:
@@ -375,6 +395,7 @@ Please check your config."""
             ReaderMethod to use for the filepath
 
         """
+        path = path.lower()
         if path.endswith(".csv") or path.endswith(".tsv"):
             return {"reader_method": "read_csv"}
         elif (
@@ -398,11 +419,25 @@ Please check your config."""
             return {"reader_method": "read_sas"}
 
         else:
-            raise ge_exceptions.ExecutionEngineError(
+            raise gx_exceptions.ExecutionEngineError(
                 f'Unable to determine reader method from path: "{path}".'
             )
 
-    def _get_reader_fn(self, reader_method=None, path=None):
+    @overload
+    def _get_reader_fn(
+        self, reader_method: str = ..., path: Optional[str] = ...
+    ) -> DataFrameFactoryFn:
+        ...
+
+    @overload
+    def _get_reader_fn(
+        self, reader_method: None = ..., path: str = ...
+    ) -> DataFrameFactoryFn:
+        ...
+
+    def _get_reader_fn(
+        self, reader_method: Optional[str] = None, path: Optional[str] = None
+    ) -> DataFrameFactoryFn:
         """Static helper for parsing reader types. If reader_method is not provided, path will be used to guess the
         correct reader_method.
 
@@ -415,13 +450,13 @@ Please check your config."""
 
         """
         if reader_method is None and path is None:
-            raise ge_exceptions.ExecutionEngineError(
+            raise gx_exceptions.ExecutionEngineError(
                 "Unable to determine pandas reader function without reader_method or path."
             )
 
         reader_options = {}
         if reader_method is None:
-            path_guess = self.guess_reader_method_from_path(path)
+            path_guess = self.guess_reader_method_from_path(path)  # type: ignore[arg-type] # see overload
             reader_method = path_guess["reader_method"]
             reader_options = path_guess.get(
                 "reader_options"
@@ -433,23 +468,30 @@ Please check your config."""
                 reader_fn = partial(reader_fn, **reader_options)
             return reader_fn
         except AttributeError:
-            raise ge_exceptions.ExecutionEngineError(
+            raise gx_exceptions.ExecutionEngineError(
                 f'Unable to find reader_method "{reader_method}" in pandas.'
             )
 
-    def get_domain_records(
+    def resolve_metric_bundle(
+        self, metric_fn_bundle
+    ) -> Dict[Tuple[str, str, str], Any]:
+        """Resolve a bundle of metrics with the same compute Domain as part of a single trip to the compute engine."""
+        return (
+            {}
+        )  # This is NO-OP for "PandasExecutionEngine" (no bundling for direct execution computational backend).
+
+    @public_api
+    def get_domain_records(  # noqa: C901 - 17
         self,
         domain_kwargs: dict,
     ) -> pd.DataFrame:
-        """
-        Uses the given domain kwargs (which include row_condition, condition_parser, and ignore_row_if directives) to
-        obtain and/or query a batch. Returns in the format of a Pandas DataFrame.
+        """Uses the given Domain kwargs (which include row_condition, condition_parser, and ignore_row_if directives) to obtain and/or query a Batch of data.
 
         Args:
-            domain_kwargs (dict) - A dictionary consisting of the domain kwargs specifying which data to obtain
+            domain_kwargs (dict) - A dictionary consisting of the Domain kwargs specifying which data to obtain
 
         Returns:
-            A DataFrame (the data on which to compute)
+            A DataFrame (the data on which to compute returned in the format of a Pandas DataFrame)
         """
         table = domain_kwargs.get("table", None)
         if table:
@@ -460,17 +502,21 @@ Please check your config."""
         batch_id = domain_kwargs.get("batch_id")
         if batch_id is None:
             # We allow no batch id specified if there is only one batch
-            if self.active_batch_data_id is not None:
-                data = self.active_batch_data.dataframe
+            if self.batch_manager.active_batch_data_id is not None:
+                data = cast(
+                    PandasBatchData, self.batch_manager.active_batch_data
+                ).dataframe
             else:
-                raise ge_exceptions.ValidationError(
+                raise gx_exceptions.ValidationError(
                     "No batch is specified, but could not identify a loaded batch."
                 )
         else:
-            if batch_id in self.loaded_batch_data_dict:
-                data = self.loaded_batch_data_dict[batch_id].dataframe
+            if batch_id in self.batch_manager.batch_data_cache:
+                data = cast(
+                    PandasBatchData, self.batch_manager.batch_data_cache[batch_id]
+                ).dataframe
             else:
-                raise ge_exceptions.ValidationError(
+                raise gx_exceptions.ValidationError(
                     f"Unable to find batch with batch_id {batch_id}"
                 )
 
@@ -525,7 +571,8 @@ Please check your config."""
                     # deprecated-v0.13.29
                     warnings.warn(
                         f"""The correct "no-action" value of the "ignore_row_if" directive for the column pair case is \
-"neither" (the use of "{ignore_row_if}" is deprecated as of v0.13.29 and will be removed in v0.16).  Please use "neither" instead.
+"neither" (the use of "{ignore_row_if}" is deprecated as of v0.13.29 and will be removed in v0.16).  \
+Please use "neither" instead.
 """,
                         DeprecationWarning,
                     )
@@ -558,42 +605,43 @@ Please check your config."""
 
         return data
 
+    @public_api
     def get_compute_domain(
         self,
         domain_kwargs: dict,
         domain_type: Union[str, MetricDomainTypes],
         accessor_keys: Optional[Iterable[str]] = None,
     ) -> Tuple[pd.DataFrame, dict, dict]:
-        """
-        Uses the given domain kwargs (which include row_condition, condition_parser, and ignore_row_if directives) to
-        obtain and/or query a batch.  Returns in the format of a Pandas DataFrame. If the domain is a single column,
-        this is added to 'accessor domain kwargs' and used for later access
+        """Uses the given Domain kwargs (which include row_condition, condition_parser, and ignore_row_if directives) to obtain and/or query a batch.
+
+        Returns in the format of a Pandas DataFrame along with Domain arguments required for computing.  If the Domain \
+        is a single column, this is added to 'accessor Domain kwargs' and used for later access.
 
         Args:
-            domain_kwargs (dict) - A dictionary consisting of the domain kwargs specifying which data to obtain
-            domain_type (str or MetricDomainTypes) - an Enum value indicating which metric domain the user would
-            like to be using, or a corresponding string value representing it. String types include "column",
-            "column_pair", "table", and "other".  Enum types include capitalized versions of these from the
-            class MetricDomainTypes.
-            accessor_keys (str iterable) - keys that are part of the compute domain but should be ignored when
-            describing the domain and simply transferred with their associated values into accessor_domain_kwargs.
+            domain_kwargs (dict): a dictionary consisting of the Domain kwargs specifying which data to obtain
+            domain_type (str or MetricDomainTypes): an Enum value indicating which metric Domain the user would like \
+            to be using, or a corresponding string value representing it.  String types include "column", \
+            "column_pair", "table", and "other".  Enum types include capitalized versions of these from the class \
+            MetricDomainTypes.
+            accessor_keys (str iterable): keys that are part of the compute Domain but should be ignored when \
+            describing the Domain and simply transferred with their associated values into accessor_domain_kwargs.
 
         Returns:
             A tuple including:
               - a DataFrame (the data on which to compute)
               - a dictionary of compute_domain_kwargs, describing the DataFrame
               - a dictionary of accessor_domain_kwargs, describing any accessors needed to
-                identify the domain within the compute domain
+                identify the Domain within the compute domain
         """
-        data = self.get_domain_records(domain_kwargs)
-
-        table = domain_kwargs.get("table", None)
+        table: str = domain_kwargs.get("table", None)
         if table:
             raise ValueError(
                 "PandasExecutionEngine does not currently support multiple named tables."
             )
 
-        split_domain_kwargs = self._split_domain_kwargs(
+        data: pd.DataFrame = self.get_domain_records(domain_kwargs=domain_kwargs)
+
+        split_domain_kwargs: SplitDomainKwargs = self._split_domain_kwargs(
             domain_kwargs, domain_type, accessor_keys
         )
 
