@@ -14,15 +14,17 @@ not by itself.
             split_query_or_clause = splitter()
 """
 
-from typing import List, Union
+from __future__ import annotations
 
-import great_expectations.exceptions as ge_exceptions
+from typing import TYPE_CHECKING, List, Union
+
+import great_expectations.exceptions as gx_exceptions
 from great_expectations.execution_engine.split_and_sample.data_splitter import (
     DataSplitter,
     DatePart,
     SplitterMethod,
 )
-from great_expectations.execution_engine.sqlalchemy_dialect import GESqlDialect
+from great_expectations.execution_engine.sqlalchemy_dialect import GXSqlDialect
 
 try:
     import sqlalchemy as sa
@@ -42,6 +44,14 @@ except ImportError:
     Label = None
     concat = None
 
+if TYPE_CHECKING:
+    import sqlalchemy as sa  # noqa: TCH004
+    from sqlalchemy.sql.expression import Cast, ColumnOperators
+
+    from great_expectations.execution_engine.sqlalchemy_execution_engine import (
+        SqlAlchemyExecutionEngine,
+    )
+
 
 class SqlAlchemyDataSplitter(DataSplitter):
     """Methods for splitting data accessible via SqlAlchemyExecutionEngine.
@@ -166,7 +176,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
         """
         self._validate_date_parts(date_parts)
 
-        date_parts: List[DatePart] = self._convert_date_parts(date_parts)
+        date_parts = self._convert_date_parts(date_parts)
 
         column_batch_identifiers: dict = batch_identifiers[column_name]
 
@@ -205,7 +215,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
         date_format_string: str = "%Y-%m-%d",
     ) -> bool:
         """Convert the values in the named column to the given date_format, and split on that"""
-        if self._dialect == GESqlDialect.SQLITE:
+        if self._dialect == GXSqlDialect.SQLITE:
             return (
                 sa.func.strftime(
                     date_format_string,
@@ -225,7 +235,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
         batch_identifiers: dict,
     ) -> bool:
         """Divide the values in the named column by `divisor`, and split on that"""
-        if self._dialect == GESqlDialect.SQLITE:
+        if self._dialect == GXSqlDialect.SQLITE:
             return (
                 sa.cast(
                     (sa.cast(sa.column(column_name), sa.Integer) / divisor), sa.Integer
@@ -233,7 +243,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
                 == batch_identifiers[column_name]
             )
 
-        if self._dialect == GESqlDialect.MYSQL:
+        if self._dialect == GXSqlDialect.MYSQL:
             return (
                 sa.cast(
                     sa.func.truncate(
@@ -244,7 +254,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
                 == batch_identifiers[column_name]
             )
 
-        if self._dialect == GESqlDialect.MSSQL:
+        if self._dialect == GXSqlDialect.MSSQL:
             return (
                 sa.cast(
                     sa.func.round(
@@ -255,7 +265,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
                 == batch_identifiers[column_name]
             )
 
-        if self._dialect == GESqlDialect.AWSATHENA:
+        if self._dialect == GXSqlDialect.AWSATHENA:
             return (
                 sa.cast(
                     sa.func.truncate(
@@ -284,8 +294,8 @@ class SqlAlchemyDataSplitter(DataSplitter):
     ) -> bool:
         """Divide the values in the named column by `mod`, and split on that"""
         if self._dialect in [
-            GESqlDialect.SQLITE,
-            GESqlDialect.MSSQL,
+            GXSqlDialect.SQLITE,
+            GXSqlDialect.MSSQL,
         ]:
             return (
                 sa.cast(sa.column(column_name), sa.Integer) % mod
@@ -318,7 +328,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
         batch_identifiers: dict,
     ) -> bool:
         """Split on the hashed value of the named column"""
-        if self._dialect == GESqlDialect.SQLITE:
+        if self._dialect == GXSqlDialect.SQLITE:
             return (
                 sa.func.md5(sa.cast(sa.column(column_name), sa.VARCHAR), hash_digits)
                 == batch_identifiers[column_name]
@@ -330,7 +340,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
 
     def get_data_for_batch_identifiers(
         self,
-        execution_engine: "SqlAlchemyExecutionEngine",  # noqa: F821
+        execution_engine: SqlAlchemyExecutionEngine,
         table_name: str,
         splitter_method_name: str,
         splitter_kwargs: dict,
@@ -351,21 +361,22 @@ class SqlAlchemyDataSplitter(DataSplitter):
         processed_splitter_method_name: str = self._get_splitter_method_name(
             splitter_method_name
         )
+        batch_identifiers_list: List[dict]
         if self._is_datetime_splitter(processed_splitter_method_name):
             splitter_fn_name: str = self.DATETIME_SPLITTER_METHOD_TO_GET_UNIQUE_BATCH_IDENTIFIERS_METHOD_MAPPING[
                 processed_splitter_method_name
             ]
-            batch_identifiers_list: List[dict] = getattr(self, splitter_fn_name)(
+            batch_identifiers_list = getattr(self, splitter_fn_name)(
                 execution_engine, table_name, **splitter_kwargs
             )
         else:
-            batch_identifiers_list: List[
-                dict
-            ] = self.get_data_for_batch_identifiers_for_non_date_part_splitters(
-                execution_engine,
-                table_name,
-                processed_splitter_method_name,
-                splitter_kwargs,
+            batch_identifiers_list = (
+                self.get_data_for_batch_identifiers_for_non_date_part_splitters(
+                    execution_engine,
+                    table_name,
+                    processed_splitter_method_name,
+                    splitter_kwargs,
+                )
             )
 
         return batch_identifiers_list
@@ -385,7 +396,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
 
     def get_data_for_batch_identifiers_year(
         self,
-        execution_engine: "SqlAlchemyExecutionEngine",  # noqa: F821
+        execution_engine: SqlAlchemyExecutionEngine,
         table_name: str,
         column_name: str,
     ) -> List[dict]:
@@ -411,7 +422,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
 
     def get_data_for_batch_identifiers_year_and_month(
         self,
-        execution_engine: "SqlAlchemyExecutionEngine",  # noqa: F821
+        execution_engine: SqlAlchemyExecutionEngine,
         table_name: str,
         column_name: str,
     ) -> List[dict]:
@@ -437,7 +448,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
 
     def get_data_for_batch_identifiers_year_and_month_and_day(
         self,
-        execution_engine: "SqlAlchemyExecutionEngine",  # noqa: F821
+        execution_engine: SqlAlchemyExecutionEngine,
         table_name: str,
         column_name: str,
     ) -> List[dict]:
@@ -483,16 +494,18 @@ class SqlAlchemyDataSplitter(DataSplitter):
         """
         self._validate_date_parts(date_parts)
 
-        date_parts: List[DatePart] = self._convert_date_parts(date_parts)
+        date_parts = self._convert_date_parts(date_parts)
 
         # NOTE: AJB 20220414 concatenating to find distinct values to support all dialects.
         # There are more performant dialect-specific methods that can be implemented in
         # future improvements.
         # NOTE: AJB 20220511 for awsathena we need to cast extracted date parts
         # to string first before concatenating them.
+        concat_clause: list[Label]
+        concat_date_parts: Cast | ColumnOperators
         if len(date_parts) == 1:
             # MSSql does not accept single item concatenation
-            concat_clause: List[Label] = [
+            concat_clause = [
                 sa.func.distinct(
                     sa.func.extract(date_parts[0].value, sa.column(column_name)).label(
                         date_parts[0].value
@@ -504,7 +517,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
             # NOTE: <Alex>6/29/2022</Alex>
             Certain SQLAlchemy-compliant backends (e.g., Amazon Redshift, SQLite) allow only binary operators for "CONCAT".
             """
-            if self._dialect == GESqlDialect.SQLITE:
+            if self._dialect == GXSqlDialect.SQLITE:
                 concat_date_parts = sa.cast(
                     sa.func.extract(date_parts[0].value, sa.column(column_name)),
                     sa.String,
@@ -519,11 +532,11 @@ class SqlAlchemyDataSplitter(DataSplitter):
                         )
                     )
 
-                concat_clause: List[Label] = [
+                concat_clause = [
                     sa.func.distinct(concat_date_parts).label("concat_distinct_values"),
                 ]
             else:
-                concat_date_parts: concat = sa.func.concat(
+                concat_date_parts = sa.func.concat(
                     "",
                     sa.cast(
                         sa.func.extract(date_parts[0].value, sa.column(column_name)),
@@ -531,7 +544,6 @@ class SqlAlchemyDataSplitter(DataSplitter):
                     ),
                 )
 
-                date_part: DatePart
                 for date_part in date_parts[1:]:
                     concat_date_parts = sa.func.concat(
                         concat_date_parts,
@@ -541,7 +553,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
                         ),
                     )
 
-                concat_clause: List[Label] = [
+                concat_clause = [
                     sa.func.distinct(concat_date_parts).label("concat_distinct_values"),
                 ]
 
@@ -559,7 +571,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
 
     def get_data_for_batch_identifiers_for_split_on_date_parts(
         self,
-        execution_engine: "SqlAlchemyExecutionEngine",  # noqa: F821
+        execution_engine: SqlAlchemyExecutionEngine,
         table_name: str,
         column_name: str,
         date_parts: Union[List[DatePart], List[str]],
@@ -596,8 +608,8 @@ class SqlAlchemyDataSplitter(DataSplitter):
 
     @staticmethod
     def _execute_split_query(
-        execution_engine: "SqlAlchemyExecutionEngine",  # noqa: F821
-        split_query: Selectable,  # noqa: F821
+        execution_engine: SqlAlchemyExecutionEngine,
+        split_query: Selectable,
     ) -> List[LegacyRow]:
         """Use the provided execution engine to run the split query and fetch all of the results.
 
@@ -611,7 +623,10 @@ class SqlAlchemyDataSplitter(DataSplitter):
         return execution_engine.execute_split_query(split_query)
 
     def _get_params_for_batch_identifiers_from_date_part_splitter(
-        self, column_name: str, result: List[LegacyRow], date_parts: List[DatePart]
+        self,
+        column_name: str,
+        result: List[LegacyRow],
+        date_parts: List[DatePart] | List[str],
     ) -> List[dict]:
         """Get parameters used to build BatchIdentifiers from the results of a get_data_for_batch_identifiers_for_split_on_date_parts
 
@@ -624,7 +639,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
         Returns:
             List of dicts of the form [{column_name: {date_part_name: date_part_value}}]
         """
-        date_parts: List[DatePart] = self._convert_date_parts(date_parts)
+        date_parts = self._convert_date_parts(date_parts)
 
         data_for_batch_identifiers: List[dict] = [
             {
@@ -650,7 +665,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
 
     def get_data_for_batch_identifiers_for_non_date_part_splitters(
         self,
-        execution_engine: "SqlAlchemyExecutionEngine",  # noqa: F821
+        execution_engine: SqlAlchemyExecutionEngine,
         table_name: str,
         splitter_method_name: str,
         splitter_kwargs: dict,
@@ -703,8 +718,8 @@ class SqlAlchemyDataSplitter(DataSplitter):
             return self.SPLITTER_METHOD_TO_GET_UNIQUE_BATCH_IDENTIFIERS_METHOD_MAPPING[
                 processed_splitter_method_name
             ]
-        except ValueError as e:
-            raise ge_exceptions.InvalidConfigError(
+        except ValueError:
+            raise gx_exceptions.InvalidConfigError(
                 f"Please provide a supported splitter method name, you provided: {splitter_method_name}"
             )
 
@@ -777,7 +792,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
         divisor: int,
     ) -> Selectable:
         """Divide the values in the named column by `divisor`, and split on that"""
-        if self._dialect == GESqlDialect.SQLITE:
+        if self._dialect == GXSqlDialect.SQLITE:
             return sa.select(
                 [
                     sa.func.distinct(
@@ -789,7 +804,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
                 ]
             ).select_from(sa.text(table_name))
 
-        if self._dialect == GESqlDialect.MYSQL:
+        if self._dialect == GXSqlDialect.MYSQL:
             return sa.select(
                 [
                     sa.func.distinct(
@@ -804,7 +819,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
                 ]
             ).select_from(sa.text(table_name))
 
-        if self._dialect == GESqlDialect.MSSQL:
+        if self._dialect == GXSqlDialect.MSSQL:
             return sa.select(
                 [
                     sa.func.distinct(
@@ -820,7 +835,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
                 ]
             ).select_from(sa.text(table_name))
 
-        if self._dialect == GESqlDialect.AWSATHENA:
+        if self._dialect == GXSqlDialect.AWSATHENA:
             return sa.select(
                 [
                     sa.func.distinct(
@@ -855,8 +870,8 @@ class SqlAlchemyDataSplitter(DataSplitter):
     ) -> Selectable:
         """Divide the values in the named column by `mod`, and split on that"""
         if self._dialect in [
-            GESqlDialect.SQLITE,
-            GESqlDialect.MSSQL,
+            GXSqlDialect.SQLITE,
+            GXSqlDialect.MSSQL,
         ]:
             return sa.select(
                 [sa.func.distinct(sa.cast(sa.column(column_name), sa.Integer) % mod)]
@@ -889,7 +904,7 @@ class SqlAlchemyDataSplitter(DataSplitter):
         hash_digits: int,
     ) -> Selectable:
         """Note: this method is experimental. It does not work with all SQL dialects."""
-        if self._dialect == GESqlDialect.SQLITE:
+        if self._dialect == GXSqlDialect.SQLITE:
             return sa.select(
                 [
                     sa.func.distinct(
