@@ -25,7 +25,7 @@ class ColumnMean(ColumnAggregateMetricProvider):
     def _sqlalchemy(cls, column, **kwargs):
         """SqlAlchemy Mean Implementation"""
         # column * 1.0 needed for correct calculation of avg in MSSQL
-        return sa.func.avg(column * 1.0)
+        return sa.func.avg(1.0 * column)
 
     @column_aggregate_partial(engine=SparkDFExecutionEngine)
     def _spark(cls, column, _table, _column_name, **kwargs):
