@@ -1,6 +1,9 @@
 from typing import Optional
 
-from great_expectations.core import ExpectationConfiguration
+from great_expectations.core import ExpectationConfiguration  # noqa: TCH001
+from great_expectations.core.metric_function_types import (
+    MetricPartialFunctionTypeSuffixes,
+)
 from great_expectations.execution_engine import (
     ExecutionEngine,
     PandasExecutionEngine,
@@ -23,17 +26,23 @@ class ColumnValuesValueLengthEquals(ColumnMapMetricProvider):
 
     @column_condition_partial(engine=PandasExecutionEngine)
     def _pandas(cls, column, value, _metrics, **kwargs):
-        column_lengths, _, _ = _metrics.get("column_values.value_length.map")
+        column_lengths, _, _ = _metrics.get(
+            f"column_values.value_length.{MetricPartialFunctionTypeSuffixes.MAP.value}"
+        )
         return column_lengths == value
 
     @column_condition_partial(engine=SqlAlchemyExecutionEngine)
     def _sqlalchemy(cls, column, value, _metrics, **kwargs):
-        column_lengths, _, _ = _metrics.get("column_values.value_length.map")
+        column_lengths, _, _ = _metrics.get(
+            f"column_values.value_length.{MetricPartialFunctionTypeSuffixes.MAP.value}"
+        )
         return column_lengths == value
 
     @column_condition_partial(engine=SparkDFExecutionEngine)
     def _spark(cls, column, value, _metrics, **kwargs):
-        column_lengths, _, _ = _metrics.get("column_values.value_length.map")
+        column_lengths, _, _ = _metrics.get(
+            f"column_values.value_length.{MetricPartialFunctionTypeSuffixes.MAP.value}"
+        )
         return column_lengths == value
 
     @classmethod
@@ -51,9 +60,14 @@ class ColumnValuesValueLengthEquals(ColumnMapMetricProvider):
             runtime_configuration=runtime_configuration,
         )
 
-        if metric.metric_name == "column_values.value_length.equals.condition":
-            dependencies["column_values.value_length.map"] = MetricConfiguration(
-                metric_name="column_values.value_length.map",
+        if (
+            metric.metric_name
+            == f"column_values.value_length.equals.{MetricPartialFunctionTypeSuffixes.CONDITION.value}"
+        ):
+            dependencies[
+                f"column_values.value_length.{MetricPartialFunctionTypeSuffixes.MAP.value}"
+            ] = MetricConfiguration(
+                metric_name=f"column_values.value_length.{MetricPartialFunctionTypeSuffixes.MAP.value}",
                 metric_domain_kwargs=metric.metric_domain_kwargs,
             )
 
@@ -92,9 +106,11 @@ class ColumnValuesValueLength(ColumnMapMetricProvider):
         max_value=None,
         strict_min=None,
         strict_max=None,
-        **kwargs
+        **kwargs,
     ):
-        column_lengths, _, _ = _metrics.get("column_values.value_length.map")
+        column_lengths, _, _ = _metrics.get(
+            f"column_values.value_length.{MetricPartialFunctionTypeSuffixes.MAP.value}"
+        )
 
         metric_series = None
         if min_value is not None and max_value is not None:
@@ -139,9 +155,11 @@ class ColumnValuesValueLength(ColumnMapMetricProvider):
         max_value=None,
         strict_min=None,
         strict_max=None,
-        **kwargs
+        **kwargs,
     ):
-        column_lengths, _, _ = _metrics.get("column_values.value_length.map")
+        column_lengths, _, _ = _metrics.get(
+            f"column_values.value_length.{MetricPartialFunctionTypeSuffixes.MAP.value}"
+        )
 
         if min_value is None and max_value is None:
             raise ValueError("min_value and max_value cannot both be None")
@@ -178,9 +196,11 @@ class ColumnValuesValueLength(ColumnMapMetricProvider):
         max_value=None,
         strict_min=None,
         strict_max=None,
-        **kwargs
+        **kwargs,
     ):
-        column_lengths, _, _ = _metrics.get("column_values.value_length.map")
+        column_lengths, _, _ = _metrics.get(
+            f"column_values.value_length.{MetricPartialFunctionTypeSuffixes.MAP.value}"
+        )
 
         if min_value is None and max_value is None:
             raise ValueError("min_value and max_value cannot both be None")
@@ -220,9 +240,14 @@ class ColumnValuesValueLength(ColumnMapMetricProvider):
             runtime_configuration=runtime_configuration,
         )
 
-        if metric.metric_name == "column_values.value_length.between.condition":
-            dependencies["column_values.value_length.map"] = MetricConfiguration(
-                metric_name="column_values.value_length.map",
+        if (
+            metric.metric_name
+            == f"column_values.value_length.between.{MetricPartialFunctionTypeSuffixes.CONDITION.value}"
+        ):
+            dependencies[
+                f"column_values.value_length.{MetricPartialFunctionTypeSuffixes.MAP.value}"
+            ] = MetricConfiguration(
+                metric_name=f"column_values.value_length.{MetricPartialFunctionTypeSuffixes.MAP.value}",
                 metric_domain_kwargs=metric.metric_domain_kwargs,
             )
 
