@@ -32,7 +32,8 @@ class ColumnPairValuesEqual(ColumnPairMapMetricProvider):
     @column_pair_condition_partial(engine=SqlAlchemyExecutionEngine)
     def _sqlalchemy(cls, column_A, column_B, **kwargs):
         row_wise_cond = sa.and_(
-            column_A == column_B, sa.not_(sa.or_(column_A == None, column_B == None))
+            column_A == column_B,
+            sa.not_(sa.or_(column_A == None, column_B == None)),  # noqa: E711
         )
         return row_wise_cond
 
