@@ -1,5 +1,10 @@
+from __future__ import annotations
+
 import enum
+import operator
 from dataclasses import dataclass
+from string import punctuation
+from typing import TYPE_CHECKING
 
 from pyparsing import (
     CaselessLiteral,
@@ -13,7 +18,7 @@ from pyparsing import (
     alphas,
 )
 
-import great_expectations.exceptions as ge_exceptions
+import great_expectations.exceptions as gx_exceptions
 from great_expectations.core.util import convert_to_json_serializable
 from great_expectations.types import SerializableDictDot
 
@@ -27,8 +32,12 @@ try:
 except ImportError:
     sa = None
 
+if TYPE_CHECKING:
+    import sqlalchemy as sa  # noqa: TCH004
+    from sqlalchemy.sql.expression import ColumnElement
 
-def _set_notnull(s, l, t) -> None:
+
+def _set_notnull(s, l, t) -> None:  # noqa: E741 # ambiguous name `l`
     t["notnull"] = True
 
 
@@ -42,11 +51,14 @@ lt = Literal("<")
 ge = Literal(">=")
 le = Literal("<=")
 eq = Literal("==")
-ops = (gt ^ lt ^ ge ^ le ^ eq).setResultsName("op")
+ne = Literal("!=")
+ops = (gt ^ lt ^ ge ^ le ^ eq ^ ne).setResultsName("op")
 fnumber = Regex(r"[+-]?\d+(?:\.\d*)?(?:[eE][+-]?\d+)?").setResultsName("fnumber")
-condition_value = Suppress('"') + Word(f"{alphanums}._").setResultsName(
+punctuation_without_apostrophe = punctuation.replace('"', "").replace("'", "")
+condition_value_chars = alphanums + punctuation_without_apostrophe
+condition_value = Suppress('"') + Word(f"{condition_value_chars}._").setResultsName(
     "condition_value"
-) + Suppress('"') ^ Suppress("'") + Word(f"{alphanums}._").setResultsName(
+) + Suppress('"') ^ Suppress("'") + Word(f"{condition_value_chars}._").setResultsName(
     "condition_value"
 ) + Suppress(
     "'"
@@ -57,7 +69,7 @@ condition = (column_name + not_null).setParseAction(_set_notnull) ^ (
 )
 
 
-class ConditionParserError(ge_exceptions.GreatExpectationsError):
+class ConditionParserError(gx_exceptions.GreatExpectationsError):
     pass
 
 
@@ -114,7 +126,9 @@ def _parse_great_expectations_condition(row_condition: str):
 
 
 # noinspection PyUnresolvedReferences
-def parse_condition_to_spark(row_condition: str) -> "pyspark.sql.Column":
+def parse_condition_to_spark(
+    row_condition: str,
+) -> "pyspark.sql.Column":  # noqa: F821 # TODO: pyspark typing
     parsed = _parse_great_expectations_condition(row_condition)
     column = parsed["column"]
     if "condition_value" in parsed:
@@ -146,34 +160,30 @@ def parse_condition_to_spark(row_condition: str) -> "pyspark.sql.Column":
         raise ConditionParserError(f"unrecognized column condition: {row_condition}")
 
 
-def parse_condition_to_sqlalchemy(
-    row_condition: str,
-) -> "sqlalchemy.sql.expression.ColumnElement":
+def generate_condition_by_operator(column, op, value):
+    operators = {
+        "==": operator.eq,
+        "<": operator.lt,
+        ">": operator.gt,
+        ">=": operator.ge,
+        "<=": operator.le,
+        "!=": operator.ne,
+    }
+    return operators[op](column, value)
+
+
+def parse_condition_to_sqlalchemy(row_condition: str) -> ColumnElement:
     parsed = _parse_great_expectations_condition(row_condition)
     column = parsed["column"]
     if "condition_value" in parsed:
-        if parsed["op"] == "==":
-            return sa.column(column) == parsed["condition_value"]
-        else:
-            raise ConditionParserError(
-                f"Invalid operator: {parsed['op']} for string literal spark condition."
-            )
+        return generate_condition_by_operator(
+            sa.column(column), parsed["op"], parsed["condition_value"]
+        )
     elif "fnumber" in parsed:
-        try:
-            num = int(parsed["fnumber"])
-        except ValueError:
-            num = float(parsed["fnumber"])
-        op = parsed["op"]
-        if op == ">":
-            return sa.column(column) > num
-        elif op == "<":
-            return sa.column(column) < num
-        elif op == ">=":
-            return sa.column(column) >= num
-        elif op == "<=":
-            return sa.column(column) <= num
-        elif op == "==":
-            return sa.column(column) == num
+        number_value = parsed["fnumber"]
+        num = int(number_value) if number_value.isdigit() else float(number_value)
+        return generate_condition_by_operator(sa.column(column), parsed["op"], num)
+
     elif "notnull" in parsed and parsed["notnull"] is True:
         return sa.not_(sa.column(column).is_(None))
     else:
