@@ -4,10 +4,12 @@ from typing import Any, Dict, List, Optional, Union
 
 import jsonschema
 
+from great_expectations.core._docs_decorators import public_api
 from great_expectations.core.expectation_configuration import ExpectationConfiguration
 from great_expectations.core.expectation_suite import ExpectationSuite
 from great_expectations.core.profiler_types_mapping import ProfilerTypeMapping
 from great_expectations.profile.base import Profiler
+from great_expectations.render.renderer_configuration import MetaNotesFormat
 
 logger = logging.getLogger(__name__)
 
@@ -44,12 +46,29 @@ class JsonSchemaProfiler(Profiler):
         JsonSchemaTypes.INTEGER.value: ProfilerTypeMapping.INT_TYPE_NAMES,
         JsonSchemaTypes.NUMBER.value: ProfilerTypeMapping.FLOAT_TYPE_NAMES,
         JsonSchemaTypes.BOOLEAN.value: ProfilerTypeMapping.BOOLEAN_TYPE_NAMES,
+        JsonSchemaTypes.OBJECT.value: ProfilerTypeMapping.OBJECT_TYPE_NAMES,
     }
 
     def __init__(self, configuration: Optional[dict] = None) -> None:
         super().__init__(configuration)
 
+    @public_api
     def validate(self, schema: dict) -> bool:  # type: ignore[override]
+        """
+        Check if `schema` can be profiled.
+
+        Args:
+            schema: A `dict` representing a JSON Schema.
+
+        Returns:
+            True if `schema` can be profiled.
+
+        Raises:
+            TypeError: If `schema` is not a `dict`.
+            KeyError: If `schema` does not have a top level `type` key.
+            TypeError: If the top level `type` is not a JSON object.
+        """
+
         if not isinstance(schema, dict):
             raise TypeError(
                 f"This profiler requires a schema of type dict and was passed a {type(schema)}"
@@ -66,7 +85,9 @@ class JsonSchemaProfiler(Profiler):
         validator.check_schema(schema)
         return True
 
-    def _profile(self, schema: Dict, suite_name: str = None) -> ExpectationSuite:
+    def _profile(
+        self, schema: Dict, suite_name: Optional[str] = None
+    ) -> ExpectationSuite:
         if not suite_name:
             raise ValueError("Please provide a suite name when using this profiler.")
         expectations = []
@@ -107,12 +128,12 @@ class JsonSchemaProfiler(Profiler):
         if description:
             meta = {
                 "notes": {
-                    "format": "markdown",
+                    "format": MetaNotesFormat.MARKDOWN,
                     "content": [f"### Description:\n{description}"],
                 }
             }
         suite = ExpectationSuite(
-            suite_name, expectations=expectations, meta=meta, data_context=None  # type: ignore[arg-type]
+            suite_name, expectations=expectations, meta=meta, data_context=None
         )
         suite.add_citation(
             comment=f"This suite was built by the {self.__class__.__name__}",
@@ -170,7 +191,7 @@ class JsonSchemaProfiler(Profiler):
         if description:
             meta = {
                 "notes": {
-                    "format": "markdown",
+                    "format": MetaNotesFormat.MARKDOWN,
                     "content": [f"### Description:\n{description}"],
                 }
             }
