@@ -1,7 +1,7 @@
+from great_expectations.render import RenderedBulletListContent
 from great_expectations.render.renderer.content_block.expectation_string import (
     ExpectationStringRenderer,
 )
-from great_expectations.render.types import RenderedBulletListContent
 
 
 class ExpectationSuiteBulletListContentBlockRenderer(ExpectationStringRenderer):
