@@ -7,14 +7,14 @@ from dateutil.parser import parse
 
 from great_expectations.core import ExpectationSuite
 from great_expectations.core.expectation_validation_result import (
-    ExpectationSuiteValidationResult,
+    ExpectationSuiteValidationResult,  # noqa: TCH001
 )
 from great_expectations.core.run_identifier import RunIdentifier
 from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.exceptions import ClassInstantiationError
-from great_expectations.render.renderer.renderer import Renderer
-from great_expectations.render.types import (
+from great_expectations.render import (
     CollapseContent,
+    LegacyDiagnosticRendererType,
     RenderedComponentContent,
     RenderedDocumentContent,
     RenderedHeaderContent,
@@ -24,9 +24,10 @@ from great_expectations.render.types import (
     RenderedTableContent,
     TextContent,
 )
+from great_expectations.render.renderer.renderer import Renderer
 from great_expectations.render.util import num_to_str
 from great_expectations.validation_operators.types.validation_operator_result import (
-    ValidationOperatorResult,
+    ValidationOperatorResult,  # noqa: TCH001
 )
 
 logger = logging.getLogger(__name__)
@@ -185,7 +186,7 @@ class ValidationResultsPageRenderer(Renderer):
                 if self._data_context is not None
                 else None
             )
-        except:
+        except Exception:
             suite_meta = None
         meta_properties_to_render = self._get_meta_properties_notes(suite_meta)
         for evr in validation_results.results:
@@ -319,7 +320,7 @@ class ValidationResultsPageRenderer(Renderer):
                 "dimension": "properties.dimension",
                 "severity": "properties.severity"
             },
-            "format": "renderer.diagnostic.meta_properties"
+            "format": LegacyDiagnosticRendererType.META_PROPERTIES
         }
         expectation level
         {
@@ -346,7 +347,8 @@ class ValidationResultsPageRenderer(Renderer):
             suite_meta is not None
             and "notes" in suite_meta
             and "format" in suite_meta["notes"]
-            and suite_meta["notes"]["format"] == "renderer.diagnostic.meta_properties"
+            and suite_meta["notes"]["format"]
+            == LegacyDiagnosticRendererType.META_PROPERTIES
         ):
             return suite_meta["notes"]["content"]
         else:
@@ -932,7 +934,7 @@ class ProfilingResultsPageRenderer(Renderer):
                 class_name=column_section_renderer["class_name"],
             )
 
-    def render(self, validation_results):
+    def render(self, validation_results):  # noqa: C901 - 16
         run_id = validation_results.meta["run_id"]
         if isinstance(run_id, str):
             try:
