@@ -1,46 +1,80 @@
+import logging
 from dataclasses import asdict, dataclass
-from typing import Any, Dict, Iterator, List, Optional, Sized
+from typing import Dict, Iterator, List, Optional, Sized
 
 import numpy as np
 import pandas as pd
 
 from great_expectations.core.util import convert_to_json_serializable
 from great_expectations.rule_based_profiler.metric_computation_result import (
-    MetricValue,
-    MetricValues,
+    MetricValues,  # noqa: TCH001
 )
 from great_expectations.types import SerializableDictDot
-from great_expectations.types.attributes import Attributes
+from great_expectations.types.attributes import Attributes  # noqa: TCH001
+from great_expectations.util import deep_filter_properties_iterable
+from great_expectations.validator.computed_metric import MetricValue  # noqa: TCH001
+
+logger = logging.getLogger(__name__)
+
+try:
+    import sqlalchemy as sa
+except ImportError:
+    logger.debug("No SqlAlchemy module available.")
+    sa = None
+
+try:
+    from sqlalchemy.engine import Row as sqlalchemy_engine_Row
+except ImportError:
+    logger.debug("No SqlAlchemy.engine module available.")
+    sqlalchemy_engine_Row = None
+
+try:
+    from pyspark.sql import Row as pyspark_sql_Row
+except ImportError:
+    logger.debug("No spark SQLContext available.")
+    pyspark_sql_Row = None
 
 
 def _condition_metric_values(metric_values: MetricValues) -> MetricValues:
     def _detect_illegal_array_type_or_shape(values: MetricValues) -> bool:
-        # Python "None" is illegal as candidate for conversion into "numpy.ndarray" type.
-        if values is None:
-            return True
-
         # Pandas "DataFrame" and "Series" are illegal as candidates for conversion into "numpy.ndarray" type.
-        if isinstance(values, (pd.DataFrame, pd.Series, set)):
+        if isinstance(
+            values,
+            deep_filter_properties_iterable(
+                properties=(
+                    pd.DataFrame,
+                    pd.Series,
+                    sqlalchemy_engine_Row,
+                    pyspark_sql_Row,
+                    set,
+                )
+            ),
+        ):
             return True
 
+        value: MetricValue
         if isinstance(values, (list, tuple)):
-            if len(values) > 0:
-                value: MetricValue = values[0]
-                # Python "None" is illegal as candidate for conversion into "numpy.ndarray" type.
-                if value is None:
-                    return True
+            if values is not None and len(values) > 0:
+                values = deep_filter_properties_iterable(properties=values)
+                if values:
+                    values_iterator: Iterator
+                    # Components of different lengths cannot be packaged into "numpy.ndarray" type (due to undefined shape).
+                    if all(isinstance(value, (list, tuple)) for value in values):
+                        values_iterator = iter(values)
+                        first_value_length: int = len(next(values_iterator))
+                        current_value: Sized
+                        if not all(
+                            len(current_value) == first_value_length
+                            for current_value in values_iterator
+                        ):
+                            return True
 
-                # Pandas "DataFrame" and "Series" are illegal as candidates for conversion into "numpy.ndarray" type.
-                if isinstance(value, (pd.DataFrame, pd.Series, set)):
-                    return True
-
-                # Components of different lengths cannot be packaged into "numpy.ndarray" type (due to undefined shape).
-                if all(isinstance(value, (list, tuple)) for value in values):
-                    values_iterator: Iterator = iter(values)
-                    first_value_length: int = len(next(values_iterator))
-                    current_value: Sized[Any]
+                    # Components of different types cannot be packaged into "numpy.ndarray" type (due to type mismatch).
+                    values_iterator = iter(values)
+                    first_value_type: type = type(next(values_iterator))
+                    current_type: type
                     if not all(
-                        len(current_value) == first_value_length
+                        type(current_value) == first_value_type
                         for current_value in values_iterator
                     ):
                         return True
@@ -53,17 +87,9 @@ def _condition_metric_values(metric_values: MetricValues) -> MetricValues:
         return False
 
     if _detect_illegal_array_type_or_shape(values=metric_values):
-        value: MetricValue
-        if (
-            metric_values is not None
-            and isinstance(metric_values, (list, tuple))
-            and all(value is None for value in metric_values)
-        ):
-            return np.asarray(metric_values)
-
         return metric_values
-    else:
-        return np.asarray(metric_values)
+
+    return np.asarray(metric_values)
 
 
 @dataclass
@@ -122,11 +148,14 @@ class AttributedResolvedMetrics(SerializableDictDot):
 
     @property
     def id(self) -> str:
+        if self.metric_attributes is None:
+            return ""
+
         return self.metric_attributes.to_id()
 
     @property
     def attributed_metric_values(self) -> Optional[Dict[str, MetricValue]]:
-        if self.metric_values_by_batch_id is None:
+        if self.metric_values_by_batch_id is None or self.batch_ids is None:
             return None
 
         batch_id: str
@@ -138,12 +167,18 @@ class AttributedResolvedMetrics(SerializableDictDot):
 
     @property
     def conditioned_attributed_metric_values(self) -> Dict[str, MetricValues]:
+        if self.attributed_metric_values is None:
+            return {}
+
         return AttributedResolvedMetrics.get_conditioned_attributed_metric_values_from_attributed_metric_values(
             attributed_metric_values=self.attributed_metric_values
         )
 
     @property
     def conditioned_metric_values(self) -> MetricValues:
+        if self.attributed_metric_values is None:
+            return None
+
         return AttributedResolvedMetrics.get_conditioned_metric_values_from_attributed_metric_values(
             attributed_metric_values=self.attributed_metric_values
         )
