@@ -2,17 +2,26 @@ from abc import ABCMeta, abstractmethod
 from inspect import isabstract
 from typing import Any, Dict, Iterable, List, Optional, Set, Tuple, Union
 
-from great_expectations.core import IDDict
-from great_expectations.core.batch import Batch, BatchRequestBase
+from great_expectations.core._docs_decorators import public_api
+from great_expectations.core.batch import Batch, BatchRequestBase  # noqa: TCH001
+from great_expectations.core.domain import Domain, SemanticDomainTypes
+from great_expectations.core.id_dict import deep_convert_properties_iterable_to_id_dict
+from great_expectations.core.metric_function_types import (
+    SummarizationMetricNameSuffixes,
+)
 from great_expectations.core.usage_statistics.usage_statistics import (
-    UsageStatisticsHandler,
+    UsageStatisticsHandler,  # noqa: TCH001
+)
+from great_expectations.experimental.datasources.interfaces import (
+    Batch as XBatch,  # noqa: TCH001
+)
+from great_expectations.rule_based_profiler import (
+    RuleBasedProfilerResult,  # noqa: TCH001
 )
-from great_expectations.rule_based_profiler import RuleBasedProfilerResult
 from great_expectations.rule_based_profiler.config import ParameterBuilderConfig
 from great_expectations.rule_based_profiler.data_assistant_result import (
     DataAssistantResult,
 )
-from great_expectations.rule_based_profiler.domain import Domain, SemanticDomainTypes
 from great_expectations.rule_based_profiler.domain_builder import (
     MapMetricColumnDomainBuilder,
 )
@@ -24,14 +33,15 @@ from great_expectations.rule_based_profiler.helpers.configuration_reconciliation
     DEFAULT_RECONCILATION_DIRECTIVES,
 )
 from great_expectations.rule_based_profiler.helpers.runtime_environment import (
-    RuntimeEnvironmentDomainTypeDirectives,
-    RuntimeEnvironmentVariablesDirectives,
+    RuntimeEnvironmentDomainTypeDirectives,  # noqa: TCH001
+    RuntimeEnvironmentVariablesDirectives,  # noqa: TCH001
 )
 from great_expectations.rule_based_profiler.helpers.util import sanitize_parameter_name
 from great_expectations.rule_based_profiler.parameter_builder import (
     HistogramSingleBatchParameterBuilder,
     MeanUnexpectedMapMetricMultiBatchParameterBuilder,
     MetricMultiBatchParameterBuilder,
+    MetricSingleBatchParameterBuilder,
     NumericMetricRangeMultiBatchParameterBuilder,
     ParameterBuilder,
 )
@@ -52,10 +62,11 @@ from great_expectations.rule_based_profiler.rule_based_profiler import (
     RuleBasedProfiler,
 )
 from great_expectations.util import camel_to_snake, measure_execution_time
-from great_expectations.validator.validator import Validator
-
+from great_expectations.validator.validator import Validator  # noqa: TCH001
 
 # noinspection PyMethodParameters
+
+
 class MetaDataAssistant(ABCMeta):
     """
     MetaDataAssistant registers every DataAssistant class as it is defined, it them to the DataAssistant registry.
@@ -107,6 +118,8 @@ class DataAssistant(metaclass=MetaDataAssistant):
         ...
     """
 
+    data_assistant_type: str  # Added by `MetaDataAssistant`
+
     class CommonlyUsedParameterBuilders:
         def get_table_row_count_metric_multi_batch_parameter_builder(
             self,
@@ -120,24 +133,18 @@ class DataAssistant(metaclass=MetaDataAssistant):
                 metric_value_kwargs=None,
             )
 
-        @staticmethod
-        def get_table_columns_metric_multi_batch_parameter_builder() -> ParameterBuilder:
+        def get_table_columns_metric_multi_batch_parameter_builder(
+            self,
+        ) -> ParameterBuilder:
             """
             This method instantiates one commonly used "MetricMultiBatchParameterBuilder" with specified directives.
             """
             metric_name: str = "table.columns"
-            name: str = sanitize_parameter_name(name=metric_name)
-            return MetricMultiBatchParameterBuilder(
-                name=name,
+            return self.build_metric_multi_batch_parameter_builder(
                 metric_name=metric_name,
+                suffix=None,
                 metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
                 metric_value_kwargs=None,
-                single_batch_mode=False,
-                enforce_numeric_metric=False,
-                replace_nan_with_zero=False,
-                reduce_scalar_metric=True,
-                evaluation_parameter_builder_configs=None,
-                data_context=None,
             )
 
         def get_column_distinct_values_count_metric_multi_batch_parameter_builder(
@@ -158,7 +165,7 @@ class DataAssistant(metaclass=MetaDataAssistant):
             This method instantiates one commonly used "MetricMultiBatchParameterBuilder" with specified directives.
             """
             return self.build_numeric_metric_multi_batch_parameter_builder(
-                metric_name="column_values.unique.unexpected_count",
+                metric_name=f"column_values.unique.{SummarizationMetricNameSuffixes.UNEXPECTED_COUNT.value}",
                 metric_value_kwargs=None,
             )
 
@@ -169,7 +176,7 @@ class DataAssistant(metaclass=MetaDataAssistant):
             This method instantiates one commonly used "MetricMultiBatchParameterBuilder" with specified directives.
             """
             return self.build_numeric_metric_multi_batch_parameter_builder(
-                metric_name="column_values.nonnull.unexpected_count",
+                metric_name=f"column_values.nonnull.{SummarizationMetricNameSuffixes.UNEXPECTED_COUNT.value}",
                 metric_value_kwargs=None,
             )
 
@@ -180,7 +187,7 @@ class DataAssistant(metaclass=MetaDataAssistant):
             This method instantiates one commonly used "MetricMultiBatchParameterBuilder" with specified directives.
             """
             return self.build_numeric_metric_multi_batch_parameter_builder(
-                metric_name="column_values.null.unexpected_count",
+                metric_name=f"column_values.null.{SummarizationMetricNameSuffixes.UNEXPECTED_COUNT.value}",
                 metric_value_kwargs=None,
             )
 
@@ -276,17 +283,69 @@ class DataAssistant(metaclass=MetaDataAssistant):
             )
 
         @staticmethod
-        def build_numeric_metric_multi_batch_parameter_builder(
+        def build_metric_multi_batch_parameter_builder(
             metric_name: str,
+            suffix: Optional[str] = None,
             metric_domain_kwargs: Optional[
                 Union[str, dict]
             ] = DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
             metric_value_kwargs: Optional[Union[str, dict]] = None,
-        ) -> MetricMultiBatchParameterBuilder:
+        ) -> ParameterBuilder:
+            """
+            This method instantiates "MetricMultiBatchParameterBuilder" with specific arguments for given purpose.
+            """
+            name: str = sanitize_parameter_name(name=metric_name, suffix=suffix)
+            return MetricMultiBatchParameterBuilder(
+                name=name,
+                metric_name=metric_name,
+                metric_domain_kwargs=metric_domain_kwargs,
+                metric_value_kwargs=metric_value_kwargs,
+                single_batch_mode=False,
+                enforce_numeric_metric=False,
+                replace_nan_with_zero=False,
+                reduce_scalar_metric=True,
+                evaluation_parameter_builder_configs=None,
+                data_context=None,
+            )
+
+        @staticmethod
+        def build_metric_single_batch_parameter_builder(
+            metric_name: str,
+            suffix: Optional[str] = None,
+            metric_domain_kwargs: Optional[
+                Union[str, dict]
+            ] = DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+            metric_value_kwargs: Optional[Union[str, dict]] = None,
+        ) -> ParameterBuilder:
+            """
+            This method instantiates "MetricSingleBatchParameterBuilder" class with arguments for specific purpose.
+            """
+            name: str = sanitize_parameter_name(name=metric_name, suffix=suffix)
+            return MetricSingleBatchParameterBuilder(
+                name=name,
+                metric_name=metric_name,
+                metric_domain_kwargs=metric_domain_kwargs,
+                metric_value_kwargs=metric_value_kwargs,
+                enforce_numeric_metric=False,
+                replace_nan_with_zero=False,
+                reduce_scalar_metric=True,
+                evaluation_parameter_builder_configs=None,
+                data_context=None,
+            )
+
+        @staticmethod
+        def build_numeric_metric_multi_batch_parameter_builder(
+            metric_name: str,
+            suffix: Optional[str] = None,
+            metric_domain_kwargs: Optional[
+                Union[str, dict]
+            ] = DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+            metric_value_kwargs: Optional[Union[str, dict]] = None,
+        ) -> ParameterBuilder:
             """
             This method instantiates "MetricMultiBatchParameterBuilder" class with specific arguments for given purpose.
             """
-            name: str = sanitize_parameter_name(name=metric_name)
+            name: str = sanitize_parameter_name(name=metric_name, suffix=suffix)
             return MetricMultiBatchParameterBuilder(
                 name=name,
                 metric_name=metric_name,
@@ -300,17 +359,46 @@ class DataAssistant(metaclass=MetaDataAssistant):
                 data_context=None,
             )
 
+        @staticmethod
+        def build_numeric_metric_single_batch_parameter_builder(
+            metric_name: str,
+            suffix: Optional[str] = None,
+            metric_domain_kwargs: Optional[
+                Union[str, dict]
+            ] = DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+            metric_value_kwargs: Optional[Union[str, dict]] = None,
+        ) -> ParameterBuilder:
+            """
+            This method instantiates "MetricSingleBatchParameterBuilder" class with arguments for specific purpose.
+            """
+            name: str = sanitize_parameter_name(name=metric_name, suffix=suffix)
+            return MetricSingleBatchParameterBuilder(
+                name=name,
+                metric_name=metric_name,
+                metric_domain_kwargs=metric_domain_kwargs,
+                metric_value_kwargs=metric_value_kwargs,
+                enforce_numeric_metric=True,
+                replace_nan_with_zero=True,
+                reduce_scalar_metric=True,
+                evaluation_parameter_builder_configs=None,
+                data_context=None,
+            )
+
         @staticmethod
         def build_numeric_metric_range_multi_batch_parameter_builder(
             metric_name: Optional[str] = None,
+            suffix: Optional[str] = None,
             metric_value_kwargs: Optional[Union[str, dict]] = None,
             evaluation_parameter_builder_configs: Optional[
                 List[ParameterBuilderConfig]
             ] = None,
-        ) -> NumericMetricRangeMultiBatchParameterBuilder:
+        ) -> ParameterBuilder:
             """
-            This method instantiates "MetricMultiBatchParameterBuilder" class with specific arguments for given purpose.
+            This method instantiates "NumericMetricRangeMultiBatchParameterBuilder" class with specific arguments for given purpose.
             """
+            if evaluation_parameter_builder_configs is None:
+                evaluation_parameter_builder_configs = []
+
             metric_multi_batch_parameter_builder_name: Optional[str] = None
             if metric_name is None:
                 metric_name = evaluation_parameter_builder_configs[0]["metric_name"]
@@ -318,7 +406,8 @@ class DataAssistant(metaclass=MetaDataAssistant):
                     evaluation_parameter_builder_configs[0].name
                 )
 
-            name: str = sanitize_parameter_name(name=f"{metric_name}.range")
+            name: str = f"{metric_name}{FULLY_QUALIFIED_PARAMETER_NAME_SEPARATOR_CHARACTER}range"
+            name = sanitize_parameter_name(name=name, suffix=suffix)
             return NumericMetricRangeMultiBatchParameterBuilder(
                 name=name,
                 metric_name=metric_name,
@@ -345,11 +434,11 @@ class DataAssistant(metaclass=MetaDataAssistant):
         @staticmethod
         def build_regex_pattern_string_parameter_builder(
             name: str,
-        ) -> RegexPatternStringParameterBuilder:
+        ) -> ParameterBuilder:
             """
             This method instantiates "RegexPatternStringParameterBuilder" class with specific arguments for given purpose.
             """
-            name: str = sanitize_parameter_name(name=f"{name}")
+            name = sanitize_parameter_name(name=name, suffix=None)
             return RegexPatternStringParameterBuilder(
                 name=name,
                 metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
@@ -363,11 +452,11 @@ class DataAssistant(metaclass=MetaDataAssistant):
         @staticmethod
         def build_histogram_single_batch_parameter_builder(
             name: str,
-        ) -> HistogramSingleBatchParameterBuilder:
+        ) -> ParameterBuilder:
             """
             This method instantiates "HistogramSingleBatchParameterBuilder" class with specific arguments for given purpose.
             """
-            name: str = sanitize_parameter_name(name=f"{name}")
+            name = sanitize_parameter_name(name=name, suffix=None)
             return HistogramSingleBatchParameterBuilder(
                 name=name,
                 evaluation_parameter_builder_configs=None,
@@ -400,12 +489,12 @@ class DataAssistant(metaclass=MetaDataAssistant):
 
         self._validator = validator
 
-        if validator is None:
-            self._data_context = None
-            self._batches = None
-        else:
-            self._data_context = self._validator.data_context
-            self._batches = self._validator.batches
+        self._data_context = (
+            self._validator.data_context if self._validator is not None else None
+        )
+        self._batches: Optional[Dict[str, Union[Batch, XBatch]]] = (
+            self._validator.batches if self._validator is not None else None
+        )
 
         variables: Optional[Dict[str, Any]] = self.get_variables() or {}
         self._profiler = RuleBasedProfiler(
@@ -417,18 +506,23 @@ class DataAssistant(metaclass=MetaDataAssistant):
 
         self._metrics_parameter_builders_by_domain = {}
 
-        rules: Optional[List[Rule]] = self.get_rules() or []
+        rules: List[Rule] = self.get_rules() or []
 
         rule: Rule
         for rule in rules:
             self.profiler.add_rule(rule=rule)
             self._metrics_parameter_builders_by_domain[
                 Domain(
-                    domain_type=rule.domain_builder.domain_type,
+                    domain_type=rule.domain_builder.domain_type
+                    if rule.domain_builder
+                    else "",
                     rule_name=rule.name,
                 )
-            ] = rule.parameter_builders
+            ] = (
+                rule.parameter_builders or []
+            )
 
+    @public_api
     def run(
         self,
         variables: Optional[Dict[str, Any]] = None,
@@ -440,17 +534,27 @@ class DataAssistant(metaclass=MetaDataAssistant):
             List[RuntimeEnvironmentDomainTypeDirectives]
         ] = None,
     ) -> DataAssistantResult:
-        """
-        Run the DataAssistant as it is currently configured.
+        """Run the DataAssistant as it is currently configured.
+
+        Example Usage::
+
+            data_assistant = VolumeDataAssistant(
+                name="my_volume_data_assistant",
+                validator=validator,
+            )
+            result: DataAssistantResult = data_assistant.run(
+                variables=None,
+                rules=None,
+            )
 
         Args:
-            variables: attribute name/value pairs (overrides), commonly-used in Builder objects
-            rules: name/(configuration-dictionary) (overrides)
-            variables_directives_list: additional/override runtime variables directives (modify "BaseRuleBasedProfiler")
-            domain_type_directives_list: additional/override runtime domain directives (modify "BaseRuleBasedProfiler")
+            variables: Attribute name/value pairs (overrides); commonly-used in Builder objects.
+            rules: Name/configuration dictionary (overrides)
+            variables_directives_list: Additional/override runtime variables directives (modify `BaseRuleBasedProfiler`).
+            domain_type_directives_list: Additional/override runtime domain directives (modify `BaseRuleBasedProfiler`).
 
         Returns:
-            DataAssistantResult: The result object for the DataAssistant
+            An instance of `DataAssistantResult`.
         """
         usage_statistics_handler: Optional[UsageStatisticsHandler]
         if self._data_context is None:
@@ -458,9 +562,7 @@ class DataAssistant(metaclass=MetaDataAssistant):
         else:
             usage_statistics_handler = self._data_context._usage_statistics_handler
 
-        batches: Dict[str, Batch] = self._batches
-        if batches is None:
-            batches = {}
+        batches: Dict[str, Union[Batch, XBatch]] = self._batches or {}
 
         data_assistant_result = DataAssistantResult(
             _batch_id_to_batch_identifier_display_name_map=self._batch_id_to_batch_identifier_display_name_map(),
@@ -568,6 +670,10 @@ class DataAssistant(metaclass=MetaDataAssistant):
                 parameter_builder.json_serialized_fully_qualified_parameter_name
                 for parameter_builder in parameter_builders
             ]
+            + [
+                parameter_builder.raw_fully_qualified_parameter_name
+                for parameter_builder in parameter_builders
+            ]
             for domain, parameter_builders in self._metrics_parameter_builders_by_domain.items()
         }
 
@@ -585,7 +691,7 @@ class DataAssistant(metaclass=MetaDataAssistant):
             )
             for domain_key, fully_qualified_metrics_parameter_names in fully_qualified_metrics_parameter_names_by_domain.items()
             for domain, parameter_values_for_fully_qualified_parameter_names in parameter_values_for_fully_qualified_parameter_names_by_domain.items()
-            if domain.is_superset(domain_key)
+            if domain.is_superset(other=domain_key)
         }
 
         return parameter_values_for_fully_qualified_parameter_names_by_domain
@@ -596,14 +702,14 @@ class DataAssistant(metaclass=MetaDataAssistant):
         """
         This method uses loaded "Batch" objects to return the mapping between unique "batch_id" and "batch_identifiers".
         """
-        batches: Dict[str, Batch] = self._batches
-        if batches is None:
-            batches = {}
+        batches: Dict[str, Union[Batch, XBatch]] = self._batches or {}
 
+        batch_id: str
+        batch: Batch
         return {
             batch_id: set(
-                IDDict.convert_dictionary_to_id_dict(
-                    batch.batch_definition.batch_identifiers
+                deep_convert_properties_iterable_to_id_dict(
+                    source=batch.batch_definition.batch_identifiers
                 ).items()
             )
             for batch_id, batch in batches.items()
@@ -644,22 +750,15 @@ def run_profiler_on_data(
         variables_directives_list: additional/override runtime variables directives (modify "BaseRuleBasedProfiler")
         domain_type_directives_list: additional/override runtime domain directives (modify "BaseRuleBasedProfiler")
     """
-    if rules is None:
-        rules = []
-
-    rule: Rule
-    rules_configs: Optional[Dict[str, Dict[str, Any]]] = {
-        rule.name: rule.to_json_dict() for rule in rules
-    }
     comment: str = f"""Created by effective Rule-Based Profiler of {data_assistant.__class__.__name__} with the \
 configuration included.
 """
     rule_based_profiler_result: RuleBasedProfilerResult = profiler.run(
         variables=variables,
-        rules=rules_configs,
+        rules=rules,
         batch_list=batch_list,
         batch_request=batch_request,
-        recompute_existing_parameter_values=False,
+        runtime_configuration=None,
         reconciliation_directives=DEFAULT_RECONCILATION_DIRECTIVES,
         variables_directives_list=variables_directives_list,
         domain_type_directives_list=domain_type_directives_list,
