@@ -8,7 +8,7 @@ from great_expectations.rule_based_profiler.data_assistant_result import (
 
 class VolumeDataAssistantResult(DataAssistantResult):
     @property
-    def metric_expectation_map(self) -> Dict[Union[str, Tuple[str]], str]:
+    def metric_expectation_map(self) -> Dict[Union[str, Tuple[str, ...]], str]:
         """
         A mapping is defined for which metrics to plot and their associated expectations.
         """
