@@ -1,11 +1,14 @@
+from __future__ import annotations
+
 import logging
-from typing import Dict, Optional
+from typing import TYPE_CHECKING, Dict, Optional
 
 import numpy as np
+from typing_extensions import Final
 
-from great_expectations.rule_based_profiler.domain import Domain
+from great_expectations.core.domain import Domain  # noqa: TCH001
 from great_expectations.rule_based_profiler.estimators.numeric_range_estimation_result import (
-    NumericRangeEstimationResult,
+    NumericRangeEstimationResult,  # noqa: TCH001
 )
 from great_expectations.rule_based_profiler.estimators.numeric_range_estimator import (
     NumericRangeEstimator,
@@ -17,15 +20,18 @@ from great_expectations.rule_based_profiler.helpers.util import (
     get_quantile_statistic_interpolation_method_from_rule_state,
 )
 from great_expectations.rule_based_profiler.parameter_container import (
-    ParameterContainer,
+    ParameterContainer,  # noqa: TCH001
 )
-from great_expectations.types.attributes import Attributes
+from great_expectations.types.attributes import Attributes  # noqa: TCH001
 from great_expectations.util import convert_ndarray_to_datetime_dtype_best_effort
 
+if TYPE_CHECKING:
+    import numpy.typing as npt
+
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 
-DEFAULT_QUANTILES_QUANTILE_STATISTIC_INTERPOLATION_METHOD = "nearest"
+DEFAULT_QUANTILES_QUANTILE_STATISTIC_INTERPOLATION_METHOD: Final[str] = "nearest"
 
 
 class QuantilesNumericRangeEstimator(NumericRangeEstimator):
@@ -52,15 +58,15 @@ class QuantilesNumericRangeEstimator(NumericRangeEstimator):
         variables: Optional[ParameterContainer] = None,
         parameters: Optional[Dict[str, ParameterContainer]] = None,
     ) -> NumericRangeEstimationResult:
-        false_positive_rate: np.float64 = get_false_positive_rate_from_rule_state(
-            false_positive_rate=self.configuration.false_positive_rate,
+        false_positive_rate: np.float64 = get_false_positive_rate_from_rule_state(  # type: ignore[assignment] # could be float
+            false_positive_rate=self.configuration.false_positive_rate,  # type: ignore[union-attr] # configuration could be None
             domain=domain,
             variables=variables,
             parameters=parameters,
         )
         quantile_statistic_interpolation_method: str = get_quantile_statistic_interpolation_method_from_rule_state(
-            quantile_statistic_interpolation_method=self.configuration.quantile_statistic_interpolation_method,
-            round_decimals=self.configuration.round_decimals,
+            quantile_statistic_interpolation_method=self.configuration.quantile_statistic_interpolation_method,  # type: ignore[union-attr] # configuration could be None
+            round_decimals=self.configuration.round_decimals,  # type: ignore[union-attr] # configuration could be None
             domain=domain,
             variables=variables,
             parameters=parameters,
@@ -71,7 +77,7 @@ class QuantilesNumericRangeEstimator(NumericRangeEstimator):
             )
 
         datetime_detected: bool = datetime_semantic_domain_type(domain=domain)
-        metric_values_converted: np.ndaarray
+        metric_values_converted: npt.NDArray
         (
             _,
             _,
