@@ -1,27 +1,38 @@
+from __future__ import annotations
+
 import logging
 from abc import ABC, abstractmethod
-from typing import Dict, List, Optional, Set, Union
+from typing import TYPE_CHECKING, ClassVar, Dict, List, Optional, Set, Union
 
-from great_expectations.core.batch import Batch, BatchRequestBase
-from great_expectations.core.expectation_configuration import ExpectationConfiguration
+from great_expectations.core.batch import Batch, BatchRequestBase  # noqa: TCH001
+from great_expectations.core.domain import Domain  # noqa: TCH001
+from great_expectations.core.expectation_configuration import (
+    ExpectationConfiguration,  # noqa: TCH001
+)
 from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.rule_based_profiler.builder import Builder
-from great_expectations.rule_based_profiler.config import ParameterBuilderConfig
-from great_expectations.rule_based_profiler.domain import Domain
+from great_expectations.rule_based_profiler.config import (
+    ParameterBuilderConfig,  # noqa: TCH001
+)
 from great_expectations.rule_based_profiler.parameter_builder import (
     ParameterBuilder,
     init_rule_parameter_builders,
 )
 from great_expectations.rule_based_profiler.parameter_container import (
-    ParameterContainer,
+    ParameterContainer,  # noqa: TCH001
 )
 
+if TYPE_CHECKING:
+    from great_expectations.data_context.data_context.abstract_data_context import (
+        AbstractDataContext,
+    )
+
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
 
 
 class ExpectationConfigurationBuilder(ABC, Builder):
-    exclude_field_names: Set[str] = Builder.exclude_field_names | {
+    exclude_field_names: ClassVar[Set[str]] = Builder.exclude_field_names | {
         "validation_parameter_builders",
     }
 
@@ -31,7 +42,7 @@ class ExpectationConfigurationBuilder(ABC, Builder):
         validation_parameter_builder_configs: Optional[
             List[ParameterBuilderConfig]
         ] = None,
-        data_context: Optional["BaseDataContext"] = None,  # noqa: F821
+        data_context: Optional[AbstractDataContext] = None,
         **kwargs,
     ) -> None:
         """
@@ -42,7 +53,7 @@ class ExpectationConfigurationBuilder(ABC, Builder):
             validation_parameter_builder_configs: ParameterBuilder configurations, having whose outputs available (as
             fully-qualified parameter names) is pre-requisite for present ExpectationConfigurationBuilder instance.
             These "ParameterBuilder" configurations help build kwargs needed for this "ExpectationConfigurationBuilder"
-            data_context: BaseDataContext associated with this ExpectationConfigurationBuilder
+            data_context: AbstractDataContext associated with this ExpectationConfigurationBuilder
             kwargs: additional arguments
         """
 
@@ -73,6 +84,7 @@ class ExpectationConfigurationBuilder(ABC, Builder):
         parameters: Optional[Dict[str, ParameterContainer]] = None,
         batch_list: Optional[List[Batch]] = None,
         batch_request: Optional[Union[BatchRequestBase, dict]] = None,
+        runtime_configuration: Optional[dict] = None,
     ) -> ExpectationConfiguration:
         """
         Args:
@@ -81,6 +93,7 @@ class ExpectationConfigurationBuilder(ABC, Builder):
             parameters: Dictionary of ParameterContainer objects corresponding to all Domain objects in memory.
             batch_list: Explicit list of Batch objects to supply data at runtime.
             batch_request: Explicit batch_request used to supply data at runtime.
+            runtime_configuration: Additional run-time settings (see "Validator.DEFAULT_RUNTIME_CONFIGURATION").
 
         Returns:
             ExpectationConfiguration object.
@@ -91,6 +104,7 @@ class ExpectationConfigurationBuilder(ABC, Builder):
             parameters=parameters,
             batch_list=batch_list,
             batch_request=batch_request,
+            runtime_configuration=runtime_configuration,
         )
 
         return self._build_expectation_configuration(
@@ -104,7 +118,7 @@ class ExpectationConfigurationBuilder(ABC, Builder):
         parameters: Optional[Dict[str, ParameterContainer]] = None,
         batch_list: Optional[List[Batch]] = None,
         batch_request: Optional[Union[BatchRequestBase, dict]] = None,
-        recompute_existing_parameter_values: bool = False,
+        runtime_configuration: Optional[dict] = None,
     ) -> None:
         validation_parameter_builders: List[ParameterBuilder] = (
             self.validation_parameter_builders or []
@@ -119,7 +133,7 @@ class ExpectationConfigurationBuilder(ABC, Builder):
                 parameter_computation_impl=None,
                 batch_list=batch_list,
                 batch_request=batch_request,
-                recompute_existing_parameter_values=recompute_existing_parameter_values,
+                runtime_configuration=runtime_configuration,
             )
 
     @abstractmethod
@@ -128,6 +142,7 @@ class ExpectationConfigurationBuilder(ABC, Builder):
         domain: Domain,
         variables: Optional[ParameterContainer] = None,
         parameters: Optional[Dict[str, ParameterContainer]] = None,
+        runtime_configuration: Optional[dict] = None,
     ) -> ExpectationConfiguration:
         pass
 
@@ -142,8 +157,8 @@ class ExpectationConfigurationBuilder(ABC, Builder):
 
 def init_rule_expectation_configuration_builders(
     expectation_configuration_builder_configs: List[dict],
-    data_context: Optional["BaseDataContext"] = None,  # noqa: F821
-) -> List["ExpectationConfigurationBuilder"]:  # noqa: F821
+    data_context: Optional[AbstractDataContext] = None,
+) -> List[ExpectationConfigurationBuilder]:
     expectation_configuration_builder_config: dict
     return [
         init_expectation_configuration_builder(
@@ -156,16 +171,16 @@ def init_rule_expectation_configuration_builders(
 
 def init_expectation_configuration_builder(
     expectation_configuration_builder_config: Union[
-        "ExpectationConfigurationBuilder", dict  # noqa: F821
+        ExpectationConfigurationBuilder, dict
     ],
-    data_context: Optional["BaseDataContext"] = None,  # noqa: F821
-) -> "ExpectationConfigurationBuilder":  # noqa: F821
+    data_context: Optional[AbstractDataContext] = None,
+) -> ExpectationConfigurationBuilder:
     if not isinstance(expectation_configuration_builder_config, dict):
         expectation_configuration_builder_config = (
             expectation_configuration_builder_config.to_dict()
         )
 
-    expectation_configuration_builder: "ExpectationConfigurationBuilder" = instantiate_class_from_config(  # noqa: F821
+    expectation_configuration_builder: ExpectationConfigurationBuilder = instantiate_class_from_config(
         config=expectation_configuration_builder_config,
         runtime_environment={"data_context": data_context},
         config_defaults={
