@@ -1,12 +1,8 @@
 from dataclasses import make_dataclass
 from typing import Any, Dict, List, Set, Tuple, Union
 
-import numpy as np
-import pandas as pd
+from great_expectations.validator.computed_metric import MetricValue
 
-MetricValue = Union[
-    Any, List[Any], Set[Any], Tuple[Any, ...], pd.DataFrame, pd.Series, np.ndarray
-]
 MetricValues = Union[
     MetricValue, List[MetricValue], Set[MetricValue], Tuple[MetricValue, ...]
 ]
