@@ -3,17 +3,17 @@ import shutil
 
 import pytest
 
-from great_expectations import DataContext
 from great_expectations.core import ExpectationConfiguration
 from great_expectations.core.yaml_handler import YAMLHandler
 from great_expectations.data_context.util import file_relative_path
+from great_expectations.util import get_context
 
 
 @pytest.fixture
 def titanic_pandas_data_context_stats_enabled_and_expectation_suite_with_one_expectation(
     titanic_pandas_data_context_with_v013_datasource_with_checkpoints_v1_with_empty_store_stats_enabled,
 ):
-    context: DataContext = titanic_pandas_data_context_with_v013_datasource_with_checkpoints_v1_with_empty_store_stats_enabled
+    context = titanic_pandas_data_context_with_v013_datasource_with_checkpoints_v1_with_empty_store_stats_enabled
     # create expectation suite
     suite = context.create_expectation_suite("my_expectation_suite")
     expectation = ExpectationConfiguration(
@@ -73,7 +73,7 @@ def titanic_spark_data_context_with_v013_datasource_with_checkpoints_v1_with_emp
         str(os.path.join(context_path, "..", "data", "titanic", "Titanic_1912.csv")),
     )
 
-    context = DataContext(context_root_dir=context_path)
+    context = get_context(context_root_dir=context_path)
     assert context.root_directory == context_path
 
     datasource_config: str = f"""
@@ -209,7 +209,7 @@ def context_with_single_taxi_csv_spark(
 def context_with_single_csv_spark_and_suite(
     context_with_single_taxi_csv_spark,
 ):
-    context: DataContext = context_with_single_taxi_csv_spark
+    context = context_with_single_taxi_csv_spark
     # create expectation suite
     suite = context.create_expectation_suite("my_expectation_suite")
     expectation = ExpectationConfiguration(
