@@ -6,9 +6,9 @@ import pytest
 from click.testing import CliRunner
 from nbconvert.preprocessors import ExecutePreprocessor
 
-from great_expectations import DataContext
 from great_expectations.cli import cli
-from tests.cli.utils import assert_no_logging_messages_or_tracebacks
+from great_expectations.util import get_context
+from tests.cli.utils import assert_no_logging_messages_or_tracebacks, escape_ansi
 
 
 @mock.patch(
@@ -17,7 +17,7 @@ from tests.cli.utils import assert_no_logging_messages_or_tracebacks
 def test_cli_datasource_list_on_project_with_no_datasources(
     mock_emit, caplog, monkeypatch, empty_data_context_stats_enabled, filesystem_csv_2
 ):
-    context: DataContext = empty_data_context_stats_enabled
+    context = empty_data_context_stats_enabled
 
     runner = CliRunner(mix_stderr=False)
     monkeypatch.chdir(os.path.dirname(context.root_directory))
@@ -65,7 +65,7 @@ def test_cli_datasource_list_on_project_with_one_datasource(
     titanic_pandas_data_context_with_v013_datasource_with_checkpoints_v1_with_empty_store_stats_enabled,
     filesystem_csv_2,
 ):
-    context: DataContext = titanic_pandas_data_context_with_v013_datasource_with_checkpoints_v1_with_empty_store_stats_enabled
+    context = titanic_pandas_data_context_with_v013_datasource_with_checkpoints_v1_with_empty_store_stats_enabled
 
     runner = CliRunner(mix_stderr=False)
     monkeypatch.chdir(os.path.dirname(context.root_directory))
@@ -75,13 +75,13 @@ def test_cli_datasource_list_on_project_with_one_datasource(
         catch_exceptions=False,
     )
 
-    expected_output = """Using v3 (Batch Request) API\x1b[0m
-1 Datasource found:[0m
-[0m
- - [36mname:[0m my_datasource[0m
-   [36mclass_name:[0m Datasource[0m
+    expected_output = """Using v3 (Batch Request) API
+1 Datasource found:
+
+ - name: my_datasource
+   class_name: Datasource
 """.strip()
-    stdout = result.stdout.strip()
+    stdout = escape_ansi(result.stdout).strip()
     assert stdout == expected_output
     assert_no_logging_messages_or_tracebacks(caplog, result)
 
@@ -143,7 +143,7 @@ def test_cli_datasource_new(
 
     assert result.exit_code == 0
 
-    uncommitted_dir = os.path.join(root_dir, context.GE_UNCOMMITTED_DIR)
+    uncommitted_dir = os.path.join(root_dir, context.GX_UNCOMMITTED_DIR)
     expected_notebook = os.path.join(uncommitted_dir, "datasource_new.ipynb")
     assert os.path.isfile(expected_notebook)
     mock_subprocess.assert_called_once_with(["jupyter", "notebook", expected_notebook])
@@ -185,7 +185,7 @@ def test_cli_datasource_new(
     ep.preprocess(nb, {"metadata": {"path": uncommitted_dir}})
 
     del context
-    context = DataContext(root_dir)
+    context = get_context(context_root_dir=root_dir)
 
     assert len(context.list_datasources()) == 1
     assert context.list_datasources() == [
@@ -260,7 +260,7 @@ def test_cli_datasource_new_no_jupyter_writes_notebook(
 
     assert result.exit_code == 0
 
-    uncommitted_dir = os.path.join(root_dir, context.GE_UNCOMMITTED_DIR)
+    uncommitted_dir = os.path.join(root_dir, context.GX_UNCOMMITTED_DIR)
     expected_notebook = os.path.join(uncommitted_dir, "datasource_new.ipynb")
     assert os.path.isfile(expected_notebook)
     assert mock_subprocess.call_count == 0
@@ -324,7 +324,7 @@ def test_cli_datasource_new_with_name_param(
 
     assert result.exit_code == 0
 
-    uncommitted_dir = os.path.join(root_dir, context.GE_UNCOMMITTED_DIR)
+    uncommitted_dir = os.path.join(root_dir, context.GX_UNCOMMITTED_DIR)
     expected_notebook = os.path.join(uncommitted_dir, "datasource_new.ipynb")
     assert os.path.isfile(expected_notebook)
     mock_subprocess.assert_called_once_with(["jupyter", "notebook", expected_notebook])
@@ -336,7 +336,7 @@ def test_cli_datasource_new_with_name_param(
     ep.preprocess(nb, {"metadata": {"path": uncommitted_dir}})
 
     del context
-    context = DataContext(root_dir)
+    context = get_context(context_root_dir=root_dir)
 
     assert len(context.list_datasources()) == 1
     assert context.list_datasources() == [
@@ -406,7 +406,7 @@ def test_cli_datasource_new_from_misc_directory(
 
     assert result.exit_code == 0
 
-    uncommitted_dir = os.path.join(root_dir, context.GE_UNCOMMITTED_DIR)
+    uncommitted_dir = os.path.join(root_dir, context.GX_UNCOMMITTED_DIR)
     expected_notebook = os.path.join(uncommitted_dir, "datasource_new.ipynb")
     assert os.path.isfile(expected_notebook)
     mock_subprocess.assert_called_once_with(["jupyter", "notebook", expected_notebook])
@@ -418,7 +418,7 @@ def test_cli_datasource_new_from_misc_directory(
     ep.preprocess(nb, {"metadata": {"path": uncommitted_dir}})
 
     del context
-    context = DataContext(root_dir)
+    context = get_context(context_root_dir=root_dir)
 
     assert context.list_datasources() == [
         {
@@ -509,7 +509,7 @@ def test_cli_datasource_delete_on_project_with_one_datasource(
     # reload context from disk to see if the datasource was in fact deleted
     root_directory = context.root_directory
     del context
-    context = DataContext(root_directory)
+    context = get_context(context_root_dir=root_directory)
     assert len(context.list_datasources()) == 0
     assert_no_logging_messages_or_tracebacks(caplog, result)
 
@@ -571,7 +571,7 @@ def test_cli_datasource_delete_on_project_with_one_datasource_assume_yes_flag(
     # reload context from disk to see if the datasource was in fact deleted
     root_directory = context.root_directory
     del context
-    context = DataContext(root_directory)
+    context = get_context(context_root_dir=root_directory)
     assert len(context.list_datasources()) == 0
     assert_no_logging_messages_or_tracebacks(caplog, result)
 
@@ -629,7 +629,7 @@ def test_cli_datasource_delete_on_project_with_one_datasource_declining_prompt_d
     # reload context from disk to see if the datasource was in fact deleted
     root_directory = context.root_directory
     del context
-    context = DataContext(root_directory)
+    context = get_context(context_root_dir=root_directory)
     assert len(context.list_datasources()) == 1
     assert_no_logging_messages_or_tracebacks(caplog, result)
 
