@@ -8,20 +8,23 @@ from freezegun import freeze_time
 from moto import mock_s3
 
 import great_expectations
-from great_expectations import DataContext
 from great_expectations.cli import cli
+from great_expectations.data_context.data_context.file_data_context import (
+    FileDataContext,
+)
 from great_expectations.data_context.util import file_relative_path
 from great_expectations.util import gen_directory_tree_str
 from tests.cli.utils import (
     VALIDATION_OPERATORS_DEPRECATION_MESSAGE,
     assert_no_logging_messages_or_tracebacks,
+    escape_ansi,
 )
 
 
 @pytest.fixture
 def v20_project_directory_with_v30_configuration_and_v20_checkpoints(tmp_path_factory):
     """
-    GE config_version: 3 project for testing upgrade helper
+    GX config_version: 3 project for testing upgrade helper
     """
     project_path = str(tmp_path_factory.mktemp("v30_project"))
     context_root_dir = os.path.join(project_path, "great_expectations")
@@ -45,7 +48,7 @@ def v20_project_directory_with_v30_configuration_and_v20_checkpoints(tmp_path_fa
 @pytest.fixture
 def v20_project_directory_with_v30_configuration_and_no_checkpoints(tmp_path_factory):
     """
-    GE config_version: 3 project for testing upgrade helper
+    GX config_version: 3 project for testing upgrade helper
     """
     project_path = str(tmp_path_factory.mktemp("v30_project"))
     context_root_dir = os.path.join(project_path, "great_expectations")
@@ -119,7 +122,7 @@ def test_upgrade_helper_intervention_on_cli_command(
         input="n\n",
         catch_exceptions=False,
     )
-    stdout: str = result.stdout
+    stdout: str = escape_ansi(result.stdout).strip()
 
     assert (
         "Your project appears to have an out-of-date config version (1.0) - the version number must be at least 3."
@@ -131,12 +134,12 @@ def test_upgrade_helper_intervention_on_cli_command(
         in stdout
     )
     assert (
-        "Ok, exiting now. To upgrade at a later time, use the following command: [36mgreat_expectations project "
-        "upgrade[0m" in stdout
+        "Ok, exiting now. To upgrade at a later time, use the following command: great_expectations project "
+        "upgrade" in stdout
     )
     assert (
-        "To learn more about the upgrade process, visit ["
-        "36mhttps://docs.greatexpectations.io/docs/guides/miscellaneous/migration_guide#migrating-to-the-batch-request-v3-api"
+        "To learn more about the upgrade process, visit "
+        "https://docs.greatexpectations.io/docs/guides/miscellaneous/migration_guide#migrating-to-the-batch-request-v3-api"
         in stdout
     )
     assert_no_logging_messages_or_tracebacks(
@@ -146,7 +149,8 @@ def test_upgrade_helper_intervention_on_cli_command(
 
     # make sure config version unchanged
     assert (
-        DataContext.get_ge_config_version(context_root_dir=v10_project_directory) == 1.0
+        FileDataContext.get_ge_config_version(context_root_dir=v10_project_directory)
+        == 1.0
     )
 
     expected_project_tree_str: str = """\
@@ -197,7 +201,7 @@ def test_basic_project_upgrade(v10_project_directory, caplog):
         input="\n",
         catch_exceptions=False,
     )
-    stdout: str = result.stdout
+    stdout: str = escape_ansi(result.stdout).strip()
 
     with open(
         file_relative_path(
@@ -205,9 +209,9 @@ def test_basic_project_upgrade(v10_project_directory, caplog):
             "../../test_fixtures/upgrade_helper/test_basic_project_upgrade_expected_stdout.fixture",
         )
     ) as f:
-        expected_stdout: str = f.read()
+        expected_stdout: str = f.read().strip()
         expected_stdout = expected_stdout.replace(
-            "GE_PROJECT_DIR", v10_project_directory
+            "GX_PROJECT_DIR", v10_project_directory
         )
         assert stdout == expected_stdout
 
@@ -256,7 +260,8 @@ great_expectations/
     assert obs_project_tree_str == expected_project_tree_str
     # make sure config number incremented
     assert (
-        DataContext.get_ge_config_version(context_root_dir=v10_project_directory) == 3.0
+        FileDataContext.get_ge_config_version(context_root_dir=v10_project_directory)
+        == 3.0
     )
 
     with open(
@@ -268,7 +273,7 @@ great_expectations/
         expected_upgrade_log_dict: dict = json.load(f)
         expected_upgrade_log_str: str = json.dumps(expected_upgrade_log_dict)
         expected_upgrade_log_str = expected_upgrade_log_str.replace(
-            "GE_PROJECT_DIR", v10_project_directory
+            "GX_PROJECT_DIR", v10_project_directory
         )
         expected_upgrade_log_dict: dict = json.loads(expected_upgrade_log_str)
 
@@ -303,7 +308,7 @@ def test_project_upgrade_with_manual_steps(
         input="\n",
         catch_exceptions=False,
     )
-    stdout: str = result.stdout
+    stdout: str = escape_ansi(result.stdout).strip()
 
     with open(
         file_relative_path(
@@ -311,9 +316,9 @@ def test_project_upgrade_with_manual_steps(
             "../../test_fixtures/upgrade_helper/test_project_upgrade_with_manual_steps_expected_stdout.fixture",
         )
     ) as f:
-        expected_stdout: str = f.read()
+        expected_stdout: str = f.read().strip()
         expected_stdout = expected_stdout.replace(
-            "GE_PROJECT_DIR", v10_project_directory
+            "GX_PROJECT_DIR", v10_project_directory
         )
         assert stdout == expected_stdout
 
@@ -369,7 +374,8 @@ great_expectations/
     assert obs_project_tree_str == expected_project_tree_str
     # make sure config number not incremented
     assert (
-        DataContext.get_ge_config_version(context_root_dir=v10_project_directory) == 1.0
+        FileDataContext.get_ge_config_version(context_root_dir=v10_project_directory)
+        == 1.0
     )
 
     with open(
@@ -381,7 +387,7 @@ great_expectations/
         expected_upgrade_log_dict: dict = json.load(f)
         expected_upgrade_log_str: str = json.dumps(expected_upgrade_log_dict)
         expected_upgrade_log_str = expected_upgrade_log_str.replace(
-            "GE_PROJECT_DIR", v10_project_directory
+            "GX_PROJECT_DIR", v10_project_directory
         )
         expected_upgrade_log_dict = json.loads(expected_upgrade_log_str)
 
@@ -414,7 +420,7 @@ def test_project_upgrade_with_exception(v10_project_directory, caplog):
         input="\n",
         catch_exceptions=False,
     )
-    stdout: str = result.stdout
+    stdout: str = escape_ansi(result.stdout).strip()
 
     with open(
         file_relative_path(
@@ -422,9 +428,9 @@ def test_project_upgrade_with_exception(v10_project_directory, caplog):
             "../../test_fixtures/upgrade_helper/test_project_upgrade_with_exception_expected_stdout.fixture",
         )
     ) as f:
-        expected_stdout: str = f.read()
+        expected_stdout: str = f.read().strip()
         expected_stdout = expected_stdout.replace(
-            "GE_PROJECT_DIR", v10_project_directory
+            "GX_PROJECT_DIR", v10_project_directory
         )
         assert stdout == expected_stdout
 
@@ -472,7 +478,8 @@ great_expectations/
     assert obs_project_tree_str == expected_project_tree_str
     # make sure config number not incremented
     assert (
-        DataContext.get_ge_config_version(context_root_dir=v10_project_directory) == 1.0
+        FileDataContext.get_ge_config_version(context_root_dir=v10_project_directory)
+        == 1.0
     )
 
     with open(
@@ -484,10 +491,10 @@ great_expectations/
         expected_upgrade_log_dict: dict = json.load(f)
         expected_upgrade_log_str: str = json.dumps(expected_upgrade_log_dict)
         expected_upgrade_log_str = expected_upgrade_log_str.replace(
-            "GE_PROJECT_DIR", v10_project_directory
+            "GX_PROJECT_DIR", v10_project_directory
         )
         expected_upgrade_log_str = expected_upgrade_log_str.replace(
-            "GE_PATH", os.path.split(great_expectations.__file__)[0]
+            "GX_PATH", os.path.split(great_expectations.__file__)[0]
         )
         expected_upgrade_log_dict = json.loads(expected_upgrade_log_str)
 
@@ -511,7 +518,7 @@ def test_v2_to_v3_project_upgrade_with_all_manual_steps_checkpoints_datasources_
         input="\n",
         catch_exceptions=False,
     )
-    stdout: str = result.stdout
+    stdout: str = escape_ansi(result.stdout).strip()
 
     with open(
         file_relative_path(
@@ -519,9 +526,9 @@ def test_v2_to_v3_project_upgrade_with_all_manual_steps_checkpoints_datasources_
             "../../test_fixtures/upgrade_helper/test_v2_to_v3_project_upgrade_with_manual_steps_checkpoints_datasources_validation_operators_expected_stdout.fixture",
         )
     ) as f:
-        expected_stdout: str = f.read()
+        expected_stdout: str = f.read().strip()
         expected_stdout = expected_stdout.replace(
-            "GE_PROJECT_DIR", v20_project_directory
+            "GX_PROJECT_DIR", v20_project_directory
         )
         assert stdout == expected_stdout
 
@@ -577,7 +584,8 @@ great_expectations/
     assert obs_project_tree_str == expected_project_tree_str
     # make sure config number incremented
     assert (
-        DataContext.get_ge_config_version(context_root_dir=v20_project_directory) == 3.0
+        FileDataContext.get_ge_config_version(context_root_dir=v20_project_directory)
+        == 3.0
     )
 
     with open(
@@ -589,7 +597,7 @@ great_expectations/
         expected_upgrade_log_dict: dict = json.load(f)
         expected_upgrade_log_str: str = json.dumps(expected_upgrade_log_dict)
         expected_upgrade_log_str = expected_upgrade_log_str.replace(
-            "GE_PROJECT_DIR", v20_project_directory
+            "GX_PROJECT_DIR", v20_project_directory
         )
         expected_upgrade_log_dict = json.loads(expected_upgrade_log_str)
 
@@ -618,7 +626,7 @@ def test_v2_to_v3_project_upgrade_with_manual_steps_checkpoints(
         input="\n",
         catch_exceptions=False,
     )
-    stdout: str = result.stdout
+    stdout: str = escape_ansi(result.stdout).strip()
 
     with open(
         file_relative_path(
@@ -626,9 +634,9 @@ def test_v2_to_v3_project_upgrade_with_manual_steps_checkpoints(
             "../../test_fixtures/upgrade_helper/test_v2_to_v3_project_upgrade_with_manual_steps_checkpoints.fixture",
         )
     ) as f:
-        expected_stdout: str = f.read()
+        expected_stdout: str = f.read().strip()
         expected_stdout = expected_stdout.replace(
-            "GE_PROJECT_DIR",
+            "GX_PROJECT_DIR",
             v20_project_directory_with_v30_configuration_and_v20_checkpoints,
         )
         assert stdout == expected_stdout
@@ -687,7 +695,7 @@ great_expectations/
     assert obs_project_tree_str == expected_project_tree_str
     # make sure config number incremented
     assert (
-        DataContext.get_ge_config_version(
+        FileDataContext.get_ge_config_version(
             context_root_dir=v20_project_directory_with_v30_configuration_and_v20_checkpoints
         )
         == 3.0
@@ -702,7 +710,7 @@ great_expectations/
         expected_upgrade_log_dict: dict = json.load(f)
         expected_upgrade_log_str: str = json.dumps(expected_upgrade_log_dict)
         expected_upgrade_log_str = expected_upgrade_log_str.replace(
-            "GE_PROJECT_DIR",
+            "GX_PROJECT_DIR",
             v20_project_directory_with_v30_configuration_and_v20_checkpoints,
         )
         expected_upgrade_log_dict = json.loads(expected_upgrade_log_str)
@@ -732,7 +740,7 @@ def test_v2_to_v3_project_upgrade_without_manual_steps(
         input="\n",
         catch_exceptions=False,
     )
-    stdout: str = result.stdout
+    stdout: str = escape_ansi(result.stdout).strip()
 
     with open(
         file_relative_path(
@@ -740,9 +748,9 @@ def test_v2_to_v3_project_upgrade_without_manual_steps(
             "../../test_fixtures/upgrade_helper/test_v2_to_v3_project_upgrade_without_manual_steps_expected_stdout.fixture",
         )
     ) as f:
-        expected_stdout: str = f.read()
+        expected_stdout: str = f.read().strip()
         expected_stdout = expected_stdout.replace(
-            "GE_PROJECT_DIR",
+            "GX_PROJECT_DIR",
             v20_project_directory_with_v30_configuration_and_no_checkpoints,
         )
         assert stdout == expected_stdout
@@ -795,7 +803,7 @@ great_expectations/
     assert obs_project_tree_str == expected_project_tree_str
     # make sure config number incremented
     assert (
-        DataContext.get_ge_config_version(
+        FileDataContext.get_ge_config_version(
             context_root_dir=v20_project_directory_with_v30_configuration_and_no_checkpoints
         )
         == 3.0
@@ -810,7 +818,7 @@ great_expectations/
         expected_upgrade_log_dict: dict = json.load(f)
         expected_upgrade_log_str: str = json.dumps(expected_upgrade_log_dict)
         expected_upgrade_log_str = expected_upgrade_log_str.replace(
-            "GE_PROJECT_DIR",
+            "GX_PROJECT_DIR",
             v20_project_directory_with_v30_configuration_and_no_checkpoints,
         )
         expected_upgrade_log_dict = json.loads(expected_upgrade_log_str)
