@@ -4,6 +4,10 @@ from click.testing import CliRunner
 
 from great_expectations import DataContext
 from great_expectations.cli.v012 import cli
+from great_expectations.data_context.data_context.file_data_context import (
+    FileDataContext,
+)
+from tests.cli.utils import escape_ansi
 from tests.cli.v012.test_cli import yaml
 from tests.cli.v012.utils import (
     assert_no_logging_messages_or_tracebacks,
@@ -64,21 +68,21 @@ def test_cli_datasource_list(caplog, empty_data_context, filesystem_csv_2):
         cli, ["datasource", "list", "-d", project_root_dir], catch_exceptions=False
     )
     expected_output = """
-1 Datasource found:[0m
-[0m
- - [36mname:[0m wow_a_datasource[0m
-   [36mmodule_name:[0m great_expectations.datasource[0m
-   [36mclass_name:[0m PandasDatasource[0m
-   [36mbatch_kwargs_generators:[0m[0m
-     [36msubdir_reader:[0m[0m
-       [36mclass_name:[0m SubdirReaderBatchKwargsGenerator[0m
-       [36mbase_directory:[0m {}[0m
-   [36mdata_asset_type:[0m[0m
-     [36mmodule_name:[0m great_expectations.dataset[0m
-     [36mclass_name:[0m PandasDataset[0m""".format(
+1 Datasource found:
+
+ - name: wow_a_datasource
+   module_name: great_expectations.datasource
+   class_name: PandasDatasource
+   batch_kwargs_generators:
+     subdir_reader:
+       class_name: SubdirReaderBatchKwargsGenerator
+       base_directory: {}
+   data_asset_type:
+     module_name: great_expectations.dataset
+     class_name: PandasDataset""".format(
         base_directory
     ).strip()
-    stdout = result.stdout.strip()
+    stdout = escape_ansi(result.stdout).strip()
     assert stdout == expected_output
     assert_no_logging_messages_or_tracebacks(caplog, result)
 
@@ -104,7 +108,7 @@ def test_cli_datasource_new(caplog, empty_data_context, filesystem_csv_2):
 
     assert result.exit_code == 0
 
-    config_path = os.path.join(project_root_dir, DataContext.GE_YML)
+    config_path = os.path.join(project_root_dir, FileDataContext.GX_YML)
     config = yaml.load(open(config_path))
     datasources = config["datasources"]
     assert "mynewsource" in datasources.keys()
