@@ -8,6 +8,9 @@ from freezegun import freeze_time
 
 from great_expectations import DataContext
 from great_expectations.cli.v012 import cli
+from great_expectations.data_context.data_context.file_data_context import (
+    FileDataContext,
+)
 from great_expectations.data_context.util import file_relative_path
 from great_expectations.util import gen_directory_tree_str
 from tests.cli.v012.test_cli import yaml
@@ -309,7 +312,7 @@ def test_init_on_existing_project_with_no_datasources_should_continue_init_flow_
     mock_webbrowser, caplog, initialized_sqlite_project, titanic_sqlite_db_file, sa
 ):
     project_dir = initialized_sqlite_project
-    ge_dir = os.path.join(project_dir, DataContext.GE_DIR)
+    ge_dir = os.path.join(project_dir, FileDataContext.GX_DIR)
 
     _remove_all_datasources(ge_dir)
     os.remove(os.path.join(ge_dir, "expectations", "warning.json"))
@@ -367,7 +370,7 @@ def test_init_on_existing_project_with_no_datasources_should_continue_init_flow_
     assert "Great Expectations connected to your database" in stdout
     assert "This looks like an existing project that" not in stdout
 
-    config = _load_config_file(os.path.join(ge_dir, DataContext.GE_YML))
+    config = _load_config_file(os.path.join(ge_dir, FileDataContext.GX_YML))
     assert "sqlite" in config["datasources"].keys()
 
     context = DataContext(ge_dir)
@@ -390,7 +393,7 @@ def test_init_on_existing_project_with_no_datasources_should_continue_init_flow_
 
 
 def _remove_all_datasources(ge_dir):
-    config_path = os.path.join(ge_dir, DataContext.GE_YML)
+    config_path = os.path.join(ge_dir, FileDataContext.GX_YML)
 
     config = _load_config_file(config_path)
     config["datasources"] = {}
@@ -454,8 +457,8 @@ def initialized_sqlite_project(
 
     assert_no_logging_messages_or_tracebacks(caplog, result)
 
-    context = DataContext(os.path.join(project_dir, DataContext.GE_DIR))
-    assert isinstance(context, DataContext)
+    context = DataContext(os.path.join(project_dir, FileDataContext.GX_DIR))
+    assert isinstance(context, FileDataContext)
     assert len(context.list_datasources()) == 1
     assert context.list_datasources() == [
         {
@@ -485,7 +488,7 @@ def test_init_on_existing_project_with_multiple_datasources_exist_do_nothing(
     empty_sqlite_db,
 ):
     project_dir = initialized_sqlite_project
-    ge_dir = os.path.join(project_dir, DataContext.GE_DIR)
+    ge_dir = os.path.join(project_dir, FileDataContext.GX_DIR)
 
     context = DataContext(ge_dir)
     datasource_name = "wow_a_datasource"
@@ -608,7 +611,7 @@ def test_init_on_existing_project_with_datasource_with_no_suite_create_one(
     mock_webbrowser, caplog, initialized_sqlite_project, sa
 ):
     project_dir = initialized_sqlite_project
-    ge_dir = os.path.join(project_dir, DataContext.GE_DIR)
+    ge_dir = os.path.join(project_dir, FileDataContext.GX_DIR)
     uncommitted_dir = os.path.join(ge_dir, "uncommitted")
 
     # mangle the setup to remove all traces of any suite
