@@ -2,6 +2,7 @@ from click.testing import CliRunner
 
 from great_expectations import DataContext
 from great_expectations.cli.v012 import cli
+from tests.cli.utils import escape_ansi
 from tests.cli.v012.utils import assert_no_logging_messages_or_tracebacks
 
 
@@ -40,20 +41,20 @@ def test_store_list_with_two_stores(caplog, empty_data_context):
     runner = CliRunner(mix_stderr=False)
 
     expected_result = """\
-2 Stores found:[0m
-[0m
- - [36mname:[0m expectations_store[0m
-   [36mclass_name:[0m ExpectationsStore[0m
-   [36mstore_backend:[0m[0m
-     [36mclass_name:[0m TupleFilesystemStoreBackend[0m
-     [36mbase_directory:[0m expectations/[0m
-[0m
- - [36mname:[0m checkpoint_store[0m
-   [36mclass_name:[0m CheckpointStore[0m
-   [36mstore_backend:[0m[0m
-     [36mclass_name:[0m TupleFilesystemStoreBackend[0m
-     [36mbase_directory:[0m checkpoints/[0m
-     [36msuppress_store_backend_id:[0m True[0m"""
+2 Stores found:
+
+ - name: expectations_store
+   class_name: ExpectationsStore
+   store_backend:
+     class_name: TupleFilesystemStoreBackend
+     base_directory: expectations/
+
+ - name: checkpoint_store
+   class_name: CheckpointStore
+   store_backend:
+     class_name: TupleFilesystemStoreBackend
+     base_directory: checkpoints/
+     suppress_store_backend_id: True"""
 
     result = runner.invoke(
         cli,
@@ -62,7 +63,7 @@ def test_store_list_with_two_stores(caplog, empty_data_context):
     )
 
     assert result.exit_code == 0
-    assert result.output.strip() == expected_result
+    assert escape_ansi(result.output).strip() == expected_result.strip()
 
     assert_no_logging_messages_or_tracebacks(caplog, result)
 
@@ -72,36 +73,36 @@ def test_store_list_with_four_stores(caplog, empty_data_context):
     runner = CliRunner(mix_stderr=False)
 
     expected_result = """\
-5 Stores found:[0m
-[0m
- - [36mname:[0m expectations_store[0m
-   [36mclass_name:[0m ExpectationsStore[0m
-   [36mstore_backend:[0m[0m
-     [36mclass_name:[0m TupleFilesystemStoreBackend[0m
-     [36mbase_directory:[0m expectations/[0m
-[0m
- - [36mname:[0m validations_store[0m
-   [36mclass_name:[0m ValidationsStore[0m
-   [36mstore_backend:[0m[0m
-     [36mclass_name:[0m TupleFilesystemStoreBackend[0m
-     [36mbase_directory:[0m uncommitted/validations/[0m
-[0m
- - [36mname:[0m evaluation_parameter_store[0m
-   [36mclass_name:[0m EvaluationParameterStore[0m
-[0m
- - [36mname:[0m checkpoint_store[0m
-   [36mclass_name:[0m CheckpointStore[0m
-   [36mstore_backend:[0m[0m
-     [36mclass_name:[0m TupleFilesystemStoreBackend[0m
-     [36mbase_directory:[0m checkpoints/[0m
-     [36msuppress_store_backend_id:[0m True[0m
-[0m
- - [36mname:[0m profiler_store[0m
-   [36mclass_name:[0m ProfilerStore[0m
-   [36mstore_backend:[0m[0m
-     [36mclass_name:[0m TupleFilesystemStoreBackend[0m
-     [36mbase_directory:[0m profilers/[0m
-     [36msuppress_store_backend_id:[0m True[0m"""
+5 Stores found:
+
+ - name: expectations_store
+   class_name: ExpectationsStore
+   store_backend:
+     class_name: TupleFilesystemStoreBackend
+     base_directory: expectations/
+
+ - name: validations_store
+   class_name: ValidationsStore
+   store_backend:
+     class_name: TupleFilesystemStoreBackend
+     base_directory: uncommitted/validations/
+
+ - name: evaluation_parameter_store
+   class_name: EvaluationParameterStore
+
+ - name: checkpoint_store
+   class_name: CheckpointStore
+   store_backend:
+     class_name: TupleFilesystemStoreBackend
+     base_directory: checkpoints/
+     suppress_store_backend_id: True
+
+ - name: profiler_store
+   class_name: ProfilerStore
+   store_backend:
+     class_name: TupleFilesystemStoreBackend
+     base_directory: profilers/
+     suppress_store_backend_id: True"""
     result = runner.invoke(
         cli,
         f"store list -d {project_dir}",
@@ -109,6 +110,6 @@ def test_store_list_with_four_stores(caplog, empty_data_context):
     )
     print(result.output)
     assert result.exit_code == 0
-    assert result.output.strip() == expected_result
+    assert escape_ansi(result.output).strip() == expected_result.strip()
 
     assert_no_logging_messages_or_tracebacks(caplog, result)
