@@ -7,13 +7,16 @@ from freezegun import freeze_time
 from moto import mock_s3
 
 import great_expectations
-from great_expectations import DataContext
 
 # NOTE: we explicitly import the v012 CLI module, so the tests don't require the --v2-api flag explicitly,
 # although that is what is being run.
 from great_expectations.cli.v012 import cli
+from great_expectations.data_context.data_context.file_data_context import (
+    FileDataContext,
+)
 from great_expectations.data_context.util import file_relative_path
 from great_expectations.util import gen_directory_tree_str
+from tests.cli.utils import escape_ansi
 from tests.cli.v012.utils import (
     VALIDATION_OPERATORS_DEPRECATION_MESSAGE,
     assert_no_logging_messages_or_tracebacks,
@@ -60,7 +63,7 @@ def test_upgrade_helper_intervention_on_cli_command(v10_project_directory, caplo
         input="n\n",
         catch_exceptions=False,
     )
-    stdout = result.stdout
+    stdout = escape_ansi(result.stdout).strip()
 
     assert (
         "Your project appears to have an out-of-date config version (1.0) - the version number must be at least 3."
@@ -72,19 +75,20 @@ def test_upgrade_helper_intervention_on_cli_command(v10_project_directory, caplo
         in stdout
     )
     assert (
-        "Ok, exiting now. To upgrade at a later time, use the following command: [36mgreat_expectations project "
-        "upgrade[0m" in stdout
+        "Ok, exiting now. To upgrade at a later time, use the following command: great_expectations project "
+        "upgrade" in stdout
     )
     assert (
-        "To learn more about the upgrade process, visit ["
-        "36mhttps://docs.greatexpectations.io/en/latest/how_to_guides/migrating_versions.html"
+        "To learn more about the upgrade process, visit "
+        "https://docs.greatexpectations.io/en/latest/how_to_guides/migrating_versions.html"
         in stdout
     )
     assert_no_logging_messages_or_tracebacks(caplog, result)
 
     # make sure config version unchanged
     assert (
-        DataContext.get_ge_config_version(context_root_dir=v10_project_directory) == 1
+        FileDataContext.get_ge_config_version(context_root_dir=v10_project_directory)
+        == 1
     )
 
     expected_project_tree_str = """\
@@ -135,7 +139,7 @@ def test_basic_project_upgrade(v10_project_directory, caplog):
         input="\n",
         catch_exceptions=False,
     )
-    stdout = result.stdout
+    stdout = escape_ansi(result.stdout).strip()
 
     with open(
         file_relative_path(
@@ -143,9 +147,9 @@ def test_basic_project_upgrade(v10_project_directory, caplog):
             "../../../test_fixtures/upgrade_helper/test_basic_project_upgrade_expected_v012_stdout.fixture",
         )
     ) as f:
-        expected_stdout = f.read()
+        expected_stdout = f.read().strip()
         expected_stdout = expected_stdout.replace(
-            "GE_PROJECT_DIR", v10_project_directory
+            "GX_PROJECT_DIR", v10_project_directory
         )
         assert stdout == expected_stdout
 
@@ -194,7 +198,8 @@ great_expectations/
     assert obs_project_tree_str == expected_project_tree_str
     # make sure config number incremented
     assert (
-        DataContext.get_ge_config_version(context_root_dir=v10_project_directory) == 3
+        FileDataContext.get_ge_config_version(context_root_dir=v10_project_directory)
+        == 3
     )
 
     with open(
@@ -206,7 +211,7 @@ great_expectations/
         expected_upgrade_log_dict = json.load(f)
         expected_upgrade_log_str = json.dumps(expected_upgrade_log_dict)
         expected_upgrade_log_str = expected_upgrade_log_str.replace(
-            "GE_PROJECT_DIR", v10_project_directory
+            "GX_PROJECT_DIR", v10_project_directory
         )
         expected_upgrade_log_dict = json.loads(expected_upgrade_log_str)
 
@@ -241,7 +246,7 @@ def test_project_upgrade_with_manual_steps(
         input="\n",
         catch_exceptions=False,
     )
-    stdout = result.stdout
+    stdout = escape_ansi(result.stdout).strip()
 
     with open(
         file_relative_path(
@@ -249,9 +254,9 @@ def test_project_upgrade_with_manual_steps(
             "../../../test_fixtures/upgrade_helper/test_project_upgrade_with_manual_steps_expected_v012_stdout.fixture",
         )
     ) as f:
-        expected_stdout = f.read()
+        expected_stdout = f.read().strip()
         expected_stdout = expected_stdout.replace(
-            "GE_PROJECT_DIR", v10_project_directory
+            "GX_PROJECT_DIR", v10_project_directory
         )
         assert stdout == expected_stdout
 
@@ -307,7 +312,8 @@ great_expectations/
     assert obs_project_tree_str == expected_project_tree_str
     # make sure config number not incremented
     assert (
-        DataContext.get_ge_config_version(context_root_dir=v10_project_directory) == 1
+        FileDataContext.get_ge_config_version(context_root_dir=v10_project_directory)
+        == 1
     )
 
     with open(
@@ -319,7 +325,7 @@ great_expectations/
         expected_upgrade_log_dict = json.load(f)
         expected_upgrade_log_str = json.dumps(expected_upgrade_log_dict)
         expected_upgrade_log_str = expected_upgrade_log_str.replace(
-            "GE_PROJECT_DIR", v10_project_directory
+            "GX_PROJECT_DIR", v10_project_directory
         )
         expected_upgrade_log_dict = json.loads(expected_upgrade_log_str)
 
@@ -352,7 +358,7 @@ def test_project_upgrade_with_exception(v10_project_directory, caplog):
         input="\n",
         catch_exceptions=False,
     )
-    stdout = result.stdout
+    stdout = escape_ansi(result.stdout).strip()
 
     with open(
         file_relative_path(
@@ -360,9 +366,9 @@ def test_project_upgrade_with_exception(v10_project_directory, caplog):
             "../../../test_fixtures/upgrade_helper/test_project_upgrade_with_exception_expected_v012_stdout.fixture",
         )
     ) as f:
-        expected_stdout = f.read()
+        expected_stdout = f.read().strip()
         expected_stdout = expected_stdout.replace(
-            "GE_PROJECT_DIR", v10_project_directory
+            "GX_PROJECT_DIR", v10_project_directory
         )
         assert stdout == expected_stdout
 
@@ -410,7 +416,8 @@ great_expectations/
     assert obs_project_tree_str == expected_project_tree_str
     # make sure config number not incremented
     assert (
-        DataContext.get_ge_config_version(context_root_dir=v10_project_directory) == 1
+        FileDataContext.get_ge_config_version(context_root_dir=v10_project_directory)
+        == 1
     )
 
     with open(
@@ -422,7 +429,7 @@ great_expectations/
         expected_upgrade_log_dict = json.load(f)
         expected_upgrade_log_str = json.dumps(expected_upgrade_log_dict)
         expected_upgrade_log_str = expected_upgrade_log_str.replace(
-            "GE_PROJECT_DIR", v10_project_directory
+            "GX_PROJECT_DIR", v10_project_directory
         )
         expected_upgrade_log_str = expected_upgrade_log_str.replace(
             "GE_PATH", os.path.split(great_expectations.__file__)[0]
@@ -449,7 +456,7 @@ def test_v2_to_v3_project_upgrade(v20_project_directory, caplog):
         input="\n",
         catch_exceptions=False,
     )
-    stdout = result.stdout
+    stdout = escape_ansi(result.stdout).strip()
 
     with open(
         file_relative_path(
@@ -457,9 +464,9 @@ def test_v2_to_v3_project_upgrade(v20_project_directory, caplog):
             "../../../test_fixtures/upgrade_helper/test_v2_to_v3_project_upgrade_expected_v012_stdout.fixture",
         )
     ) as f:
-        expected_stdout = f.read()
+        expected_stdout = f.read().strip()
         expected_stdout = expected_stdout.replace(
-            "GE_PROJECT_DIR", v20_project_directory
+            "GX_PROJECT_DIR", v20_project_directory
         )
         assert stdout == expected_stdout
 
@@ -515,7 +522,8 @@ great_expectations/
     assert obs_project_tree_str == expected_project_tree_str
     # make sure config number incremented
     assert (
-        DataContext.get_ge_config_version(context_root_dir=v20_project_directory) == 3
+        FileDataContext.get_ge_config_version(context_root_dir=v20_project_directory)
+        == 3
     )
 
     with open(
@@ -527,7 +535,7 @@ great_expectations/
         expected_upgrade_log_dict = json.load(f)
         expected_upgrade_log_str = json.dumps(expected_upgrade_log_dict)
         expected_upgrade_log_str = expected_upgrade_log_str.replace(
-            "GE_PROJECT_DIR", v20_project_directory
+            "GX_PROJECT_DIR", v20_project_directory
         )
         expected_upgrade_log_dict = json.loads(expected_upgrade_log_str)
 
