@@ -10,6 +10,7 @@ from great_expectations.core.batch import (
     IDDict,
 )
 from great_expectations.core.batch_spec import RuntimeDataBatchSpec
+from great_expectations.core.id_dict import deep_convert_properties_iterable_to_id_dict
 from great_expectations.core.util import convert_to_json_serializable
 from great_expectations.exceptions import InvalidBatchSpecError
 
@@ -34,7 +35,9 @@ def test_id_dict_structure():
             "b2": 5,
         },
     }
-    nested_id_dictionary: IDDict = IDDict.convert_dictionary_to_id_dict(data=data)
+    nested_id_dictionary: IDDict = deep_convert_properties_iterable_to_id_dict(
+        source=data
+    )
     assert isinstance(nested_id_dictionary, IDDict)
     assert isinstance(nested_id_dictionary["a0"], int)
     assert isinstance(nested_id_dictionary["a1"], IDDict)
@@ -80,16 +83,16 @@ def test_iddict_is_hashable():
         "c0": "4",
         "c1": "5",
     }
-    # noinspection PyBroadException
+    # noinspection PyBroadException,PyUnusedLocal
     try:
         # noinspection PyUnusedLocal
-        dictionaries_as_set: set = {
-            IDDict.convert_dictionary_to_id_dict(data=data_0),
-            IDDict.convert_dictionary_to_id_dict(data=data_1),
-            IDDict.convert_dictionary_to_id_dict(data=data_2),
-            IDDict.convert_dictionary_to_id_dict(data=data_3),
+        dictionaries_as_set: set = {  # noqa: F841
+            deep_convert_properties_iterable_to_id_dict(source=data_0),
+            deep_convert_properties_iterable_to_id_dict(source=data_1),
+            deep_convert_properties_iterable_to_id_dict(source=data_2),
+            deep_convert_properties_iterable_to_id_dict(source=data_3),
         }
-    except Exception as e:
+    except Exception:
         assert False, "IDDict.__hash__() failed."
 
 
@@ -112,6 +115,7 @@ def test_batch_definition_instantiation():
         # noinspection PyTypeChecker,PyUnusedLocal,PyPep8Naming
         A = BatchDefinition("A", "a", "aaa", {"id": "A"})
 
+    # noinspection PyPep8Naming
     A = BatchDefinition("A", "a", "aaa", batch_identifiers=IDDict({"id": "A"}))
 
     print(A.id)
@@ -201,6 +205,7 @@ def test_batch_request_instantiation():
 
     # No data_source_name specified
     with pytest.raises(TypeError):
+        # noinspection PyArgumentList
         BatchRequest(
             data_connector_name="a",
             data_asset_name="aaa",
@@ -209,15 +214,18 @@ def test_batch_request_instantiation():
 
     # No data_source_name and data_connector_name specified
     with pytest.raises(TypeError):
+        # noinspection PyArgumentList
         BatchRequest(data_asset_name="aaa", data_connector_query={"id": "A"})
 
     # No data_source_name and data_connector_name and data_asset_name specified
     with pytest.raises(TypeError):
+        # noinspection PyArgumentList
         BatchRequest(data_connector_query={"id": "A"})
 
     BatchRequest(datasource_name="A", data_connector_name="a", data_asset_name="aaa")
 
 
+# noinspection PyPep8Naming
 @pytest.mark.unit
 def test_RuntimeDataBatchSpec():
     with pytest.raises(InvalidBatchSpecError):
