@@ -4,15 +4,14 @@ from unittest import mock
 import pytest
 
 from great_expectations.core.expectation_suite import ExpectationSuite
-from great_expectations.data_context.data_context.base_data_context import (
-    BaseDataContext,
+from great_expectations.data_context.cloud_constants import GXCloudRESTResource
+from great_expectations.data_context.data_context.cloud_data_context import (
+    CloudDataContext,
 )
-from great_expectations.data_context.store.ge_cloud_store_backend import (
-    GeCloudRESTResource,
-)
-from great_expectations.data_context.types.base import DataContextConfig, GeCloudConfig
-from great_expectations.data_context.types.resource_identifiers import GeCloudIdentifier
-from great_expectations.exceptions.exceptions import DataContextError
+from great_expectations.data_context.types.base import DataContextConfig, GXCloudConfig
+from great_expectations.data_context.types.resource_identifiers import GXCloudIdentifier
+from great_expectations.exceptions.exceptions import DataContextError, StoreBackendError
+from great_expectations.util import get_context
 from tests.data_context.conftest import MockResponse
 
 
@@ -135,13 +134,8 @@ def mocked_get_response(
             {
                 "data": {
                     "attributes": {
-                        "clause_id": "3199e1eb-3f68-473a-aca5-5e12324c3b92",
-                        "created_at": "2021-12-02T16:53:31.015139",
                         "created_by_id": "67dce9ed-9c41-4607-9f22-15c14cc82ac0",
-                        "deleted": False,
-                        "deleted_at": None,
                         "organization_id": "c8f9f2d0-fb5c-464b-bcc9-8a45b8144f44",
-                        "rendered_data_doc_id": None,
                         "suite": {
                             "data_asset_type": None,
                             "expectation_suite_name": "my_mock_suite",
@@ -157,6 +151,7 @@ def mocked_get_response(
                         },
                     },
                     "id": suite_id,
+                    "type": "expectation_suite",
                 }
             },
             200,
@@ -165,6 +160,59 @@ def mocked_get_response(
     return _mocked_get_response
 
 
+@pytest.fixture
+def mocked_404_response(
+    mock_response_factory: Callable,
+) -> Callable[[], MockResponse]:
+    def _mocked_get_response(*args, **kwargs):
+        return mock_response_factory(
+            {},
+            404,
+        )
+
+    return _mocked_get_response
+
+
+@pytest.fixture
+def mocked_get_by_name_response(
+    mock_response_factory: Callable,
+    suite_1: SuiteIdentifierTuple,
+) -> Callable[[], MockResponse]:
+    suite_id = suite_1.id
+
+    def _mocked_get_by_name_response(*args, **kwargs):
+        return mock_response_factory(
+            {
+                "data": [
+                    {
+                        "attributes": {
+                            "created_by_id": "67dce9ed-9c41-4607-9f22-15c14cc82ac0",
+                            "organization_id": "c8f9f2d0-fb5c-464b-bcc9-8a45b8144f44",
+                            "suite": {
+                                "data_asset_type": None,
+                                "expectation_suite_name": "my_mock_suite",
+                                "expectations": [
+                                    {
+                                        "expectation_type": "expect_column_to_exist",
+                                        "ge_cloud_id": "869771ee-a728-413d-96a6-8efc4dc70318",
+                                        "kwargs": {"column": "infinities"},
+                                        "meta": {},
+                                    },
+                                ],
+                                "ge_cloud_id": suite_id,
+                            },
+                        },
+                        "id": suite_id,
+                        "type": "expectation_suite",
+                    }
+                ]
+            },
+            200,
+        )
+
+    return _mocked_get_by_name_response
+
+
 @pytest.fixture
 def mock_list_expectation_suite_names() -> mock.MagicMock:
     """
@@ -176,6 +224,17 @@ def mock_list_expectation_suite_names() -> mock.MagicMock:
         yield mock_method
 
 
+@pytest.fixture
+def mock_list_expectation_suites() -> mock.MagicMock:
+    """
+    Expects a return value to be set within the test function.
+    """
+    with mock.patch(
+        "great_expectations.data_context.data_context.cloud_data_context.CloudDataContext.list_expectation_suites",
+    ) as mock_method:
+        yield mock_method
+
+
 @pytest.fixture
 def mock_expectations_store_has_key() -> mock.MagicMock:
     """
@@ -191,18 +250,20 @@ def mock_expectations_store_has_key() -> mock.MagicMock:
 @pytest.mark.cloud
 def test_list_expectation_suites(
     empty_ge_cloud_data_context_config: DataContextConfig,
-    ge_cloud_config: GeCloudConfig,
+    ge_cloud_config: GXCloudConfig,
     suite_1: SuiteIdentifierTuple,
     suite_2: SuiteIdentifierTuple,
     mock_get_all_suites_json: dict,
 ) -> None:
     project_path_name = "foo/bar/baz"
 
-    context = BaseDataContext(
+    context = get_context(
         project_config=empty_ge_cloud_data_context_config,
         context_root_dir=project_path_name,
-        ge_cloud_config=ge_cloud_config,
-        ge_cloud_mode=True,
+        cloud_base_url=ge_cloud_config.base_url,
+        cloud_access_token=ge_cloud_config.access_token,
+        cloud_organization_id=ge_cloud_config.organization_id,
+        cloud_mode=True,
     )
 
     with mock.patch("requests.Session.get", autospec=True) as mock_get:
@@ -212,14 +273,14 @@ def test_list_expectation_suites(
         suites = context.list_expectation_suites()
 
     assert suites == [
-        GeCloudIdentifier(
-            resource_type=GeCloudRESTResource.EXPECTATION_SUITE,
-            ge_cloud_id=suite_1.id,
+        GXCloudIdentifier(
+            resource_type=GXCloudRESTResource.EXPECTATION_SUITE,
+            cloud_id=suite_1.id,
             resource_name=suite_1.name,
         ),
-        GeCloudIdentifier(
-            resource_type=GeCloudRESTResource.EXPECTATION_SUITE,
-            ge_cloud_id=suite_2.id,
+        GXCloudIdentifier(
+            resource_type=GXCloudRESTResource.EXPECTATION_SUITE,
+            cloud_id=suite_2.id,
             resource_name=suite_2.name,
         ),
     ]
@@ -228,7 +289,7 @@ def test_list_expectation_suites(
 @pytest.mark.unit
 @pytest.mark.cloud
 def test_create_expectation_suite_saves_suite_to_cloud(
-    empty_base_data_context_in_cloud_mode: BaseDataContext,
+    empty_base_data_context_in_cloud_mode: CloudDataContext,
     mocked_post_response: Callable[[], MockResponse],
     mock_list_expectation_suite_names: mock.MagicMock,
 ) -> None:
@@ -249,28 +310,39 @@ def test_create_expectation_suite_saves_suite_to_cloud(
 @pytest.mark.unit
 @pytest.mark.cloud
 def test_create_expectation_suite_overwrites_existing_suite(
-    empty_base_data_context_in_cloud_mode: BaseDataContext,
-    mocked_post_response: Callable[[], MockResponse],
+    empty_base_data_context_in_cloud_mode: CloudDataContext,
     mock_list_expectation_suite_names: mock.MagicMock,
+    mock_list_expectation_suites: mock.MagicMock,
+    suite_1: SuiteIdentifierTuple,
 ) -> None:
     context = empty_base_data_context_in_cloud_mode
 
-    suite_name = "my_suite"
+    suite_name = suite_1.name
     existing_suite_names = [suite_name]
+    suite_id = suite_1.id
 
     with mock.patch(
-        "requests.Session.post", autospec=True, side_effect=mocked_post_response
+        "great_expectations.data_context.data_context.cloud_data_context.CloudDataContext.expectations_store"
     ):
         mock_list_expectation_suite_names.return_value = existing_suite_names
-        suite = context.create_expectation_suite(suite_name, overwrite_existing=True)
+        mock_list_expectation_suites.return_value = [
+            GXCloudIdentifier(
+                resource_type=GXCloudRESTResource.EXPECTATION,
+                cloud_id=suite_id,
+                resource_name=suite_name,
+            )
+        ]
+        suite = context.create_expectation_suite(
+            expectation_suite_name=suite_name, overwrite_existing=True
+        )
 
-    assert suite.ge_cloud_id is not None
+    assert suite.ge_cloud_id == suite_id
 
 
 @pytest.mark.unit
 @pytest.mark.cloud
 def test_create_expectation_suite_namespace_collision_raises_error(
-    empty_base_data_context_in_cloud_mode: BaseDataContext,
+    empty_base_data_context_in_cloud_mode: CloudDataContext,
     mock_list_expectation_suite_names: mock.MagicMock,
 ) -> None:
     context = empty_base_data_context_in_cloud_mode
@@ -288,23 +360,18 @@ def test_create_expectation_suite_namespace_collision_raises_error(
 @pytest.mark.unit
 @pytest.mark.cloud
 def test_delete_expectation_suite_deletes_suite_in_cloud(
-    empty_base_data_context_in_cloud_mode: BaseDataContext,
+    empty_base_data_context_in_cloud_mode: CloudDataContext,
     suite_1: SuiteIdentifierTuple,
-    mock_expectations_store_has_key: mock.MagicMock,
 ) -> None:
     context = empty_base_data_context_in_cloud_mode
     suite_id = suite_1.id
 
     with mock.patch("requests.Session.delete", autospec=True) as mock_delete:
-        mock_expectations_store_has_key.return_value = True
         context.delete_expectation_suite(ge_cloud_id=suite_id)
 
-    mock_expectations_store_has_key.assert_called_once_with(
-        GeCloudIdentifier(GeCloudRESTResource.EXPECTATION_SUITE, ge_cloud_id=suite_id)
-    )
     assert mock_delete.call_args[1]["json"] == {
         "data": {
-            "type": GeCloudRESTResource.EXPECTATION_SUITE,
+            "type": GXCloudRESTResource.EXPECTATION_SUITE,
             "id": suite_id,
             "attributes": {"deleted": True},
         }
@@ -314,70 +381,65 @@ def test_delete_expectation_suite_deletes_suite_in_cloud(
 @pytest.mark.unit
 @pytest.mark.cloud
 def test_delete_expectation_suite_nonexistent_suite_raises_error(
-    empty_base_data_context_in_cloud_mode: BaseDataContext,
+    empty_base_data_context_in_cloud_mode: CloudDataContext,
     suite_1: SuiteIdentifierTuple,
-    mock_expectations_store_has_key: mock.MagicMock,
+    mocked_404_response,
 ) -> None:
     context = empty_base_data_context_in_cloud_mode
     suite_id = suite_1.id
 
-    with pytest.raises(DataContextError) as e:
-        mock_expectations_store_has_key.return_value = False
-        context.delete_expectation_suite(ge_cloud_id=suite_id)
-
-    mock_expectations_store_has_key.assert_called_once_with(
-        GeCloudIdentifier(GeCloudRESTResource.EXPECTATION_SUITE, ge_cloud_id=suite_id)
-    )
-    assert f"expectation_suite with id {suite_id} does not exist" in str(e.value)
+    with pytest.raises(StoreBackendError):
+        with mock.patch(
+            "requests.Session.delete", autospec=True, side_effect=mocked_404_response
+        ):
+            context.delete_expectation_suite(ge_cloud_id=suite_id)
 
 
 @pytest.mark.unit
 @pytest.mark.cloud
-def test_get_expectation_suite_retrieves_suite_from_cloud(
-    empty_base_data_context_in_cloud_mode: BaseDataContext,
+def test_get_expectation_suite_by_name_retrieves_suite_from_cloud(
+    empty_base_data_context_in_cloud_mode: CloudDataContext,
     suite_1: SuiteIdentifierTuple,
-    mocked_get_response: Callable[[], MockResponse],
-    mock_expectations_store_has_key: mock.MagicMock,
+    mocked_get_by_name_response: Callable[[], MockResponse],
+    ge_cloud_base_url: str,
+    ge_cloud_organization_id: str,
 ) -> None:
     context = empty_base_data_context_in_cloud_mode
     suite_id = suite_1.id
 
     with mock.patch(
-        "requests.Session.get", autospec=True, side_effect=mocked_get_response
-    ):
-        mock_expectations_store_has_key.return_value = True
-        suite = context.get_expectation_suite(ge_cloud_id=suite_id)
+        "requests.Session.get", autospec=True, side_effect=mocked_get_by_name_response
+    ) as mock_get:
+        suite = context.get_expectation_suite(expectation_suite_name=suite_1.name)
+        mock_get.assert_called_with(
+            mock.ANY,
+            f"{ge_cloud_base_url}/organizations/{ge_cloud_organization_id}/expectation-suites",
+            params={"name": suite_1.name},
+        )
 
-    mock_expectations_store_has_key.assert_called_once_with(
-        GeCloudIdentifier(GeCloudRESTResource.EXPECTATION_SUITE, ge_cloud_id=suite_id)
-    )
     assert str(suite.ge_cloud_id) == str(suite_id)
 
 
 @pytest.mark.unit
 @pytest.mark.cloud
 def test_get_expectation_suite_nonexistent_suite_raises_error(
-    empty_base_data_context_in_cloud_mode: BaseDataContext,
-    mock_expectations_store_has_key: mock.MagicMock,
+    empty_base_data_context_in_cloud_mode: CloudDataContext, mocked_404_response
 ) -> None:
     context = empty_base_data_context_in_cloud_mode
 
     suite_id = "abc123"
 
-    with pytest.raises(DataContextError) as e:
-        mock_expectations_store_has_key.return_value = False
-        context.get_expectation_suite(ge_cloud_id=suite_id)
-
-    mock_expectations_store_has_key.assert_called_once_with(
-        GeCloudIdentifier(GeCloudRESTResource.EXPECTATION_SUITE, ge_cloud_id=suite_id)
-    )
-    assert f"expectation_suite with id {suite_id} not found" in str(e.value)
+    with pytest.raises(StoreBackendError):
+        with mock.patch(
+            "requests.Session.get", autospec=True, side_effect=mocked_404_response
+        ):
+            context.get_expectation_suite(ge_cloud_id=suite_id)
 
 
 @pytest.mark.unit
 @pytest.mark.cloud
 def test_save_expectation_suite_saves_suite_to_cloud(
-    empty_base_data_context_in_cloud_mode: BaseDataContext,
+    empty_base_data_context_in_cloud_mode: CloudDataContext,
     mocked_post_response: Callable[[], MockResponse],
 ) -> None:
     context = empty_base_data_context_in_cloud_mode
@@ -399,7 +461,7 @@ def test_save_expectation_suite_saves_suite_to_cloud(
 @pytest.mark.unit
 @pytest.mark.cloud
 def test_save_expectation_suite_overwrites_existing_suite(
-    empty_base_data_context_in_cloud_mode: BaseDataContext,
+    empty_base_data_context_in_cloud_mode: CloudDataContext,
     suite_1: SuiteIdentifierTuple,
 ) -> None:
     context = empty_base_data_context_in_cloud_mode
@@ -433,7 +495,7 @@ def test_save_expectation_suite_overwrites_existing_suite(
 @pytest.mark.unit
 @pytest.mark.cloud
 def test_save_expectation_suite_no_overwrite_namespace_collision_raises_error(
-    empty_base_data_context_in_cloud_mode: BaseDataContext,
+    empty_base_data_context_in_cloud_mode: CloudDataContext,
     mock_expectations_store_has_key: mock.MagicMock,
     mock_list_expectation_suite_names: mock.MagicMock,
 ) -> None:
@@ -458,7 +520,7 @@ def test_save_expectation_suite_no_overwrite_namespace_collision_raises_error(
 @pytest.mark.unit
 @pytest.mark.cloud
 def test_save_expectation_suite_no_overwrite_id_collision_raises_error(
-    empty_base_data_context_in_cloud_mode: BaseDataContext,
+    empty_base_data_context_in_cloud_mode: CloudDataContext,
     suite_1: SuiteIdentifierTuple,
     mock_expectations_store_has_key: mock.MagicMock,
 ) -> None:
@@ -475,12 +537,12 @@ def test_save_expectation_suite_no_overwrite_id_collision_raises_error(
         )
 
     mock_expectations_store_has_key.assert_called_once_with(
-        GeCloudIdentifier(
-            GeCloudRESTResource.EXPECTATION_SUITE,
-            ge_cloud_id=suite_id,
+        GXCloudIdentifier(
+            GXCloudRESTResource.EXPECTATION_SUITE,
+            cloud_id=suite_id,
             resource_name=suite_name,
         )
     )
-    assert f"expectation_suite with GE Cloud ID {suite_id} already exists" in str(
+    assert f"expectation_suite with GX Cloud ID {suite_id} already exists" in str(
         e.value
     )
