@@ -11,7 +11,6 @@ from great_expectations.core.expectation_validation_result import (
     ExpectationSuiteValidationResult,
     ExpectationValidationResult,
 )
-from great_expectations.core.metric import ValidationMetricIdentifier
 from great_expectations.core.run_identifier import RunIdentifier
 from great_expectations.data_context.data_context import DataContext
 from great_expectations.data_context.store import (
@@ -20,6 +19,9 @@ from great_expectations.data_context.store import (
     TupleGCSStoreBackend,
     TupleS3StoreBackend,
 )
+from great_expectations.data_context.types.resource_identifiers import (
+    ValidationMetricIdentifier,
+)
 from great_expectations.data_context.util import instantiate_class_from_config
 from tests.core.usage_statistics.util import (
     usage_stats_exceptions_exist,
