@@ -1,30 +1,23 @@
 import os
-from contextlib import contextmanager
-from unittest import mock
 
 import pytest
 
-import great_expectations.exceptions as gee
+import great_expectations.exceptions as gx_exceptions
 from great_expectations.data_context.util import (
     PasswordMasker,
     parse_substitution_variable,
-    secretmanager,
-    substitute_value_from_aws_secrets_manager,
-    substitute_value_from_azure_keyvault,
-    substitute_value_from_gcp_secret_manager,
-    substitute_value_from_secret_store,
 )
 from great_expectations.types import safe_deep_copy
 from great_expectations.util import load_class
 
 
 def test_load_class_raises_error_when_module_not_found():
-    with pytest.raises(gee.PluginModuleNotFoundError):
+    with pytest.raises(gx_exceptions.PluginModuleNotFoundError):
         load_class("foo", "bar")
 
 
 def test_load_class_raises_error_when_class_not_found():
-    with pytest.raises(gee.PluginClassNotFoundError):
+    with pytest.raises(gx_exceptions.PluginClassNotFoundError):
         load_class("TotallyNotARealClass", "great_expectations.datasource")
 
 
@@ -342,7 +335,7 @@ def test_sanitize_config_masks_cloud_store_backend_access_tokens(
                 ]["ge_cloud_credentials"]["access_token"]
                 == ge_cloud_access_token
             )
-            # expect that the GE Cloud token has been obscured
+            # expect that the GX Cloud token has been obscured
             assert (
                 store_config["store_backend"]["ge_cloud_credentials"]["access_token"]
                 != ge_cloud_access_token
@@ -502,229 +495,3 @@ def test_parse_substitution_variable():
     assert parse_substitution_variable("some_$tring") is None
     assert parse_substitution_variable("${SOME_$TRING}") is None
     assert parse_substitution_variable("$SOME_$TRING") == "SOME_"
-
-
-@contextmanager
-def does_not_raise():
-    yield
-
-
-@pytest.mark.parametrize(
-    "input_value,method_to_patch,return_value",
-    [
-        ("any_value", None, "any_value"),
-        ("secret|any_value", None, "secret|any_value"),
-        (
-            "secret|arn:aws:secretsmanager:region-name-1:123456789012:secret:my-secret",
-            "great_expectations.data_context.util.substitute_value_from_aws_secrets_manager",
-            "success",
-        ),
-        (
-            "secret|projects/project_id/secrets/my_secret",
-            "great_expectations.data_context.util.substitute_value_from_gcp_secret_manager",
-            "success",
-        ),
-        (
-            "secret|https://my-vault-name.vault.azure.net/secrets/my_secret",
-            "great_expectations.data_context.util.substitute_value_from_azure_keyvault",
-            "success",
-        ),
-    ],
-)
-def test_substitute_value_from_secret_store(input_value, method_to_patch, return_value):
-    if method_to_patch:
-        with mock.patch(method_to_patch, return_value=return_value):
-            assert substitute_value_from_secret_store(value=input_value) == return_value
-    else:
-        assert substitute_value_from_secret_store(value=input_value) == return_value
-
-
-class MockedBoto3Client:
-    def __init__(self, secret_response):
-        self.secret_response = secret_response
-
-    def get_secret_value(self, *args, **kwargs):
-        return self.secret_response
-
-
-class MockedBoto3Session:
-    def __init__(self, secret_response):
-        self.secret_response = secret_response
-
-    def __call__(self):
-        return self
-
-    def client(self, *args, **kwargs):
-        return MockedBoto3Client(self.secret_response)
-
-
-@pytest.mark.parametrize(
-    "input_value,secret_response,raises,expected",
-    [
-        (
-            "secret|arn:aws:secretsmanager:region-name-1:123456789012:secret:my-secret",
-            {"SecretString": "value"},
-            does_not_raise(),
-            "value",
-        ),
-        (
-            "secret|arn:aws:secretsmanager:region-name-1:123456789012:secret:my-secret",
-            {"SecretBinary": b"dmFsdWU="},
-            does_not_raise(),
-            "value",
-        ),
-        (
-            "secret|arn:aws:secretsmanager:region-name-1:123456789012:secret:my-secret|key",
-            {"SecretString": '{"key": "value"}'},
-            does_not_raise(),
-            "value",
-        ),
-        (
-            "secret|arn:aws:secretsmanager:region-name-1:123456789012:secret:my-secret|key",
-            {"SecretBinary": b"eyJrZXkiOiAidmFsdWUifQ=="},
-            does_not_raise(),
-            "value",
-        ),
-        (
-            "secret|arn:aws:secretsmanager:region-name-1:123456789012:secret:my-se%&et|key",
-            None,
-            pytest.raises(ValueError),
-            None,
-        ),
-        (
-            "secret|arn:aws:secretsmanager:region-name-1:123456789012:secret:my-secret:000000000-0000-0000-0000-00000000000|key",
-            None,
-            pytest.raises(ValueError),
-            None,
-        ),
-    ],
-)
-def test_substitute_value_from_aws_secrets_manager(
-    input_value, secret_response, raises, expected
-):
-    with raises:
-        with mock.patch(
-            "great_expectations.data_context.util.boto3.session.Session",
-            return_value=MockedBoto3Session(secret_response),
-        ):
-            assert substitute_value_from_aws_secrets_manager(input_value) == expected
-
-
-class MockedSecretManagerServiceClient:
-    def __init__(self, secret_response):
-        self.secret_response = secret_response
-
-    def __call__(self):
-        return self
-
-    def access_secret_version(self, *args, **kwargs):
-        class Response:
-            pass
-
-        response = Response()
-        response._pb = Response()
-        response._pb.payload = Response()
-        response._pb.payload.data = self.secret_response
-
-        return response
-
-
-@pytest.mark.skipif(
-    secretmanager is None,
-    reason="Could not import 'secretmanager' from google.cloud in data_context.util",
-)
-@pytest.mark.parametrize(
-    "input_value,secret_response,raises,expected",
-    [
-        (
-            "secret|projects/project_id/secrets/my_secret",
-            b"value",
-            does_not_raise(),
-            "value",
-        ),
-        (
-            "secret|projects/project_id/secrets/my_secret|key",
-            b'{"key": "value"}',
-            does_not_raise(),
-            "value",
-        ),
-        (
-            "secret|projects/project_id/secrets/my_se%&et|key",
-            None,
-            pytest.raises(ValueError),
-            None,
-        ),
-        (
-            "secret|projects/project_id/secrets/my_secret/version/A|key",
-            None,
-            pytest.raises(ValueError),
-            None,
-        ),
-    ],
-)
-def test_substitute_value_from_gcp_secret_manager(
-    input_value, secret_response, raises, expected
-):
-    with raises:
-        with mock.patch(
-            "great_expectations.data_context.util.secretmanager.SecretManagerServiceClient",
-            return_value=MockedSecretManagerServiceClient(secret_response),
-        ):
-            assert substitute_value_from_gcp_secret_manager(input_value) == expected
-
-
-class MockedSecretClient:
-    def __init__(self, secret_response):
-        self.secret_response = secret_response
-
-    def __call__(self, *args, **kwargs):
-        return self
-
-    def get_secret(self, *args, **kwargs):
-        class Response:
-            pass
-
-        response = Response()
-        response.value = self.secret_response
-        return response
-
-
-@mock.patch("great_expectations.data_context.util.DefaultAzureCredential", new=object)
-@pytest.mark.parametrize(
-    "input_value,secret_response,raises,expected",
-    [
-        (
-            "secret|https://my-vault-name.vault.azure.net/secrets/my-secret",
-            "value",
-            does_not_raise(),
-            "value",
-        ),
-        (
-            "secret|https://my-vault-name.vault.azure.net/secrets/my-secret|key",
-            '{"key": "value"}',
-            does_not_raise(),
-            "value",
-        ),
-        (
-            "secret|https://my-vault-name.vault.azure.net/secrets/my-se%&et|key",
-            None,
-            pytest.raises(ValueError),
-            None,
-        ),
-        (
-            "secret|https://my_vault_name.vault.azure.net/secrets/my-secret/A0000000000000000000000000000000|key",
-            None,
-            pytest.raises(ValueError),
-            None,
-        ),
-    ],
-)
-def test_substitute_value_from_azure_keyvault(
-    input_value, secret_response, raises, expected
-):
-    with raises:
-        with mock.patch(
-            "great_expectations.data_context.util.SecretClient",
-            return_value=MockedSecretClient(secret_response),
-        ):
-            assert substitute_value_from_azure_keyvault(input_value) == expected
