@@ -114,14 +114,14 @@ def test__file_object_caching_for_FileDataConnector(tmp_path_factory):
         assets={"stuff": {}},
     )
 
-    assert my_data_connector.get_data_reference_list_count() == 0
+    assert my_data_connector.get_data_reference_count() == 0
     assert len(my_data_connector.get_unmatched_data_references()) == 0
 
     # noinspection PyProtectedMember
     my_data_connector._refresh_data_references_cache()
 
     assert len(my_data_connector.get_unmatched_data_references()) == 0
-    assert my_data_connector.get_data_reference_list_count() == 4
+    assert my_data_connector.get_data_reference_count() == 4
 
 
 def test_get_batch_definition_list_from_batch_request():
