@@ -9,7 +9,7 @@ import pytest
 from moto import mock_s3
 from ruamel.yaml import YAML
 
-import great_expectations.exceptions.exceptions as ge_exceptions
+import great_expectations.exceptions.exceptions as gx_exceptions
 from great_expectations import DataContext
 from great_expectations.core.batch import BatchDefinition, BatchRequest, IDDict
 from great_expectations.data_context.util import instantiate_class_from_config
@@ -61,7 +61,7 @@ def test_basic_instantiation():
     # noinspection PyProtectedMember
     my_data_connector._refresh_data_references_cache()
 
-    assert my_data_connector.get_data_reference_list_count() == 4
+    assert my_data_connector.get_data_reference_count() == 4
     assert my_data_connector.get_unmatched_data_references() == []
 
     # Illegal execution environment name
@@ -973,7 +973,7 @@ def test_redundant_information_in_naming_convention_bucket_sorter_does_not_match
           """,
     )
 
-    with pytest.raises(ge_exceptions.DataConnectorError):
+    with pytest.raises(gx_exceptions.DataConnectorError):
         # noinspection PyUnusedLocal
         my_data_connector: InferredAssetS3DataConnector = instantiate_class_from_config(
             config=my_data_connector_yaml,
@@ -1038,7 +1038,7 @@ def test_redundant_information_in_naming_convention_bucket_too_many_sorters():
           """,
     )
 
-    with pytest.raises(ge_exceptions.DataConnectorError):
+    with pytest.raises(gx_exceptions.DataConnectorError):
         # noinspection PyUnusedLocal
         my_data_connector: InferredAssetS3DataConnector = instantiate_class_from_config(
             config=my_data_connector_yaml,
@@ -1057,7 +1057,7 @@ def test_redundant_information_in_naming_convention_bucket_too_many_sorters():
     "path,expectation",
     [("BUCKET/DIR/FILE.CSV", does_not_raise())]
     + [
-        (f"BUCKET/DIR/FILE{c}CSV", pytest.raises(ge_exceptions.ParserError))
+        (f"BUCKET/DIR/FILE{c}CSV", pytest.raises(gx_exceptions.ParserError))
         for c in INVALID_S3_CHARS
     ],
 )
