@@ -327,7 +327,7 @@ def test_s3_pandas_source_read_parquet(
     data_context_parameterized_expectation_suite.create_expectation_suite(
         expectation_suite_name="test_parquet"
     )
-    with pytest.deprecated_call():  # "Direct GE Support for the s3 BatchKwarg will be removed in v0.16.
+    with pytest.deprecated_call():  # "Direct GX Support for the s3 BatchKwarg will be removed in v0.16.
         batch = data_context_parameterized_expectation_suite.get_batch(
             data_context_parameterized_expectation_suite.build_batch_kwargs(
                 "parquet_source",
