@@ -1,6 +1,6 @@
 import os
 
-import great_expectations as ge
+import great_expectations as gx
 from great_expectations.core.batch import BatchRequest, RuntimeBatchRequest
 from great_expectations.core.yaml_handler import YAMLHandler
 
@@ -18,9 +18,9 @@ bigquery_dataset = "demo"
 
 CONNECTION_STRING = f"bigquery://{gcp_project}/{bigquery_dataset}"
 
-context = ge.get_context()
+context = gx.get_context()
 
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/bigquery_python_example.py datasource_config">
 datasource_config = {
     "name": "my_bigquery_datasource",
     "class_name": "Datasource",
@@ -45,11 +45,11 @@ datasource_config = {
 # In normal usage you'd set your path directly in the yaml above.
 datasource_config["execution_engine"]["connection_string"] = CONNECTION_STRING
 
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/bigquery_python_example.py test_yaml_config">
 context.test_yaml_config(yaml.dump(datasource_config))
 # </snippet>
 
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/bigquery_python_example.py add_datasource">
 context.add_datasource(**datasource_config)
 # </snippet>
 
@@ -71,10 +71,10 @@ validator = context.get_validator(
 print(validator.head())
 
 # NOTE: The following code is only for testing and can be ignored by users.
-assert isinstance(validator, ge.validator.validator.Validator)
+assert isinstance(validator, gx.validator.validator.Validator)
 
 # Test for BatchRequest naming a table.
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/bigquery_python_example.py batch_request">
 batch_request = BatchRequest(
     datasource_name="my_bigquery_datasource",
     data_connector_name="default_inferred_data_connector_name",
@@ -90,7 +90,7 @@ print(validator.head())
 # </snippet>
 
 # NOTE: The following code is only for testing and can be ignored by users.
-assert isinstance(validator, ge.validator.validator.Validator)
+assert isinstance(validator, gx.validator.validator.Validator)
 assert [ds["name"] for ds in context.list_datasources()] == ["my_bigquery_datasource"]
 assert "demo.taxi_data" in set(
     context.get_available_data_asset_names()["my_bigquery_datasource"][
