@@ -1,7 +1,7 @@
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/bigquery_yaml_example.py imports">
 import os
 
-import great_expectations as ge
+import great_expectations as gx
 from great_expectations.core.batch import BatchRequest, RuntimeBatchRequest
 from great_expectations.core.yaml_handler import YAMLHandler
 
@@ -20,11 +20,11 @@ bigquery_dataset = "demo"
 
 CONNECTION_STRING = f"bigquery://{gcp_project}/{bigquery_dataset}"
 
-# <snippet>
-context = ge.get_context()
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/bigquery_yaml_example.py get_context">
+context = gx.get_context()
 # </snippet>
 
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/bigquery_yaml_example.py datasource_yaml">
 datasource_yaml = f"""
 name: my_bigquery_datasource
 class_name: Datasource
@@ -49,16 +49,16 @@ datasource_yaml = datasource_yaml.replace(
     CONNECTION_STRING,
 )
 
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/bigquery_yaml_example.py test_yaml_config">
 context.test_yaml_config(datasource_yaml)
 # </snippet>
 
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/bigquery_yaml_example.py add_datasource">
 context.add_datasource(**yaml.load(datasource_yaml))
 # </snippet>
 
 # Test for RuntimeBatchRequest using a query.
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/database/bigquery_yaml_example.py runtime_batch_request">
 batch_request = RuntimeBatchRequest(
     datasource_name="my_bigquery_datasource",
     data_connector_name="default_runtime_data_connector_name",
@@ -77,7 +77,7 @@ print(validator.head())
 # </snippet>
 
 # NOTE: The following code is only for testing and can be ignored by users.
-assert isinstance(validator, ge.validator.validator.Validator)
+assert isinstance(validator, gx.validator.validator.Validator)
 
 # Test for BatchRequest naming a table.
 batch_request = BatchRequest(
@@ -94,7 +94,7 @@ validator = context.get_validator(
 print(validator.head())
 
 # NOTE: The following code is only for testing and can be ignored by users.
-assert isinstance(validator, ge.validator.validator.Validator)
+assert isinstance(validator, gx.validator.validator.Validator)
 assert [ds["name"] for ds in context.list_datasources()] == ["my_bigquery_datasource"]
 assert "demo.taxi_data" in set(
     context.get_available_data_asset_names()["my_bigquery_datasource"][
