@@ -2,7 +2,7 @@ import os
 
 from ruamel import yaml
 
-import great_expectations as ge
+import great_expectations as gx
 from great_expectations.core.batch import BatchRequest, RuntimeBatchRequest
 
 redshift_username = os.environ.get("REDSHIFT_USERNAME")
@@ -23,7 +23,7 @@ load_data_into_test_database(
     connection_string=CONNECTION_STRING,
 )
 
-context = ge.get_context()
+context = gx.get_context()
 
 datasource_yaml = f"""
 name: my_redshift_datasource
@@ -70,7 +70,7 @@ validator = context.get_validator(
 print(validator.head())
 
 # NOTE: The following code is only for testing and can be ignored by users.
-assert isinstance(validator, ge.validator.validator.Validator)
+assert isinstance(validator, gx.validator.validator.Validator)
 
 # Second test for BatchRequest naming a table
 batch_request = BatchRequest(
@@ -87,7 +87,7 @@ validator = context.get_validator(
 print(validator.head())
 
 # NOTE: The following code is only for testing and can be ignored by users.
-assert isinstance(validator, ge.validator.validator.Validator)
+assert isinstance(validator, gx.validator.validator.Validator)
 assert [ds["name"] for ds in context.list_datasources()] == ["my_redshift_datasource"]
 assert "taxi_data" in set(
     context.get_available_data_asset_names()["my_redshift_datasource"][
