@@ -1,9 +1,9 @@
 from ruamel import yaml
 
-import great_expectations as ge
+import great_expectations as gx
 from great_expectations.core.batch import BatchRequest
 
-context = ge.get_context()
+context = gx.get_context()
 
 # YAML
 datasource_yaml = r"""
@@ -87,7 +87,7 @@ validator = context.get_validator(
 print(validator.head())
 
 # NOTE: The following code is only for testing and can be ignored by users.
-assert isinstance(validator, ge.validator.validator.Validator)
+assert isinstance(validator, gx.validator.validator.Validator)
 assert [ds["name"] for ds in context.list_datasources()] == ["taxi_datasource"]
 assert "yellow_tripdata" in set(
     context.get_available_data_asset_names()["taxi_datasource"][
@@ -251,7 +251,7 @@ validator = context.get_validator(
 )
 
 # NOTE: The following code is only for testing and can be ignored by users.
-assert isinstance(validator, ge.validator.validator.Validator)
+assert isinstance(validator, gx.validator.validator.Validator)
 assert [ds["name"] for ds in context.list_datasources()] == ["taxi_datasource"]
 assert "yellow_tripdata" in set(
     context.get_available_data_asset_names()["taxi_datasource"][
