@@ -1,10 +1,10 @@
 import pandas as pd
 from ruamel import yaml
 
-import great_expectations as ge
+import great_expectations as gx
 from great_expectations.core.batch import RuntimeBatchRequest
 
-context = ge.get_context()
+context = gx.get_context()
 
 # YAML
 datasource_yaml = r"""
@@ -69,7 +69,7 @@ validator = context.get_validator(
 print(validator.head())
 
 # NOTE: The following code is only for testing and can be ignored by users.
-assert isinstance(validator, ge.validator.validator.Validator)
+assert isinstance(validator, gx.validator.validator.Validator)
 assert [ds["name"] for ds in context.list_datasources()] == ["taxi_datasource"]
 assert "<YOUR MEANINGFUL NAME>" in set(
     context.get_available_data_asset_names()["taxi_datasource"][
@@ -97,7 +97,7 @@ validator = context.get_validator(
 print(validator.head())
 
 # NOTE: The following code is only for testing and can be ignored by users.
-assert isinstance(validator, ge.validator.validator.Validator)
+assert isinstance(validator, gx.validator.validator.Validator)
 assert [ds["name"] for ds in context.list_datasources()] == ["taxi_datasource"]
 assert "<YOUR MEANINGFUL NAME>" in set(
     context.get_available_data_asset_names()["taxi_datasource"][
