@@ -1,9 +1,9 @@
 from ruamel import yaml
 
-import great_expectations as ge
+import great_expectations as gx
 from great_expectations.core.batch import BatchRequest
 
-context = ge.get_context()
+context = gx.get_context()
 
 # YAML
 datasource_yaml = r"""
@@ -304,7 +304,7 @@ validator = context.get_validator(
 )
 
 # NOTE: The following code is only for testing and can be ignored by users.
-assert isinstance(validator, ge.validator.validator.Validator)
+assert isinstance(validator, gx.validator.validator.Validator)
 
 batch_request = BatchRequest(
     datasource_name="taxi_datasource",
@@ -319,7 +319,7 @@ validator = context.get_validator(
 )
 
 # NOTE: The following code is only for testing and can be ignored by users.
-assert isinstance(validator, ge.validator.validator.Validator)
+assert isinstance(validator, gx.validator.validator.Validator)
 assert validator.active_batch_definition.batch_identifiers == {
     "year": "2019",
     "month": "02",
