@@ -1,8 +1,8 @@
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/how_to_create_a_batch_of_data_from_an_in_memory_pandas_dataframe.py imports">
 import pandas as pd
 from ruamel import yaml
 
-import great_expectations as ge
+import great_expectations as gx
 from great_expectations import DataContext
 from great_expectations.core import ExpectationSuite
 from great_expectations.core.batch import RuntimeBatchRequest
@@ -10,23 +10,23 @@ from great_expectations.validator.validator import Validator
 
 # </snippet>
 
-# <snippet>
-context: DataContext = ge.get_context()
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/how_to_create_a_batch_of_data_from_an_in_memory_pandas_dataframe.py get_context">
+context: DataContext = gx.get_context()
 # </snippet>
 
 # create and load Expectation Suite
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/how_to_create_a_batch_of_data_from_an_in_memory_pandas_dataframe.py create_expectation_suite">
 context.create_expectation_suite(
     expectation_suite_name="insert_your_expectation_suite_name_here"
 )
 # </snippet>
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/how_to_create_a_batch_of_data_from_an_in_memory_pandas_dataframe.py get_expectation_suite">
 suite: ExpectationSuite = context.get_expectation_suite(
     expectation_suite_name="insert_your_expectation_suite_name_here"
 )
 # </snippet>
 
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/how_to_create_a_batch_of_data_from_an_in_memory_pandas_dataframe.py datasource_yaml">
 datasource_yaml = f"""
 name: my_pandas_datasource
 class_name: Datasource
@@ -43,22 +43,22 @@ data_connectors:
 """
 # </snippet>
 
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/how_to_create_a_batch_of_data_from_an_in_memory_pandas_dataframe.py add_datasource">
 context.add_datasource(**yaml.load(datasource_yaml))
 # </snippet>
 
 # RuntimeBatchRequest with batch_data as Pandas Dataframe
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/how_to_create_a_batch_of_data_from_an_in_memory_pandas_dataframe.py path_to_file">
 path_to_file: str = "some_path.csv"
 # </snippet>
 
 # Please note this override is only to provide good UX for docs and tests.
 path_to_file: str = "./data/yellow_tripdata_sample_2019-01.csv"
 
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/how_to_create_a_batch_of_data_from_an_in_memory_pandas_dataframe.py read_csv">
 df: pd.DataFrame = pd.read_csv(path_to_file)
 # </snippet>
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/how_to_create_a_batch_of_data_from_an_in_memory_pandas_dataframe.py runtime_batch_request">
 runtime_batch_request = RuntimeBatchRequest(
     datasource_name="my_pandas_datasource",
     data_connector_name="my_runtime_data_connector",
@@ -72,7 +72,7 @@ runtime_batch_request = RuntimeBatchRequest(
 # </snippet>
 
 # RuntimeBatchRequest with path
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/how_to_create_a_batch_of_data_from_an_in_memory_pandas_dataframe.py runtime_batch_request_with_path">
 runtime_batch_request = RuntimeBatchRequest(
     datasource_name="my_pandas_datasource",
     data_connector_name="my_runtime_data_connector",
@@ -90,7 +90,7 @@ runtime_batch_request = RuntimeBatchRequest(
 # </snippet>
 
 # Constructing Validator by passing in RuntimeBatchRequest
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/how_to_create_a_batch_of_data_from_an_in_memory_pandas_dataframe.py get_validator_runtime_batch_request">
 my_validator: Validator = context.get_validator(
     batch_request=runtime_batch_request,
     expectation_suite=suite,  # OR
@@ -100,7 +100,7 @@ my_validator: Validator = context.get_validator(
 # my_validator.head()
 
 # Constructing Validator by passing in arguments
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/how_to_create_a_batch_of_data_from_an_in_memory_pandas_dataframe.py get_validator_args">
 my_validator: Validator = context.get_validator(
     datasource_name="my_pandas_datasource",
     data_connector_name="my_runtime_data_connector",
@@ -118,6 +118,6 @@ my_validator: Validator = context.get_validator(
     # expectation_suite_name=suite_name
 )
 # </snippet>
-# <snippet>
+# <snippet name="tests/integration/docusaurus/connecting_to_your_data/how_to_create_a_batch_of_data_from_an_in_memory_pandas_dataframe.py validator_head">
 my_validator.head()
 # </snippet>
