@@ -1,10 +1,10 @@
 import pandas as pd
 from ruamel import yaml
 
-import great_expectations as ge
+import great_expectations as gx
 from great_expectations.core.batch import RuntimeBatchRequest
 
-context = ge.get_context()
+context = gx.get_context()
 
 datasource_yaml = f"""
 name: example_datasource
@@ -45,4 +45,4 @@ validator = context.get_validator(
 print(validator.head())
 
 # NOTE: The following code is only for testing and can be ignored by users.
-assert isinstance(validator, ge.validator.validator.Validator)
+assert isinstance(validator, gx.validator.validator.Validator)
