@@ -1,15 +1,15 @@
 from ruamel import yaml
 
-import great_expectations as ge
-from great_expectations.core.batch import BatchRequest, RuntimeBatchRequest
-from great_expectations.data_context import BaseDataContext
+import great_expectations as gx
+from great_expectations.core.batch import RuntimeBatchRequest
 from great_expectations.data_context.types.base import (
     DataContextConfig,
     InMemoryStoreBackendDefaults,
 )
+from great_expectations.util import get_context
 
 # Set up a basic spark session
-spark = ge.core.util.get_or_create_spark_application()
+spark = gx.core.util.get_or_create_spark_application()
 
 # basic dataframe
 data = [
@@ -27,7 +27,7 @@ data_context_config = DataContextConfig(
     store_backend_defaults=store_backend_defaults,
     checkpoint_store_name=store_backend_defaults.checkpoint_store_name,
 )
-context = BaseDataContext(project_config=data_context_config)
+context = get_context(project_config=data_context_config)
 
 datasource_config = {
     "name": "my_spark_dataframe",
@@ -63,7 +63,7 @@ validator = context.get_validator(
 print(validator.head())
 
 # NOTE: The following code is only for testing and can be ignored by users.
-assert isinstance(validator, ge.validator.validator.Validator)
+assert isinstance(validator, gx.validator.validator.Validator)
 assert [ds["name"] for ds in context.list_datasources()] == ["my_spark_dataframe"]
 assert set(
     context.get_available_data_asset_names()["my_spark_dataframe"][
