@@ -117,10 +117,12 @@ def test_batches_are_accessible(
             )
         )
         assert metric_max == (total_batches + 1) - batch_num
-        metric_value_set = validator.get_metric(
-            MetricConfiguration(
-                "column.distinct_values",
-                metric_domain_kwargs={"column": "string_cardinality_3"},
+        metric_value_set = set(
+            validator.get_metric(
+                MetricConfiguration(
+                    "column.distinct_values",
+                    metric_domain_kwargs={"column": "string_cardinality_3"},
+                )
             )
         )
         assert metric_value_set == {"category0", "category1", "category2"}
@@ -173,10 +175,7 @@ def test_profile_includes_citations(
 
     # noinspection PyUnresolvedReferences
     actual_events: List[unittest.mock._Call] = mock_emit.call_args_list
-    assert (
-        actual_events[-1][0][0]["event"]
-        == UsageStatsEvents.RULE_BASED_PROFILER_RUN.value
-    )
+    assert actual_events[-1][0][0]["event"] == UsageStatsEvents.RULE_BASED_PROFILER_RUN
 
 
 @mock.patch(
@@ -230,5 +229,5 @@ def test_profile_get_expectation_suite(
     actual_events: List[unittest.mock._Call] = mock_emit.call_args_list
     assert (
         actual_events[-1][0][0]["event"]
-        == UsageStatsEvents.RULE_BASED_PROFILER_RESULT_GET_EXPECTATION_SUITE.value
+        == UsageStatsEvents.RULE_BASED_PROFILER_RESULT_GET_EXPECTATION_SUITE
     )
