@@ -20,6 +20,7 @@ from great_expectations.render.renderer.content_block import (
     ProfilingColumnPropertiesTableContentBlockRenderer,
     ValidationResultsTableContentBlockRenderer,
 )
+from great_expectations.render.renderer_configuration import MetaNotesFormat
 from great_expectations.self_check.util import (
     expectationSuiteSchema,
     expectationSuiteValidationResultSchema,
@@ -91,6 +92,7 @@ def test_render_profiling_results_column_section_renderer(titanic_validation_res
                 "./output/test_render_profiling_results_column_section_renderer__"
                 + column
                 + ".json",
+                strict=False,
             ),
             "w",
         ) as outfile:
@@ -125,6 +127,7 @@ def test_render_expectation_suite_column_section_renderer(titanic_expectations):
                 "./output/test_render_expectation_suite_column_section_renderer"
                 + column
                 + ".json",
+                strict=False,
             ),
             "w",
         ) as outfile:
@@ -413,7 +416,7 @@ def test_ExpectationSuiteColumnSectionRenderer_expectation_with_markdown_meta_no
         meta={
             "BasicDatasetProfiler": {"confidence": "very low"},
             "notes": {
-                "format": "markdown",
+                "format": MetaNotesFormat.MARKDOWN,
                 "content": [
                     "#### These are expectation notes \n - you can use markdown \n - or just strings"
                 ],
@@ -575,7 +578,7 @@ def test_ExpectationSuiteColumnSectionRenderer_expectation_with_string_list_meta
         meta={
             "BasicDatasetProfiler": {"confidence": "very low"},
             "notes": {
-                "format": "string",
+                "format": MetaNotesFormat.STRING,
                 "content": [
                     "This is a",
                     "string list,",
@@ -740,7 +743,7 @@ def test_ExpectationSuiteColumnSectionRenderer_expectation_with_single_string_me
         meta={
             "BasicDatasetProfiler": {"confidence": "very low"},
             "notes": {
-                "format": "string",
+                "format": MetaNotesFormat.STRING,
                 "content": "This is just a single string, assigned to the 'content' key of a notes dict.",
             },
         },
@@ -1431,6 +1434,7 @@ def test_ValidationResultsTableContentBlockRenderer_generate_expectation_row_hap
 
 
 # noinspection PyPep8Naming
+@pytest.mark.integration
 def test_ValidationResultsTableContentBlockRenderer_generate_expectation_row_happy_path_with_eval_parameter():
     evr = ExpectationValidationResult(
         success=True,
@@ -1568,6 +1572,112 @@ def test_ValidationResultsTableContentBlockRenderer_generate_expectation_row_hap
         "table_options": {"search": True, "icon-size": "sm"},
     }
 
+    # also test case where evaluation_parameters aren't required at runtime such as using now()
+    evr = ExpectationValidationResult(
+        success=True,
+        result={
+            "observed_value": True,
+            "element_count": 162,
+            "missing_count": 153,
+            "missing_percent": 94.44444444444444,
+        },
+        exception_info={
+            "raised_exception": False,
+            "exception_message": None,
+            "exception_traceback": None,
+        },
+        expectation_config=ExpectationConfiguration(
+            expectation_type="expect_column_min_to_be_between",
+            kwargs={
+                "column": "start_date",
+                "min_value": {"$PARAMETER": "now() - timedelta(weeks=208)"},
+                "max_value": {"$PARAMETER": "now() - timedelta(weeks=1)"},
+                "result_format": "SUMMARY",
+            },
+        ),
+    )
+
+    result = ValidationResultsTableContentBlockRenderer.render(
+        [evr],
+    ).to_json_dict()
+
+    assert result == {
+        "content_block_type": "table",
+        "styling": {
+            "body": {"classes": ["table"]},
+            "classes": [
+                "ml-2",
+                "mr-2",
+                "mt-0",
+                "mb-0",
+                "table-responsive",
+                "hide-succeeded-validations-column-section-target-child",
+            ],
+        },
+        "table": [
+            [
+                {
+                    "content_block_type": "string_template",
+                    "styling": {
+                        "parent": {
+                            "classes": ["hide-succeeded-validation-target-child"]
+                        }
+                    },
+                    "string_template": {
+                        "template": "$icon",
+                        "params": {"icon": "", "markdown_status_icon": "✅"},
+                        "styling": {
+                            "params": {
+                                "icon": {
+                                    "classes": [
+                                        "fas",
+                                        "fa-check-circle",
+                                        "text-success",
+                                    ],
+                                    "tag": "i",
+                                }
+                            }
+                        },
+                    },
+                },
+                {
+                    "content_block_type": "string_template",
+                    "string_template": {
+                        "params": {
+                            "column": "start_date",
+                            "condition_parser": None,
+                            "max_value": {
+                                "$PARAMETER": "now() " "- " "timedelta(weeks=1)"
+                            },
+                            "min_value": {
+                                "$PARAMETER": "now() " "- " "timedelta(weeks=208)"
+                            },
+                            "parse_strings_as_datetimes": None,
+                            "result_format": "SUMMARY",
+                            "row_condition": None,
+                            "strict_max": None,
+                            "strict_min": None,
+                        },
+                        "styling": {
+                            "default": {"classes": ["badge", "badge-secondary"]},
+                            "params": {
+                                "column": {"classes": ["badge", "badge-primary"]}
+                            },
+                        },
+                        "template": "$column minimum value must be "
+                        "greater than or equal to "
+                        "$min_value and less than or "
+                        "equal to $max_value.",
+                    },
+                },
+                "True",
+            ]
+        ],
+        "header_row": ["Status", "Expectation", "Observed Value"],
+        "header_row_options": {"Status": {"sortable": True}},
+        "table_options": {"search": True, "icon-size": "sm"},
+    }
+
 
 # noinspection PyPep8Naming
 @pytest.mark.filterwarnings(
