@@ -4,22 +4,23 @@ from collections import OrderedDict
 
 import pytest
 
-import great_expectations as ge
+import great_expectations as gx
 from great_expectations import DataContext
 from great_expectations.core import ExpectationConfiguration, ExpectationSuite
 from great_expectations.core.expectation_validation_result import (
     ExpectationSuiteValidationResultSchema,
 )
-from great_expectations.render.renderer import (
-    ExpectationSuitePageRenderer,
-    ValidationResultsPageRenderer,
-)
-from great_expectations.render.types import (
+from great_expectations.render import (
     RenderedDocumentContent,
     RenderedHeaderContent,
     RenderedSectionContent,
     RenderedTableContent,
 )
+from great_expectations.render.renderer import (
+    ExpectationSuitePageRenderer,
+    ValidationResultsPageRenderer,
+)
+from great_expectations.render.renderer_configuration import MetaNotesFormat
 from great_expectations.render.view import DefaultMarkdownPageView
 from great_expectations.validation_operators.types.validation_operator_result import (
     ValidationOperatorResult,
@@ -74,7 +75,7 @@ def expectation_suite_to_render_with_notes(empty_data_context):
                             "Example notes about this expectation. **Markdown** `Supported`.",
                             "Second example note **with** *Markdown*",
                         ],
-                        "format": "markdown",
+                        "format": MetaNotesFormat.MARKDOWN,
                     }
                 },
             ),
@@ -114,7 +115,7 @@ def test_render_section_page():
         }
     )
 
-    rendered_doc = ge.render.view.view.DefaultMarkdownPageView().render(
+    rendered_doc = gx.render.view.view.DefaultMarkdownPageView().render(
         RenderedDocumentContent(sections=[section])
     )
 
