@@ -1,15 +1,22 @@
+import logging
 import os
+import sys
 from typing import List
 
+import pandas as pd
 import pytest
 
-import great_expectations as ge
+import great_expectations as gx
+from great_expectations import DataContext
 from great_expectations.core import ExpectationSuite
 from great_expectations.core.batch import BatchRequest
 from great_expectations.core.yaml_handler import YAMLHandler
 from great_expectations.data_context.util import file_relative_path
 
 yaml: YAMLHandler = YAMLHandler()
+
+logger = logging.getLogger(__name__)
+
 # constants used by the sql example
 pg_hostname = os.getenv("GE_TEST_LOCAL_DB_HOSTNAME", "localhost")
 CONNECTION_STRING: str = f"postgresql+psycopg2://postgres:@{pg_hostname}/test_ci"
@@ -35,7 +42,7 @@ def test_pandas_happy_path_onboarding_data_assistant(empty_data_context) -> None
     This test tests the code in `DataAssistants_Instantiation_And_Running-OnboardingAssistant-Pandas.ipynb`
 
     """
-    data_context: ge.DataContext = empty_data_context
+    data_context: gx.DataContext = empty_data_context
     taxi_data_path: str = file_relative_path(
         __file__, os.path.join("..", "..", "test_sets", "taxi_yellow_tripdata_samples")
     )
@@ -143,7 +150,7 @@ def test_spark_happy_path_onboarding_data_assistant(
     from pyspark.sql.types import StructType
 
     schema: StructType = spark_df_taxi_data_schema
-    data_context: ge.DataContext = empty_data_context
+    data_context: gx.DataContext = empty_data_context
     taxi_data_path: str = file_relative_path(
         __file__, os.path.join("..", "..", "test_sets", "taxi_yellow_tripdata_samples")
     )
@@ -252,7 +259,7 @@ def test_sql_happy_path_onboarding_data_assistant(
     else:
         load_data_into_postgres_database(sa)
 
-    data_context: ge.DataContext = empty_data_context
+    data_context: gx.DataContext = empty_data_context
 
     datasource_config = {
         "name": "taxi_multi_batch_sql_datasource",
@@ -330,6 +337,164 @@ def test_sql_happy_path_onboarding_data_assistant(
     assert results.success is False
 
 
+@pytest.mark.skipif(sys.version_info < (3, 8), reason="requires Python3.8")
+@pytest.mark.integration
+@pytest.mark.slow  # 6.54 seconds
+def test_sql_happy_path_onboarding_data_assistant_null_column_quantiles_metric_values(
+    sa,
+    empty_data_context,
+) -> None:
+    context: DataContext = empty_data_context
+
+    db_file = file_relative_path(
+        __file__,
+        os.path.join(
+            "..",
+            "..",
+            "test_sets",
+            "taxi_yellow_tripdata_samples",
+            "sqlite",
+            "yellow_tripdata.db",
+        ),
+    )
+
+    datasource = context.sources.add_sqlite(
+        name="test_datasource",
+        connection_string=f"sqlite:///{db_file}",
+    )
+
+    table_name = "yellow_tripdata_sample_2019_01"
+    split_col = "pickup_datetime"
+    asset = (
+        datasource.add_table_asset(
+            name="my_asset",
+            table_name=table_name,
+        )
+        .add_year_and_month_splitter(column_name=split_col)
+        .add_sorters(["year", "month"])
+    )
+
+    batch_request = asset.get_batch_request({"year": 2019, "month": 1})
+
+    result = context.assistants.onboarding.run(
+        batch_request=batch_request,
+        numeric_columns_rule={
+            "estimator": "exact",
+            "random_seed": 2022080401,
+        },
+    )
+    assert len(result.metrics_by_domain) == 36
+    assert len(result.expectation_configurations) == 122
+
+
+@pytest.mark.integration
+@pytest.mark.slow  # 26.57 seconds
+def test_sql_happy_path_onboarding_data_assistant_mixed_decimal_float_and_boolean_column_unique_proportion_metric_values(
+    empty_data_context,
+    test_backends,
+    sa,
+) -> None:
+    if "postgresql" not in test_backends:
+        pytest.skip("testing data assistant in sql requires postgres backend")
+
+    context: DataContext = empty_data_context
+    postgresql_engine: sa.engine.Engine = sa.create_engine(CONNECTION_STRING)
+    # noinspection PyUnusedLocal
+    conn: sa.engine.Connection = postgresql_engine.connect()
+
+    table_name = "sampled_yellow_tripdata_test"
+
+    try:
+        csv_path: str = file_relative_path(
+            __file__,
+            os.path.join(
+                "..",
+                "..",
+                "test_sets",
+                "taxi_yellow_tripdata_samples",
+                "samples_2021",
+                "yellow_tripdata_sample_2021.csv",
+            ),
+        )
+        df: pd.DataFrame = pd.read_csv(filepath_or_buffer=csv_path)
+        df["test_bool"] = df.apply(
+            lambda row: True if row["test_bool"] == "t" else False, axis=1
+        )
+        df.to_sql(
+            name=table_name,
+            con=postgresql_engine,
+            schema="public",
+            index=False,
+            dtype={
+                "VendorID": sa.types.BIGINT(),
+                "tpep_pickup_datetime": sa.DateTime(),
+                "tpep_dropoff_datetime": sa.DateTime(),
+                "passenger_count": sa.types.INTEGER(),
+                "trip_distance": sa.types.NUMERIC(),
+                "RatecodeID": sa.types.INTEGER(),
+                "store_and_fwd_flag": sa.types.TEXT(),
+                "PULocationID": sa.types.BIGINT(),
+                "DOLocationID": sa.types.BIGINT(),
+                "payment_type": sa.types.BIGINT(),
+                "fare_amount": sa.types.NUMERIC(),
+                "extra": sa.types.NUMERIC(),
+                "mta_tax": sa.types.NUMERIC(),
+                "tip_amount": sa.types.NUMERIC(),
+                "tolls_amount": sa.types.NUMERIC(),
+                "improvement_surcharge": sa.types.NUMERIC(),
+                "total_amount": sa.types.NUMERIC(),
+                "congestion_surcharge": sa.types.NUMERIC(),
+                "test_bool": sa.types.Boolean(),
+            },
+            if_exists="replace",
+        )
+    except ValueError as ve:
+        logger.warning(f"Unable to store information into database: {str(ve)}")
+
+    batch_options = {"year": 2021}
+
+    data_asset = (
+        context.sources.add_postgres(
+            name="postgres_demo_datasource",
+            connection_string=CONNECTION_STRING,
+        )
+        .add_table_asset(
+            name="sampled_yellow_tripdata_test",
+            table_name=table_name,
+        )
+        .add_year_and_month_splitter(column_name="tpep_pickup_datetime")
+        .add_sorters(["year", "-month"])
+    )
+
+    batch_request = data_asset.get_batch_request(batch_options)
+
+    result = context.assistants.onboarding.run(
+        batch_request=batch_request,
+        numeric_columns_rule={
+            "estimator": "exact",
+            "random_seed": 2022080401,
+        },
+    )
+    assert len(result.metrics_by_domain) == 49
+    assert len(result.expectation_configurations) == 171
+    assert list(
+        filter(
+            lambda element: element.expectation_type
+            == "expect_column_proportion_of_unique_values_to_be_between"
+            and element.kwargs["column"] == "test_bool",
+            result.get_expectation_suite(
+                send_usage_event=False
+            ).get_column_expectations(),
+        )
+    )[0].kwargs == {
+        "column": "test_bool",
+        "min_value": 0.001002004008016032,
+        "strict_max": False,
+        "max_value": 0.5,
+        "strict_min": False,
+    }
+
+
 def load_data_into_postgres_database(sa):
     """
     Method to load our 2019 and 2020 taxi data into a postgres database.  This is a helper method
