@@ -4,8 +4,8 @@ import pytest
 
 from great_expectations import DataContext
 from great_expectations.core.batch import BatchRequest
+from great_expectations.core.domain import Domain
 from great_expectations.core.metric_domain_types import MetricDomainTypes
-from great_expectations.rule_based_profiler.domain import Domain
 from great_expectations.rule_based_profiler.domain_builder import (
     MapMetricColumnDomainBuilder,
 )
