@@ -2,11 +2,12 @@ from typing import Dict, Optional
 
 import pytest
 
+from great_expectations.core.domain import Domain
 from great_expectations.core.metric_domain_types import MetricDomainTypes
 from great_expectations.data_context import DataContext
-from great_expectations.rule_based_profiler.domain import Domain
 from great_expectations.rule_based_profiler.parameter_builder import (
     MetricMultiBatchParameterBuilder,
+    ParameterBuilder,
 )
 from great_expectations.rule_based_profiler.parameter_container import (
     DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
@@ -34,16 +35,18 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_default(
     }
 
     # Omitting "single_batch_mode" argument in order to exercise default (False) behavior.
-    metric_multi_batch_parameter_builder = MetricMultiBatchParameterBuilder(
-        name="row_count_range",
-        metric_name="table.row_count",
-        metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
-        metric_value_kwargs=None,
-        enforce_numeric_metric=True,
-        replace_nan_with_zero=True,
-        reduce_scalar_metric=True,
-        evaluation_parameter_builder_configs=None,
-        data_context=data_context,
+    metric_multi_batch_parameter_builder: ParameterBuilder = (
+        MetricMultiBatchParameterBuilder(
+            name="row_count",
+            metric_name="table.row_count",
+            metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+            metric_value_kwargs=None,
+            enforce_numeric_metric=True,
+            replace_nan_with_zero=True,
+            reduce_scalar_metric=True,
+            evaluation_parameter_builder_configs=None,
+            data_context=data_context,
+        )
     )
 
     domain = Domain(
@@ -51,7 +54,7 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_default(
         rule_name="my_rule",
     )
     parameter_container = ParameterContainer(parameter_nodes=None)
-    parameters: Dict[str, ParameterContainer] = {
+    parameters: Dict[str, ParameterContainer | None] = {
         domain.id: parameter_container,
     }
 
@@ -64,6 +67,7 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_default(
         variables=variables,
         parameters=parameters,
         batch_request=batch_request,
+        runtime_configuration=None,
     )
 
     parameter_nodes: Optional[Dict[str, ParameterNode]] = (
@@ -71,8 +75,8 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_default(
     )
     assert len(parameter_nodes) == 1
 
-    fully_qualified_parameter_name_for_value: str = "$parameter.row_count_range"
-    expected_value_dict: Dict[str, Optional[str]] = {
+    fully_qualified_parameter_name: str = "$parameter.row_count"
+    expected_parameter_node_as_dict: dict = {
         "value": None,
         "attributed_value": None,
         "details": {
@@ -80,7 +84,6 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_default(
                 "domain_kwargs": {},
                 "metric_name": "table.row_count",
                 "metric_value_kwargs": None,
-                "metric_dependencies": None,
             },
             "num_batches": 3,
         },
@@ -88,7 +91,7 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_default(
 
     parameter_node: ParameterNode = (
         get_parameter_value_by_fully_qualified_parameter_name(
-            fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
+            fully_qualified_parameter_name=fully_qualified_parameter_name,
             domain=domain,
             parameters=parameters,
         )
@@ -97,7 +100,7 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_default(
     parameter_node["value"] = None
     parameter_node["attributed_value"] = None
 
-    assert parameter_node == expected_value_dict
+    assert parameter_node == expected_parameter_node_as_dict
 
 
 @pytest.mark.integration
@@ -115,17 +118,19 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_no(
         "data_asset_name": "my_reports",
     }
 
-    metric_multi_batch_parameter_builder = MetricMultiBatchParameterBuilder(
-        name="row_count_range",
-        metric_name="table.row_count",
-        metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
-        metric_value_kwargs=None,
-        single_batch_mode=f"{VARIABLES_KEY}single_batch_mode",
-        enforce_numeric_metric=True,
-        replace_nan_with_zero=True,
-        reduce_scalar_metric=True,
-        evaluation_parameter_builder_configs=None,
-        data_context=data_context,
+    metric_multi_batch_parameter_builder: ParameterBuilder = (
+        MetricMultiBatchParameterBuilder(
+            name="row_count",
+            metric_name="table.row_count",
+            metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+            metric_value_kwargs=None,
+            single_batch_mode=f"{VARIABLES_KEY}single_batch_mode",
+            enforce_numeric_metric=True,
+            replace_nan_with_zero=True,
+            reduce_scalar_metric=True,
+            evaluation_parameter_builder_configs=None,
+            data_context=data_context,
+        )
     )
 
     domain = Domain(
@@ -133,7 +138,7 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_no(
         rule_name="my_rule",
     )
     parameter_container = ParameterContainer(parameter_nodes=None)
-    parameters: Dict[str, ParameterContainer] = {
+    parameters: Dict[str, ParameterContainer | None] = {
         domain.id: parameter_container,
     }
 
@@ -150,6 +155,7 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_no(
         variables=variables,
         parameters=parameters,
         batch_request=batch_request,
+        runtime_configuration=None,
     )
 
     parameter_nodes: Optional[Dict[str, ParameterNode]] = (
@@ -157,8 +163,8 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_no(
     )
     assert len(parameter_nodes) == 1
 
-    fully_qualified_parameter_name_for_value: str = "$parameter.row_count_range"
-    expected_value_dict: Dict[str, Optional[str]] = {
+    fully_qualified_parameter_name: str = "$parameter.row_count"
+    expected_parameter_node_as_dict: dict = {
         "value": None,
         "attributed_value": None,
         "details": {
@@ -166,7 +172,6 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_no(
                 "domain_kwargs": {},
                 "metric_name": "table.row_count",
                 "metric_value_kwargs": None,
-                "metric_dependencies": None,
             },
             "num_batches": 3,
         },
@@ -174,7 +179,7 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_no(
 
     parameter_node: ParameterNode = (
         get_parameter_value_by_fully_qualified_parameter_name(
-            fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
+            fully_qualified_parameter_name=fully_qualified_parameter_name,
             domain=domain,
             parameters=parameters,
         )
@@ -183,7 +188,7 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_no(
     parameter_node["value"] = None
     parameter_node["attributed_value"] = None
 
-    assert parameter_node == expected_value_dict
+    assert parameter_node == expected_parameter_node_as_dict
 
 
 @pytest.mark.integration
@@ -201,17 +206,19 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_yes(
         "data_asset_name": "my_reports",
     }
 
-    metric_multi_batch_parameter_builder = MetricMultiBatchParameterBuilder(
-        name="row_count_range",
-        metric_name="table.row_count",
-        metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
-        metric_value_kwargs=None,
-        single_batch_mode=f"{VARIABLES_KEY}single_batch_mode",
-        enforce_numeric_metric=True,
-        replace_nan_with_zero=True,
-        reduce_scalar_metric=True,
-        evaluation_parameter_builder_configs=None,
-        data_context=data_context,
+    metric_multi_batch_parameter_builder: ParameterBuilder = (
+        MetricMultiBatchParameterBuilder(
+            name="row_count",
+            metric_name="table.row_count",
+            metric_domain_kwargs=DOMAIN_KWARGS_PARAMETER_FULLY_QUALIFIED_NAME,
+            metric_value_kwargs=None,
+            single_batch_mode=f"{VARIABLES_KEY}single_batch_mode",
+            enforce_numeric_metric=True,
+            replace_nan_with_zero=True,
+            reduce_scalar_metric=True,
+            evaluation_parameter_builder_configs=None,
+            data_context=data_context,
+        )
     )
 
     domain = Domain(
@@ -219,7 +226,7 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_yes(
         rule_name="my_rule",
     )
     parameter_container = ParameterContainer(parameter_nodes=None)
-    parameters: Dict[str, ParameterContainer] = {
+    parameters: Dict[str, ParameterContainer | None] = {
         domain.id: parameter_container,
     }
 
@@ -236,6 +243,7 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_yes(
         variables=variables,
         parameters=parameters,
         batch_request=batch_request,
+        runtime_configuration=None,
     )
 
     parameter_nodes: Optional[Dict[str, ParameterNode]] = (
@@ -243,8 +251,8 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_yes(
     )
     assert len(parameter_nodes) == 1
 
-    fully_qualified_parameter_name_for_value: str = "$parameter.row_count_range"
-    expected_value_dict: Dict[str, Optional[str]] = {
+    fully_qualified_parameter_name: str = "$parameter.row_count"
+    expected_parameter_node_as_dict: dict = {
         "value": None,
         "attributed_value": None,
         "details": {
@@ -252,7 +260,6 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_yes(
                 "domain_kwargs": {},
                 "metric_name": "table.row_count",
                 "metric_value_kwargs": None,
-                "metric_dependencies": None,
             },
             "num_batches": 1,
         },
@@ -260,7 +267,7 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_yes(
 
     parameter_node: ParameterNode = (
         get_parameter_value_by_fully_qualified_parameter_name(
-            fully_qualified_parameter_name=fully_qualified_parameter_name_for_value,
+            fully_qualified_parameter_name=fully_qualified_parameter_name,
             domain=domain,
             parameters=parameters,
         )
@@ -269,4 +276,4 @@ def test_metric_multi_batch_parameter_builder_bobby_single_batch_yes(
     parameter_node["value"] = None
     parameter_node["attributed_value"] = None
 
-    assert parameter_node == expected_value_dict
+    assert parameter_node == expected_parameter_node_as_dict
