@@ -1,6 +1,9 @@
+import pytest
+
 from great_expectations.core import ExpectationSuite
 
 
+@pytest.mark.integration
 def test_alice_fixture_generation(
     alice_columnar_table_single_batch,
 ):
@@ -23,6 +26,7 @@ def test_alice_fixture_generation(
     )
 
 
+@pytest.mark.integration
 def test_bobby_fixture_generation(
     bobby_columnar_table_multi_batch,
 ):
